@@ -56,10 +56,8 @@ split_gears = gears.split_bodies()
 central_gear = split_gears.pop(1)
 central_gear.translate([0, 60, 60], inplace=True)
 
-# also, grab the size of the central gear
-x_size = central_gear.bounds[1] - central_gear.bounds[0]
-y_size = central_gear.bounds[3] - central_gear.bounds[2]
-z_size = central_gear.bounds[5] - central_gear.bounds[4]
+# also, grab the size of the central gear's bounds
+x_size, y_size, z_size = central_gear.bounds_size
 
 plotter = pv.Plotter()
 plotter.add_mesh(split_gears, smooth_shading=True, split_sharp_edges=True)
@@ -72,3 +70,5 @@ plotter.show_grid(
     grid=False,
 )
 plotter.show()
+# %%
+# .. tags:: plot
