@@ -4,7 +4,8 @@
 Plot with Floors
 ~~~~~~~~~~~~~~~~
 
-Add a floor/wall at the boundary of the rendering scene.
+Add a floor/wall at the boundary of the rendering scene
+using :func:`~pyvista.Plotter.add_floor`.
 """
 
 from __future__ import annotations
@@ -19,3 +20,5 @@ plotter.add_mesh(mesh)
 plotter.add_floor('-y')
 plotter.add_floor('-z')
 plotter.show()
+# %%
+# .. tags:: plot
