@@ -1,5 +1,5 @@
 """
-.. _lighting_properties_example:
+.. _lighting_mesh_example:
 
 Lighting Properties
 ~~~~~~~~~~~~~~~~~~~
@@ -86,3 +86,5 @@ mesh.plot(diffuse=0.5, specular=0.5, ambient=0.5, cpos=cpos, show_scalar_bar=Fal
 # %%
 # For detailed control over lighting conditions in general see the
 # :ref:`light_examples` examples.
+#
+# .. tags:: plot
