@@ -1,5 +1,5 @@
 """
-.. _orbiting_example:
+.. _orbit_example:
 
 Orbiting
 ~~~~~~~~
@@ -30,14 +30,15 @@ from pyvista import examples
 mesh = examples.download_st_helens().warp_by_scalar()
 
 # %%
-# Orbit around the Mt. St Helens dataset.
+# Orbit around the Mt. St Helens dataset using
+# :func:`~pyvista.Plotter.generate_orbital_path`.
 
 p = pv.Plotter()
 p.add_mesh(mesh, lighting=False)
 p.camera.zoom(1.5)
 p.show(auto_close=False)
 path = p.generate_orbital_path(n_points=36, shift=mesh.length)
-p.open_gif("orbit.gif")
+p.open_gif('orbit.gif')
 p.orbit_on_path(path, write_frames=True)
 p.close()
 
@@ -50,7 +51,7 @@ p.show_grid()
 p.show(auto_close=False)
 viewup = [0.5, 0.5, 1]
 path = p.generate_orbital_path(factor=2.0, shift=10000, viewup=viewup, n_points=36)
-p.open_gif("orbit.gif")
+p.open_gif('orbit.gif')
 p.orbit_on_path(path, write_frames=True, viewup=[0, 0, 1], step=0.05)
 p.close()
 
@@ -65,6 +66,8 @@ p = pv.Plotter()
 p.add_mesh(mesh)
 p.show(auto_close=False)
 path = p.generate_orbital_path(factor=2.0, n_points=36, viewup=viewup, shift=0.2)
-p.open_gif("orbit.gif")
+p.open_gif('orbit.gif')
 p.orbit_on_path(path, write_frames=True, viewup=viewup, step=0.05)
 p.close()
+# %%
+# .. tags:: plot
