@@ -6,6 +6,10 @@ Silhouette Highlight
 
 Extract a subset of the edges of a polygonal mesh to generate an outline
 (silhouette) of a mesh.
+The silhouette may be created using the `silhouette` keyword with
+:meth:`~pyvista.Plotter.add_mesh`, or by using
+`~pyvista.Plotter.add_silhouette` directly.
+
 """
 
 from __future__ import annotations
@@ -22,11 +26,11 @@ bunny = examples.download_bunny()
 plotter = pyvista.Plotter(shape=(1, 2))
 plotter.subplot(0, 0)
 plotter.add_mesh(bunny, color='lightblue', silhouette=True)
-plotter.add_text("Silhouette")
+plotter.add_text('Silhouette')
 plotter.view_xy()
 plotter.subplot(0, 1)
 plotter.add_mesh(bunny, color='lightblue')
-plotter.add_text("No silhouette")
+plotter.add_text('No silhouette')
 plotter.view_xy()
 plotter.show()
 
@@ -63,7 +67,7 @@ plotter.add_mesh(
     smooth_shading=True,
     silhouette=dict(color='red', line_width=8.0, decimate=None, feature_angle=True),
 )
-plotter.add_text("Silhouette with sharp edges")
+plotter.add_text('Silhouette with sharp edges')
 plotter.view_isometric()
 plotter.subplot(0, 1)
 plotter.add_mesh(
@@ -72,11 +76,11 @@ plotter.add_mesh(
     smooth_shading=True,
     silhouette=dict(color='red', line_width=8.0, decimate=None),
 )
-plotter.add_text("Silhouette without sharp edges")
+plotter.add_text('Silhouette without sharp edges')
 plotter.view_isometric()
 plotter.subplot(0, 2)
 plotter.add_mesh(cylinder, color='lightblue', smooth_shading=True)
-plotter.add_text("No silhouette")
+plotter.add_text('No silhouette')
 plotter.view_isometric()
 plotter.show()
 
@@ -85,10 +89,10 @@ plotter.show()
 # Here is another example:
 dragon = examples.download_dragon()
 plotter = pyvista.Plotter()
-plotter.set_background('black', 'blue')
+plotter.set_background('black', top='blue')
 plotter.add_mesh(
     dragon,
-    color="green",
+    color='green',
     specular=1,
     smooth_shading=True,
     silhouette=dict(line_width=8, color='white'),
@@ -106,3 +110,5 @@ plotter.camera_position = [
     (0.34348225747312017, 0.8567703221182346, -0.38466160965007384),
 ]
 plotter.show()
+# %%
+# .. tags:: plot
