@@ -5,7 +5,8 @@ Control Global and Local Plotting Themes
 ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 
 PyVista allows you to set global and local plotting themes to easily
-set default plotting parameters.
+set default plotting parameters. This example shows how to use the
+:ref:`theme_api` and :func:`~pyvista.set_plot_theme` function.
 
 """
 
@@ -45,12 +46,13 @@ plot_example()
 #
 # * ``'ParaView'``: this is designed to mimic ParaView's default plotting theme.
 # * ``'dark'``: this is designed to be night-mode friendly with dark backgrounds and color schemes.
-# * ``'document'``: this is built for use in document style plotting and making publication quality figures.
+# * ``'document'``: this is built for use in document style plotting and making publication
+#   quality figures.
 
 # %%
 # Demo the ``'ParaView'`` theme.
 
-pv.set_plot_theme("paraview")
+pv.set_plot_theme('paraview')
 
 plot_example()
 
@@ -58,14 +60,14 @@ plot_example()
 # %%
 # Demo the ``'dark'`` theme.
 
-pv.set_plot_theme("dark")
+pv.set_plot_theme('dark')
 
 plot_example()
 
 # %%
 # Demo the ``'document'`` theme.  This theme is used on our online examples.
 
-pv.set_plot_theme("document")
+pv.set_plot_theme('document')
 
 plot_example()
 
@@ -76,7 +78,7 @@ plotter = pv.Plotter()
 plotter.add_mesh(mesh)
 plotter.show_grid()
 # Here we set the gradient
-plotter.set_background("royalblue", top="aliceblue")
+plotter.set_background('royalblue', top='aliceblue')
 cpos = plotter.show()
 
 
@@ -171,4 +173,6 @@ cpos = pl.show()
 
 # %%
 # Reset to use the document theme
-pv.set_plot_theme("document")
+pv.set_plot_theme('document')
+# %%
+# .. tags:: plot
