@@ -1,4 +1,6 @@
 """
+.. _vertices_example:
+
 Visible Vertices
 ~~~~~~~~~~~~~~~~
 
@@ -79,3 +81,5 @@ pl.add_points(
     show_scalar_bar=False,
 )
 pl.show(cpos=cpos)
+# %%
+# .. tags:: plot
