@@ -5,7 +5,8 @@ Animation
 ~~~~~~~~~
 
 This example demonstrates how to create a simple animation.
-A timer is used to move a sphere across a scene.
+A timer is used with :meth:`~pyvista.Plotter.add_timer_event`
+to move a sphere across a scene.
 
 Inspired by `VTK Animation Examples <https://examples.vtk.org/site/Python/Utilities/Animation/>`_.
 """
@@ -28,3 +29,5 @@ pl.add_timer_event(max_steps=200, duration=500, callback=callback)
 
 cpos = [(0.0, 0.0, 10.0), (0.0, 0.0, 0.0), (0.0, 1.0, 0.0)]
 pl.show(cpos=cpos)
+# %%
+# .. tags:: widgets
