@@ -4,7 +4,8 @@
 3D Earth and Celestial Bodies
 ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 
-Plot the solar system in PyVista.
+Plot the solar system in PyVista using datasets from the
+:mod:`~pyvista.examples.planets` module.
 
 This example is inspired by `planet3D-MATLAB
 <https://github.com/tamaskis/planet3D-MATLAB>`_.
@@ -79,10 +80,10 @@ uranus.translate((-600000.0, 0.0, 0.0), inplace=True)
 neptune.translate((-700000.0, 0.0, 0.0), inplace=True)
 
 # Add planets to Plotter.
-pl = pyvista.Plotter(lighting="none")
-cubemap = examples.download_cubemap_space_16k()
+pl = pyvista.Plotter(lighting='none')
+cubemap = examples.download_cubemap_space_4k()
 _ = pl.add_actor(cubemap.to_skybox())
-pl.set_environment_texture(cubemap, True)
+pl.set_environment_texture(cubemap, is_srgb=True, resample=1 / 64)
 pl.add_light(light)
 pl.add_mesh(mercury, texture=mercury_texture, smooth_shading=True)
 pl.add_mesh(venus, texture=venus_texture, smooth_shading=True)
@@ -105,21 +106,21 @@ pl.show()
 
 pl = pyvista.Plotter(shape=(3, 2))
 pl.subplot(0, 0)
-pl.add_text("Mercury")
+pl.add_text('Mercury')
 pl.add_mesh(examples.planets.download_mercury_surface(), rgb=True)
 pl.subplot(0, 1)
 pl.add_mesh(mercury, texture=mercury_texture)
 pl.subplot(1, 0)
-pl.add_text("Venus")
+pl.add_text('Venus')
 pl.add_mesh(examples.planets.download_venus_surface(atmosphere=True), rgb=True)
 pl.subplot(1, 1)
 pl.add_mesh(venus, texture=venus_texture)
 pl.subplot(2, 0)
-pl.add_text("Mars")
+pl.add_text('Mars')
 pl.add_mesh(examples.planets.download_mars_surface(), rgb=True)
 pl.subplot(2, 1)
 pl.add_mesh(mars, texture=mars_texture)
-pl.show(cpos="xy")
+pl.show(cpos='xy')
 
 
 # %%
@@ -133,10 +134,10 @@ surface_texture = examples.planets.download_venus_surface(atmosphere=False, text
 
 pl = pyvista.Plotter(shape=(1, 2))
 pl.subplot(0, 0)
-pl.add_text("Venus Atmosphere")
+pl.add_text('Venus Atmosphere')
 pl.add_mesh(venus, texture=atmosphere_texture, smooth_shading=True)
 pl.subplot(0, 1)
-pl.add_text("Venus Surface")
+pl.add_text('Venus Surface')
 pl.add_mesh(venus, texture=surface_texture, smooth_shading=True)
 pl.link_views()
-pl.show(cpos="xy")
+pl.show(cpos='xy')
