@@ -55,8 +55,9 @@ def sphere_to_cylinder(theta, phi):
     return h, phi
 
 
-def cylinder_to_wormhole(h, phi, t, p, q):
-    """Map from a cylinder to an open wormhole using Eq. (4).
+def cylinder_to_wormhole(h, phi, t, p, q):  # noqa: PLR0917
+    """
+    Map from a cylinder to an open wormhole using Eq. (4).
 
     Input h goes from -infinity to infinity, phi goes from -phi to phi.
     Output is an (x, y, z) point embedded in 3d space.
@@ -71,8 +72,9 @@ def cylinder_to_wormhole(h, phi, t, p, q):
     return x, y, z
 
 
-def close_wormhole(x0, y0, z0, eta, xi, alpha):
-    """Close the wormhole using Eqs. (7)-(8).
+def close_wormhole(x0, y0, z0, eta, xi, alpha):  # noqa: PLR0917
+    """
+    Close the wormhole using Eqs. (7)-(8).
 
     Input is an (x0, y0, z0) point embedded in 3d space.
     Output is an (x2, y2, z2) == (x'', y'', z'') point embedded in 3d space.
@@ -105,8 +107,9 @@ def close_wormhole(x0, y0, z0, eta, xi, alpha):
     return x2, y2, z2
 
 
-def unfold_sphere(theta, phi, t, q, eta, lamda):
-    """Unfold the sphere using Eqs. (12), (15), (10).
+def unfold_sphere(theta, phi, t, q, eta, lamda):  # noqa: PLR0917
+    """
+    Unfold the sphere using Eqs. (12), (15), (10).
 
     Input is a (theta, phi) point in spherical coordinates.
     Output is an (x, y, z) point embedded in 3d space.
@@ -133,7 +136,7 @@ def unfold_sphere(theta, phi, t, q, eta, lamda):
             - t / n * np.cos(n * phi)
         )
         - (1 - lamda) * eta**(1 + kappa) * t * abs(t)**(2 * kappa)
-            * np.sin(theta) / np.cos(theta)**(2 * n)  # noqa: E131
+            * np.sin(theta) / np.cos(theta)**(2 * n)
     )
     # fmt: on
 
@@ -171,7 +174,7 @@ plotter.open_gif('sphere_eversion.gif')
 
 
 def save_frame(x, y, z):
-    """Helper to generate and store a frame of the eversion."""
+    """Generate and store a frame of the eversion."""
     plotter.clear()
     plotter.enable_lightkit()
     plotter.add_mesh(pv.StructuredGrid(x, y, z), **opts)
