@@ -13,10 +13,10 @@ from pyvista.trame.ui import plotter_ui
 
 pv.OFF_SCREEN = True
 
-server = get_server(client_type="vue3")
+server = get_server(client_type='vue3')
 state, ctrl = server.state, server.controller
 
-state.trame__title = "Cone"
+state.trame__title = 'Cone'
 ctrl.on_server_ready.add(ctrl.view_update)
 
 
@@ -35,8 +35,8 @@ pl.add_mesh(source, color='seagreen')
 # -----------------------------------------------------------------------------
 
 
-@state.change("resolution")
-def update_contour(resolution, **kwargs):
+@state.change('resolution')
+def update_contour(resolution, **kwargs):  # noqa: ARG001
     source.resolution = int(resolution)
     ctrl.view_update()
 
@@ -47,18 +47,18 @@ def update_contour(resolution, **kwargs):
 
 
 with SinglePageLayout(server) as layout:
-    layout.title.set_text("Cone")
+    layout.title.set_text('Cone')
 
     with layout.toolbar:
         vuetify3.VSpacer()
         vuetify3.VSlider(
-            label="Resolution",
-            v_model=("resolution", 15),
+            label='Resolution',
+            v_model=('resolution', 15),
             min=5,
             max=30,
             hide_details=True,
-            density="compact",
-            style="max-width: 300px",
+            density='compact',
+            style='max-width: 300px',
             change=ctrl.view_update,
         )
 
@@ -66,13 +66,13 @@ with SinglePageLayout(server) as layout:
             indeterminate=True,
             absolute=True,
             bottom=True,
-            active=("trame__busy",),
+            active=('trame__busy',),
         )
 
     with layout.content:
         with vuetify3.VContainer(
             fluid=True,
-            classes="pa-0 fill-height",
+            classes='pa-0 fill-height',
         ):
             # Use PyVista UI template for Plotters
             view = plotter_ui(pl)
