@@ -14,10 +14,10 @@ from pyvista.trame.ui import plotter_ui
 
 pv.OFF_SCREEN = True
 
-server = get_server(client_type="vue3")
+server = get_server(client_type='vue3')
 state, ctrl = server.state, server.controller
 
-state.trame__title = "Multi Views"
+state.trame__title = 'Multi Views'
 ctrl.on_server_ready.add(ctrl.view_update)
 
 
@@ -25,14 +25,14 @@ ctrl.on_server_ready.add(ctrl.view_update)
 # Plotting
 # -----------------------------------------------------------------------------
 mesh = examples.load_random_hills()
-arrows = mesh.glyph(scale="Normals", orient="Normals", tolerance=0.05)
+arrows = mesh.glyph(scale='Normals', orient='Normals', tolerance=0.05)
 
 
 pl = pv.Plotter(shape=(1, 2))
-pl.add_mesh(mesh, scalars="Elevation", cmap="terrain", smooth_shading=True)
+pl.add_mesh(mesh, scalars='Elevation', cmap='terrain', smooth_shading=True)
 pl.subplot(0, 1)
-pl.add_mesh(mesh, opacity=0.75, scalars="Elevation", cmap="terrain", smooth_shading=True)
-pl.add_mesh(arrows, color="black")
+pl.add_mesh(mesh, opacity=0.75, scalars='Elevation', cmap='terrain', smooth_shading=True)
+pl.add_mesh(arrows, color='black')
 pl.link_views()
 
 
@@ -42,13 +42,13 @@ pl.link_views()
 
 
 with SinglePageLayout(server) as layout:
-    layout.title.set_text("Multi Views")
+    layout.title.set_text('Multi Views')
     layout.icon.click = ctrl.view_reset_camera
 
     with layout.content:
         with vuetify3.VContainer(
             fluid=True,
-            classes="pa-0 fill-height",
+            classes='pa-0 fill-height',
         ):
             # Use PyVista UI template for Plotters
             view = plotter_ui(pl)
