@@ -10,39 +10,43 @@ decouple the ``core`` and ``plotting`` APIs.
 
 from __future__ import annotations
 
+from pathlib import Path
+
 import numpy as np
 
 import pyvista
+from pyvista._deprecate_positional_args import _deprecate_positional_args
 
 
-def plot(
+@_deprecate_positional_args(allowed=['var_item'])
+def plot(  # noqa: PLR0917
     var_item,
     off_screen=None,
     full_screen=None,
     screenshot=None,
-    interactive=True,
+    interactive=True,  # noqa: FBT002
     cpos=None,
     window_size=None,
-    show_bounds=False,
+    show_bounds=False,  # noqa: FBT002
     show_axes=None,
     notebook=None,
     background=None,
     text='',
-    return_img=False,
-    eye_dome_lighting=False,
-    volume=False,
-    parallel_projection=False,
+    return_img=False,  # noqa: FBT002
+    eye_dome_lighting=False,  # noqa: FBT002
+    volume=False,  # noqa: FBT002
+    parallel_projection=False,  # noqa: FBT002
     jupyter_backend=None,
-    return_viewer=False,
-    return_cpos=False,
+    return_viewer=False,  # noqa: FBT002
+    return_cpos=False,  # noqa: FBT002
     jupyter_kwargs=None,
     theme=None,
     anti_aliasing=None,
     zoom=None,
-    border=False,
+    border=False,  # noqa: FBT002
     border_color='k',
     border_width=2.0,
-    ssao=False,
+    ssao=False,  # noqa: FBT002
     **kwargs,
 ):
     """Plot a PyVista, numpy, or vtk object.
@@ -129,6 +133,8 @@ def plot(
 
     jupyter_kwargs : dict, optional
         Keyword arguments for the Jupyter notebook plotting backend.
+        See :ref:`customize_trame_toolbar_example` for an example
+        using this keyword.
 
     theme : pyvista.plotting.themes.Theme, optional
         Plot-specific theme.
@@ -198,9 +204,7 @@ def plot(
     ImageData. Note ``volume=True`` is passed.
 
     >>> import numpy as np
-    >>> grid = pv.ImageData(
-    ...     dimensions=(32, 32, 32), spacing=(0.5, 0.5, 0.5)
-    ... )
+    >>> grid = pv.ImageData(dimensions=(32, 32, 32), spacing=(0.5, 0.5, 0.5))
     >>> grid['data'] = np.linalg.norm(grid.center - grid.points, axis=1)
     >>> grid['data'] = np.abs(grid['data'] - grid['data'].max()) ** 3
     >>> grid.plot(volume=True)
@@ -213,7 +217,7 @@ def plot(
     before_close_callback = kwargs.pop('before_close_callback', None)
 
     # pop from kwargs here to avoid including them in add_mesh or add_volume
-    eye_dome_lighting = kwargs.pop("edl", eye_dome_lighting)
+    eye_dome_lighting = kwargs.pop('edl', eye_dome_lighting)
     show_grid = kwargs.pop('show_grid', False)
     auto_close = kwargs.get('auto_close')
 
@@ -243,7 +247,16 @@ def plot(
     elif anti_aliasing is False:
         pl.disable_anti_aliasing()
 
-    pl.set_background(background)
+    try:
+        pl.set_background(background)
+    except (ValueError, TypeError):
+        if isinstance(background, (str, Path)):
+            path = Path(background)
+            if path.is_file():
+                pl.add_background_image(path)
+        else:
+            msg = f'Background must be color-like or a file path. Got {background} instead.'
+            raise TypeError(msg)
 
     if isinstance(var_item, list):
         if len(var_item) == 2:  # might be arrows
@@ -263,13 +276,12 @@ def plot(
                     pl.add_volume(item, **kwargs)
                 else:
                     pl.add_mesh(item, **kwargs)
+    elif volume or (isinstance(var_item, np.ndarray) and var_item.ndim == 3):
+        pl.add_volume(var_item, **kwargs)
+    elif isinstance(var_item, pyvista.MultiBlock):
+        pl.add_composite(var_item, **kwargs)
     else:
-        if volume or (isinstance(var_item, np.ndarray) and var_item.ndim == 3):
-            pl.add_volume(var_item, **kwargs)
-        elif isinstance(var_item, pyvista.MultiBlock):
-            pl.add_composite(var_item, **kwargs)
-        else:
-            pl.add_mesh(var_item, **kwargs)
+        pl.add_mesh(var_item, **kwargs)
 
     if text:
         pl.add_text(text)
