@@ -12,12 +12,16 @@ A ``check`` function typically:
 
 from __future__ import annotations
 
+from collections.abc import Container
 from collections.abc import Iterable
+from collections.abc import Sequence
+from collections.abc import Sized
 from numbers import Number
 import reprlib
 from typing import TYPE_CHECKING
-from typing import Sequence
+from typing import Any
 from typing import Union
+from typing import cast
 from typing import get_args
 from typing import get_origin
 
@@ -26,9 +30,16 @@ import numpy.typing as npt
 
 from pyvista.core._validation._cast_array import _cast_to_numpy
 
-if TYPE_CHECKING:  # pragma: no cover
+if TYPE_CHECKING:
     from pyvista.core._typing_core import NumberType
+    from pyvista.core._typing_core import NumpyArray
+    from pyvista.core._typing_core import VectorLike
     from pyvista.core._typing_core._aliases import _ArrayLikeOrScalar
+    from pyvista.core._typing_core._array_like import _NumberType
+
+
+_Shape = Union[tuple[()], tuple[int, ...]]
+_ShapeLike = Union[int, _Shape]
 
 
 def check_subdtype(
@@ -37,7 +48,7 @@ def check_subdtype(
     base_dtype: Union[npt.DTypeLike, tuple[npt.DTypeLike, ...], list[npt.DTypeLike]],
     *,
     name: str = 'Input',
-):
+) -> None:
     """Check if an input's data-type is a subtype of another data-type(s).
 
     Parameters
@@ -95,13 +106,13 @@ def check_subdtype(
         # Not a subdtype, so raise error
         msg = f"{name} has incorrect dtype of '{input_dtype.name}'. "
         if len(base_dtype) == 1:
-            msg += f"The dtype must be a subtype of {base_dtype[0]}."
+            msg += f'The dtype must be a subtype of {base_dtype[0]}.'
         else:
-            msg += f"The dtype must be a subtype of at least one of \n{base_dtype}."
+            msg += f'The dtype must be a subtype of at least one of \n{base_dtype}.'
         raise TypeError(msg)
 
 
-def check_real(array: _ArrayLikeOrScalar[NumberType], /, *, name: str = "Array"):
+def check_real(array: _ArrayLikeOrScalar[NumberType], /, *, name: str = 'Array') -> None:
     """Check if an array has real numbers, i.e. float or integer type.
 
     Notes
@@ -152,7 +163,8 @@ def check_real(array: _ArrayLikeOrScalar[NumberType], /, *, name: str = "Array")
     try:
         check_subdtype(array, (np.floating, np.integer), name=name)
     except TypeError as e:
-        raise TypeError(f"{name} must have real numbers.") from e
+        msg = f'{name} must have real numbers.'
+        raise TypeError(msg) from e
 
 
 def check_sorted(
@@ -162,8 +174,8 @@ def check_sorted(
     ascending: bool = True,
     strict: bool = False,
     axis: int = -1,
-    name: str = "Array",
-):
+    name: str = 'Array',
+) -> None:
     """Check if an array's values are sorted.
 
     Parameters
@@ -215,17 +227,18 @@ def check_sorted(
 
     # Validate axis
     if axis not in [-1, None]:
-        check_number(axis, name="Axis")
-        check_integer(axis, name="Axis")
+        check_number(axis, name='Axis')
+        check_integer(axis, name='Axis')
         axis = int(axis)
         try:
-            check_range(axis, rng=[-ndim, ndim - 1], name="Axis")
+            check_range(axis, rng=[-ndim, ndim - 1], name='Axis')
         except ValueError:
-            raise ValueError(f"Axis {axis} is out of bounds for ndim {ndim}.")
+            msg = f'Axis {axis} is out of bounds for ndim {ndim}.'
+            raise ValueError(msg)
 
-    if axis is None and ndim >= 1:
+    if axis is None and ndim >= 1:  # type: ignore[unreachable]
         # Emulate np.sort(), which flattens array when axis is None
-        array = array.ravel(order='A')
+        array = array.ravel(order='A')  # type: ignore[unreachable]
         ndim = 1
         axis = 0
 
@@ -250,22 +263,23 @@ def check_sorted(
 
     if not is_sorted:
         # Show the array's elements in error msg if array is small
-        msg_body = f"with {array.size} elements"
-        order = "ascending" if ascending else "descending"
-        strict_ = "strict " if strict else ""
-        raise ValueError(
-            f"{name} {msg_body} must be sorted in {strict_}{order} order. "
-            f"Got:\n    {reprlib.repr(array)}",
+        msg_body = f'with {array.size} elements'
+        order = 'ascending' if ascending else 'descending'
+        strict_ = 'strict ' if strict else ''
+        msg = (
+            f'{name} {msg_body} must be sorted in {strict_}{order} order. '
+            f'Got:\n    {reprlib.repr(array)}'
         )
+        raise ValueError(msg)
 
 
-def check_finite(arr, /, *, name="Array"):
+def check_finite(array: _ArrayLikeOrScalar[NumberType], /, *, name: str = 'Array') -> None:
     """Check if an array has finite values, i.e. no NaN or Inf values.
 
     Parameters
     ----------
-    arr : array_like
-        Array to check.
+    array : float | ArrayLike[float]
+        Number or array to check.
 
     name : str, default: "Array"
         Variable name to use in the error messages if any are raised.
@@ -287,22 +301,30 @@ def check_finite(arr, /, *, name="Array"):
     >>> _validation.check_finite([1, 2, 3])
 
     """
-    arr = arr if isinstance(arr, np.ndarray) else _cast_to_numpy(arr)
-    if not np.all(np.isfinite(arr)):
-        raise ValueError(f"{name} must have finite values.")
+    array = array if isinstance(array, np.ndarray) else _cast_to_numpy(array)
+    if not np.all(np.isfinite(array)):
+        msg = f'{name} must have finite values.'
+        raise ValueError(msg)
 
 
-def check_integer(arr, /, *, strict=False, name="Array"):
+def check_integer(
+    array: _ArrayLikeOrScalar[NumberType],
+    /,
+    *,
+    strict: bool = False,
+    name: str = 'Array',
+) -> None:
     """Check if an array has integer or integer-like float values.
 
     Parameters
     ----------
-    arr : array_like
-        Array to check.
+    array : float | ArrayLike[float]
+        Number or array to check.
 
     strict : bool, default: False
-        If ``True``, the array's data must be a subtype of ``np.integer``
-        (i.e. float types are not allowed).
+        If ``True``, the array's data must be a subtype of `int` or
+        ``np.integer``. Otherwise, floats are allowed but must be
+        whole numbers.
 
     name : str, default: "Array"
         Variable name to use in the error messages if any are raised.
@@ -318,6 +340,7 @@ def check_integer(arr, /, *, strict=False, name="Array"):
     See Also
     --------
     check_nonnegative
+    check_subdtype
 
     Examples
     --------
@@ -327,20 +350,21 @@ def check_integer(arr, /, *, strict=False, name="Array"):
     >>> _validation.check_integer([1.0, 2.0])
 
     """
-    arr = arr if isinstance(arr, np.ndarray) else _cast_to_numpy(arr)
+    array = array if isinstance(array, np.ndarray) else _cast_to_numpy(array)
     if strict:
-        check_subdtype(arr, np.integer)
-    elif not np.array_equal(arr, np.floor(arr)):
-        raise ValueError(f"{name} must have integer-like values.")
+        check_subdtype(array, np.integer)
+    elif not np.array_equal(array, np.floor(array)):
+        msg = f'{name} must have integer-like values.'
+        raise ValueError(msg)
 
 
-def check_nonnegative(arr, /, *, name="Array"):
+def check_nonnegative(array: _ArrayLikeOrScalar[NumberType], /, *, name: str = 'Array') -> None:
     """Check if an array's elements are all nonnegative.
 
     Parameters
     ----------
-    arr : array_like
-        Array to check.
+    array : float | ArrayLike[float]
+        Number or array to check.
 
     name : str, default: "Array"
         Variable name to use in the error messages if any are raised.
@@ -363,18 +387,32 @@ def check_nonnegative(arr, /, *, name="Array"):
     >>> _validation.check_nonnegative([1, 2, 3])
 
     """
-    check_greater_than(arr, 0, strict=False, name=name)
+    check_greater_than(array, 0, strict=False, name=name)
 
 
-def check_greater_than(arr, /, value, *, strict=True, name="Array"):
+def _validate_real_value(scalar: float, name: str = 'Value') -> NumpyArray[float]:
+    valid_scalar = _cast_to_numpy(scalar)
+    check_shape(valid_scalar, (), name=name)
+    check_real(valid_scalar, name=name)
+    return valid_scalar
+
+
+def check_greater_than(
+    array: _ArrayLikeOrScalar[NumberType],
+    /,
+    value: float,
+    *,
+    strict: bool = True,
+    name: str = 'Array',
+) -> None:
     """Check if an array's elements are all greater than some value.
 
     Parameters
     ----------
-    arr : array_like
-        Array to check.
+    array : float | ArrayLike[float]
+        Number or array to check.
 
-    value : Number
+    value : float
         Value which the array's elements must be greater than.
 
     strict : bool, default: True
@@ -393,7 +431,7 @@ def check_greater_than(arr, /, value, *, strict=True, name="Array"):
     See Also
     --------
     check_less_than
-    check_in_range
+    check_range
     check_nonnegative
 
     Examples
@@ -404,26 +442,32 @@ def check_greater_than(arr, /, value, *, strict=True, name="Array"):
     >>> _validation.check_greater_than([1, 2, 3], value=0)
 
     """
-    arr = arr if isinstance(arr, np.ndarray) else _cast_to_numpy(arr)
-    value = _cast_to_numpy(value)
-    check_shape(value, ())
-    check_real(value)
-    check_finite(value)
-    if strict and not np.all(arr > value):
-        raise ValueError(f"{name} values must all be greater than {value}.")
-    elif not np.all(arr >= value):
-        raise ValueError(f"{name} values must all be greater than or equal to {value}.")
+    array = array if isinstance(array, np.ndarray) else _cast_to_numpy(array)
+    valid_value = _validate_real_value(value)
+    if strict and not np.all(array > valid_value):
+        msg = f'{name} values must all be greater than {value}.'
+        raise ValueError(msg)
+    elif not np.all(array >= valid_value):
+        msg = f'{name} values must all be greater than or equal to {value}.'
+        raise ValueError(msg)
 
 
-def check_less_than(arr, /, value, *, strict=True, name="Array"):
+def check_less_than(
+    array: _ArrayLikeOrScalar[NumberType],
+    /,
+    value: float,
+    *,
+    strict: bool = True,
+    name: str = 'Array',
+) -> None:
     """Check if an array's elements are all less than some value.
 
     Parameters
     ----------
-    arr : array_like
-        Array to check.
+    array : float | ArrayLike[float]
+        Number or array to check.
 
-    value : Number
+    value : float
         Value which the array's elements must be less than.
 
     strict : bool, default: True
@@ -443,7 +487,7 @@ def check_less_than(arr, /, value, *, strict=True, name="Array"):
     See Also
     --------
     check_greater_than
-    check_in_range
+    check_range
     check_nonnegative
 
     Examples
@@ -454,23 +498,34 @@ def check_less_than(arr, /, value, *, strict=True, name="Array"):
     >>> _validation.check_less_than([-1, -2, -3], value=0)
 
     """
-    arr = arr if isinstance(arr, np.ndarray) else _cast_to_numpy(arr)
-    if strict and not np.all(arr < value):
-        raise ValueError(f"{name} values must all be less than {value}.")
-    elif not np.all(arr <= value):
-        raise ValueError(f"{name} values must all be less than or equal to {value}.")
+    array = array if isinstance(array, np.ndarray) else _cast_to_numpy(array)
+    valid_value = _validate_real_value(value)
+    if strict and not np.all(array < valid_value):
+        msg = f'{name} values must all be less than {value}.'
+        raise ValueError(msg)
+    elif not np.all(array <= valid_value):
+        msg = f'{name} values must all be less than or equal to {value}.'
+        raise ValueError(msg)
 
 
-def check_range(arr, /, rng, *, strict_lower=False, strict_upper=False, name="Array"):
+def check_range(
+    array: _ArrayLikeOrScalar[NumberType],
+    /,
+    rng: VectorLike[_NumberType],
+    *,
+    strict_lower: bool = False,
+    strict_upper: bool = False,
+    name: str = 'Array',
+) -> None:
     """Check if an array's values are all within a specific range.
 
     Parameters
     ----------
-    arr : array_like
-        Array to check.
+    array : float | ArrayLike[float]
+        Number or array to check.
 
-    rng : array_like[float, float], optional
-        Array-like with two elements ``[min, max]`` specifying the minimum
+    rng : VectorLike[float], optional
+        Vector with two elements ``[min, max]`` specifying the minimum
         and maximum data values allowed, respectively. By default, the
         range endpoints are inclusive, i.e. values must be >= min
         and <= max. Use ``strict_lower`` and/or ``strict_upper``
@@ -506,31 +561,30 @@ def check_range(arr, /, rng, *, strict_lower=False, strict_upper=False, name="Ar
     >>> _validation.check_range([0, 0.5, 1], rng=[0, 1])
 
     """
-    rng = _cast_to_numpy(rng)
-    check_shape(rng, 2, name="Range")
-    check_real(rng, name="Range")
-    check_sorted(rng, name="Range")
+    rng = rng if isinstance(rng, np.ndarray) else _cast_to_numpy(rng)
+    check_shape(rng, 2, name='Range')
+    check_sorted(rng, name='Range')
 
-    arr = arr if isinstance(arr, np.ndarray) else _cast_to_numpy(arr)
-    check_greater_than(arr, rng[0], strict=strict_lower, name=name)
-    check_less_than(arr, rng[1], strict=strict_upper, name=name)
+    array = array if isinstance(array, np.ndarray) else _cast_to_numpy(array)
+    check_greater_than(array, rng[0], strict=strict_lower, name=name)
+    check_less_than(array, rng[1], strict=strict_upper, name=name)
 
 
 def check_shape(
-    arr,
+    array: _ArrayLikeOrScalar[NumberType],
     /,
-    shape,
+    shape: _ShapeLike | list[_ShapeLike],
     *,
-    name="Array",
-):
+    name: str = 'Array',
+) -> None:
     """Check if an array has the specified shape.
 
     Parameters
     ----------
-    arr : array_like
-        Array to check.
+    array : float | ArrayLike[float]
+        Number or array to check.
 
-    shape : int, tuple[int, ...] | list[int, tuple[int, ...]], optional
+    shape : ShapeLike | list[ShapeLike]
         A single shape or a list of any allowable shapes. If an integer,
         ``i``, the shape is interpreted as ``(i,)``. Use a value of
         -1 for any dimension where its size is allowed to vary, e.g.
@@ -549,6 +603,7 @@ def check_shape(
     See Also
     --------
     check_length
+    check_ndim
 
     Examples
     --------
@@ -568,31 +623,97 @@ def check_shape(
 
     """
 
-    def _shape_is_allowed(a, b):
+    def _shape_is_allowed(a: _Shape, b: _Shape) -> bool:
         # a: array's actual shape
         # b: allowed shape (may have -1)
-        return bool(len(a) == len(b) and all(map(lambda x, y: True if x == y else y == -1, a, b)))
-
-    arr = arr if isinstance(arr, np.ndarray) else _cast_to_numpy(arr)
+        return len(a) == len(b) and all(map(lambda x, y: True if x == y else y == -1, a, b))
 
     if not isinstance(shape, list):
         shape = [shape]
 
-    array_shape = arr.shape
-    for shp in shape:
-        shp = _validate_shape_value(shp)
-        if _shape_is_allowed(array_shape, shp):
+    array_shape = np.shape(array)  # type: ignore[arg-type]
+    for input_shape in shape:
+        valid_shape = _validate_shape_value(input_shape)
+        if _shape_is_allowed(array_shape, valid_shape):
             return
 
-    msg = f"{name} has shape {arr.shape} which is not allowed. "
+    msg = f'{name} has shape {array_shape} which is not allowed. '
     if len(shape) == 1:
-        msg += f"Shape must be {shape[0]}."
+        msg += f'Shape must be {shape[0]}.'
     else:
-        msg += f"Shape must be one of {shape}."
+        msg += f'Shape must be one of {shape}.'
     raise ValueError(msg)
 
 
-def check_number(num, /, *, name='Object'):
+def check_ndim(
+    array: _ArrayLikeOrScalar[NumberType],
+    /,
+    ndim: int | VectorLike[int],
+    *,
+    name: str = 'Array',
+) -> None:
+    """Check if an array has the specified number of dimensions.
+
+    .. note::
+        Scalar values have a dimension of ``0``.
+
+    Parameters
+    ----------
+    array : float | ArrayLike[float]
+        Number or array to check.
+
+    ndim : int | Sequence[int], optional
+        A single dimension or a sequence of allowable dimensions. If an
+        integer, the array must have this number of dimension(s). If a
+        sequence, the array must have at least one of the specified number
+        of dimensions.
+
+    name : str, default: "Array"
+        Variable name to use in the error messages if any are raised.
+
+    Raises
+    ------
+    ValueError
+        If the array does not have the required number of dimensions.
+
+    See Also
+    --------
+    check_length
+    check_shape
+
+    Examples
+    --------
+    Check if an array is one-dimensional
+
+    >>> import numpy as np
+    >>> from pyvista import _validation
+    >>> _validation.check_ndim([1, 2, 3], ndim=1)
+
+    Check if an array is two-dimensional or a scalar.
+
+    >>> _validation.check_ndim(1, ndim=(0, 2))
+
+    """
+    ndim_ = np.atleast_1d(ndim)
+
+    array_ndim = _cast_to_numpy(array).ndim
+    if array_ndim not in ndim_:
+        check_ndim(ndim, [0, 1], name='ndim')
+
+        if len(ndim_) == 1:
+            check_integer(ndim_[0], strict=True, name='ndim')
+            expected = f'{ndim}'
+        else:
+            check_integer(ndim, strict=True, name='ndim')
+            expected = f'one of {ndim}'
+        msg = (
+            f'{name} has the incorrect number of dimensions. '
+            f'Got {array_ndim}, expected {expected}.'
+        )
+        raise ValueError(msg)
+
+
+def check_number(num: float, /, *, name: str = 'Object') -> None:
     """Check if an object is an instance of ``Number``.
 
     A number is any instance of ``numbers.Number``, e.g.  ``int``,
@@ -604,7 +725,7 @@ def check_number(num, /, *, name='Object'):
 
     Parameters
     ----------
-    num : Number
+    num : numbers.Number
         Number to check.
 
     name : str, default: "Object"
@@ -615,10 +736,6 @@ def check_number(num, /, *, name='Object'):
     TypeError
         If input is not an instance of ``Number``.
 
-    See Also
-    --------
-    check_scalar
-
     Examples
     --------
     Check if a complex number is an instance of ``Number``.
@@ -630,7 +747,7 @@ def check_number(num, /, *, name='Object'):
     check_instance(num, Number, allow_subclass=True, name=name)
 
 
-def check_string(obj, /, *, allow_subclass=True, name='Object'):
+def check_string(obj: str, /, *, allow_subclass: bool = True, name: str = 'Object') -> None:
     """Check if an object is an instance of ``str``.
 
     Parameters
@@ -662,13 +779,13 @@ def check_string(obj, /, *, allow_subclass=True, name='Object'):
     Check if an object is a string.
 
     >>> from pyvista import _validation
-    >>> _validation.check_string("eggs")
+    >>> _validation.check_string('eggs')
 
     """
     check_instance(obj, str, allow_subclass=allow_subclass, name=name)
 
 
-def check_sequence(obj, /, *, name='Object'):
+def check_sequence(obj: Sequence[Any], /, *, name: str = 'Object') -> None:
     """Check if an object is an instance of ``Sequence``.
 
     Parameters
@@ -696,13 +813,13 @@ def check_sequence(obj, /, *, name='Object'):
     >>> import numpy as np
     >>> from pyvista import _validation
     >>> _validation.check_sequence([1, 2, 3])
-    >>> _validation.check_sequence("A")
+    >>> _validation.check_sequence('A')
 
     """
     check_instance(obj, Sequence, allow_subclass=True, name=name)
 
 
-def check_iterable(obj, /, *, name='Object'):
+def check_iterable(obj: Iterable[Any], /, *, name: str = 'Object') -> None:
     """Check if an object is an instance of ``Iterable``.
 
     Parameters
@@ -737,7 +854,14 @@ def check_iterable(obj, /, *, name='Object'):
     check_instance(obj, Iterable, allow_subclass=True, name=name)
 
 
-def check_instance(obj, /, classinfo, *, allow_subclass=True, name='Object'):
+def check_instance(
+    obj: object,
+    /,
+    classinfo: type | tuple[type, ...],
+    *,
+    allow_subclass: bool = True,
+    name: str = 'Object',
+) -> None:
     """Check if an object is an instance of the given type or types.
 
     Parameters
@@ -778,11 +902,12 @@ def check_instance(obj, /, classinfo, *, allow_subclass=True, name='Object'):
 
     Check if an object is an instance of one of several types.
 
-    >>> _validation.check_instance("eggs", (int, str))
+    >>> _validation.check_instance('eggs', (int, str))
 
     """
     if not isinstance(name, str):
-        raise TypeError(f"Name must be a string, got {type(name)} instead.")
+        msg = f'Name must be a string, got {type(name)} instead.'  # type: ignore[unreachable]
+        raise TypeError(msg)
 
     # Get class info from generics
     if get_origin(classinfo) is Union:
@@ -799,26 +924,28 @@ def check_instance(obj, /, classinfo, *, allow_subclass=True, name='Object'):
     if allow_subclass and not is_instance:
         is_error = True
         if num_classes == 1:
-            msg_body = "must be an instance of"
+            msg_body = 'must be an instance of'
         else:
-            msg_body = "must be an instance of any type"
+            msg_body = 'must be an instance of any type'
 
     # Set flag to raise error if not type
     elif not allow_subclass:
         if isinstance(classinfo, tuple):
             if type(obj) not in classinfo:
                 is_error = True
-                msg_body = "must have one of the following types"
+                msg_body = 'must have one of the following types'
         elif type(obj) is not classinfo:
             is_error = True
-            msg_body = "must have type"
+            msg_body = 'must have type'
 
     if is_error:
-        msg = f"{name} {msg_body} {classinfo}. Got {type(obj)} instead."
+        msg = f'{name} {msg_body} {classinfo}. Got {type(obj)} instead.'
         raise TypeError(msg)
 
 
-def check_type(obj, /, classinfo, *, name='Object'):
+def check_type(
+    obj: object, /, classinfo: type | tuple[type, ...], *, name: str = 'Object'
+) -> None:
     """Check if an object is one of the given type or types.
 
     Notes
@@ -852,20 +979,20 @@ def check_type(obj, /, classinfo, *, name='Object'):
     Check if an object is type ``dict`` or ``set``.
 
     >>> from pyvista import _validation
-    >>> _validation.check_type({'spam': "eggs"}, (dict, set))
+    >>> _validation.check_type({'spam': 'eggs'}, (dict, set))
 
     """
     check_instance(obj, classinfo, allow_subclass=False, name=name)
 
 
 def check_iterable_items(
-    iterable_obj,
+    iterable_obj: Iterable[Any],
     /,
-    item_type,
+    item_type: type | tuple[type, ...],
     *,
-    allow_subclass=True,
-    name='Iterable',
-):
+    allow_subclass: bool = True,
+    name: str = 'Iterable',
+) -> None:
     """Check if an iterable's items all have a specified type.
 
     Parameters
@@ -911,26 +1038,28 @@ def check_iterable_items(
     """
     check_iterable(iterable_obj, name=name)
     any(
-        check_instance(
+        check_instance(  # type: ignore[func-returns-value]
             item,
             item_type,
             allow_subclass=allow_subclass,
-            name=f"All items of {name}",
+            name=f'All items of {name}',
         )
         for item in iterable_obj
     )
 
 
-def check_contains(*, item, container, name='Input'):
+def check_contains(
+    container: Container[Any], /, must_contain: Any, *, name: str = 'Input'
+) -> None:
     """Check if an item is in a container.
 
     Parameters
     ----------
-    item : Any
-        Item to check.
-
     container : Any
-        Container the item is expected to be in.
+        Container to check.
+
+    must_contain : Any
+        Item which must be in the container.
 
     name : str, default: "Input"
         Variable name to use in the error messages if any are raised.
@@ -938,7 +1067,7 @@ def check_contains(*, item, container, name='Input'):
     Raises
     ------
     ValueError
-        If the string is not in the iterable.
+        If the item is not in the container.
 
     See Also
     --------
@@ -950,26 +1079,26 @@ def check_contains(*, item, container, name='Input'):
     Check if ``"A"`` is in a list of strings.
 
     >>> from pyvista import _validation
-    >>> _validation.check_contains(item="A", container=["A", "B", "C"])
+    >>> _validation.check_contains(['A', 'B', 'C'], must_contain='A')
 
     """
-    if item not in container:
+    if must_contain not in container:
         qualifier = 'one of' if isinstance(container, (list, tuple)) else 'in'
-        msg = f"{name} '{item}' is not valid. {name} must be {qualifier}: \n\t{container}"
+        msg = f"{name} '{must_contain}' is not valid. {name} must be {qualifier}: \n\t{container}"
         raise ValueError(msg)
 
 
 def check_length(
-    arr,
+    sized_input: float | Sized,
     /,
+    exact_length: int | VectorLike[int] | None = None,
     *,
-    exact_length=None,
-    min_length=None,
-    max_length=None,
-    must_be_1d=False,
-    allow_scalars=False,
-    name="Array",
-):
+    min_length: int | None = None,
+    max_length: int | None = None,
+    must_be_1d: bool = False,
+    allow_scalar: bool = False,
+    name: str = 'Array',
+) -> None:
     """Check if the length of an array meets specific requirements.
 
     Notes
@@ -981,10 +1110,10 @@ def check_length(
 
     Parameters
     ----------
-    arr : array_like
-        Array to check.
+    sized_input : float | Sized
+        Number or array to check.
 
-    exact_length : int | array_like[int, ...]
+    exact_length : int | VectorLike[int], optional
         Check if the array has the given length. If multiple
         numbers are given, the array's length must match one of the
         numbers.
@@ -999,9 +1128,9 @@ def check_length(
         If ``True``, check if the shape of the array is one-dimensional,
         i.e. that the array's shape is ``(1,)``.
 
-    allow_scalars : bool, default: False
-        If ``True``, a scalar input will be reshaped to have a length of
-        1. Otherwise, the check will fail since a scalar does not
+    allow_scalar : bool, default: False
+        If ``True``, a scalar input will be reshaped to have a length
+        of 1. Otherwise, the check will fail since a scalar does not
         have a length.
 
     name : str, default: "Array"
@@ -1015,6 +1144,7 @@ def check_length(
     See Also
     --------
     check_shape
+    check_ndim
 
     Examples
     --------
@@ -1032,69 +1162,60 @@ def check_length(
     >>> _validation.check_length([[1, 2, 3], [4, 5, 6]], max_length=2)
 
     """
-    if allow_scalars:
+    if allow_scalar:
         # Reshape to 1D
-        if isinstance(arr, np.ndarray) and arr.ndim == 0:
-            arr = [arr.tolist()]
-        elif isinstance(arr, Number):
-            arr = [arr]
-    check_instance(arr, (Sequence, np.ndarray), name=name)
+        if isinstance(sized_input, np.ndarray) and sized_input.ndim == 0:
+            sized_input = [sized_input.tolist()]
+        elif isinstance(sized_input, (float, int)):
+            sized_input = [sized_input]
 
     if must_be_1d:
-        check_shape(arr, shape=(-1))
+        check_shape(sized_input, shape=(-1))  # type: ignore[arg-type]
 
+    array_len = len(sized_input)  # type: ignore[arg-type]
     if exact_length is not None:
-        exact_length = np.array(exact_length)
         check_integer(exact_length, name="'exact_length'")
-        if len(arr) not in exact_length:
-            raise ValueError(
-                f"{name} must have a length equal to any of: {exact_length}. "
-                f"Got length {len(arr)} instead.",
+        if array_len not in np.atleast_1d(exact_length):
+            msg = (
+                f'{name} must have a length equal to any of: {exact_length}. '
+                f'Got length {array_len} instead.'
             )
+            raise ValueError(msg)
 
     # Validate min/max length
     if min_length is not None:
-        min_length = _cast_to_numpy(min_length)
-        check_number(min_length.tolist(), name="Min length")
-        check_real(min_length, name="Min length")
+        check_finite(min_length, name='Min length')
     if max_length is not None:
-        max_length = _cast_to_numpy(max_length)
-        check_number(max_length.tolist(), name="Max length")
-        check_real(max_length, name="Max length")
+        check_finite(max_length, name='Max length')
     if min_length is not None and max_length is not None:
-        check_sorted((min_length, max_length), name="Range")
+        check_sorted((min_length, max_length), name='Range')
 
-    if min_length is not None:
-        if len(arr) < min_length:
-            raise ValueError(
-                f"{name} must have a minimum length of {min_length}. "
-                f"Got length {len(arr)} instead.",
-            )
-    if max_length is not None:
-        if len(arr) > max_length:
-            raise ValueError(
-                f"{name} must have a maximum length of {max_length}. "
-                f"Got length {len(arr)} instead.",
-            )
+    if min_length is not None and array_len < min_length:
+        msg = f'{name} must have a minimum length of {min_length}. Got length {array_len} instead.'
+        raise ValueError(msg)
+    if max_length is not None and array_len > max_length:
+        msg = f'{name} must have a maximum length of {max_length}. Got length {array_len} instead.'
+        raise ValueError(msg)
 
 
-def _validate_shape_value(shape: int | tuple[int, ...] | tuple[None]):
+def _validate_shape_value(shape: _ShapeLike) -> _Shape:
     """Validate shape-like input and return its tuple representation."""
     if shape is None:
         # `None` is used to mean `any shape is allowed` by the array
         #  validation methods, so raise an error here.
         #  Also, setting `None` as a shape is deprecated by NumPy.
-        raise TypeError("`None` is not a valid shape. Use `()` instead.")
+        msg = '`None` is not a valid shape. Use `()` instead.'  # type: ignore[unreachable]
+        raise TypeError(msg)
 
     # Return early for common inputs
     if shape in [(), (-1,), (1,), (3,), (2,), (1, 3), (-1, 3)]:
-        return shape
+        return cast('_Shape', shape)
 
-    def _is_valid_dim(d):
+    def _is_valid_dim(d: Any) -> bool:
         return isinstance(d, int) and d >= -1
 
     if _is_valid_dim(shape):
-        return (shape,)
+        return (cast('int', shape),)
     if isinstance(shape, tuple) and all(map(_is_valid_dim, shape)):
         return shape
 
@@ -1105,5 +1226,6 @@ def _validate_shape_value(shape: int | tuple[int, ...] | tuple[None]):
         shape = (shape,)
     else:
         check_iterable_items(shape, int, name='Shape')
-    check_greater_than(shape, -1, name="Shape", strict=False)
-    raise RuntimeError("This line should not be reachable.")  # pragma: no cover
+    check_greater_than(shape, -1, name='Shape', strict=False)
+    msg = 'This line should not be reachable.'  # pragma: no cover
+    raise RuntimeError(msg)  # pragma: no cover
