@@ -3,32 +3,38 @@
 from __future__ import annotations
 
 from typing import TYPE_CHECKING
-from typing import Tuple
 from typing import cast
 import warnings
 
 import numpy as np
 
 import pyvista
+from pyvista._deprecate_positional_args import _deprecate_positional_args
 
 from . import _vtk_core as _vtk
+from ._typing_core import BoundsTuple
 from .celltype import CellType
-from .dataset import DataObject
+from .dataobject import DataObject
 from .errors import CellSizeError
 from .errors import PyVistaDeprecationWarning
 from .utilities.cells import numpy_to_idarr
+from .utilities.misc import _BoundsSizeMixin
+from .utilities.misc import _NoNewAttrMixin
 
-if TYPE_CHECKING:  # pragma: no cover
-    from typing import Sequence
+if TYPE_CHECKING:
+    from typing import Any
+
+    from typing_extensions import Self
+
+    from pyvista import UnstructuredGrid
 
     from ._typing_core import CellsLike
     from ._typing_core import MatrixLike
     from ._typing_core import NumpyArray
-    from ._typing_core import VectorLike
 
 
-def _get_vtk_id_type():
-    """Return the numpy datatype responding to ``vtk.vtkIdTypeArray``."""
+def _get_vtk_id_type() -> type[np.int32 | np.int64]:
+    """Return the numpy datatype responding to :vtk:`vtkIdTypeArray`."""
     VTK_ID_TYPE_SIZE = _vtk.vtkIdTypeArray().GetDataTypeSize()
     if VTK_ID_TYPE_SIZE == 4:
         return np.int32
@@ -37,8 +43,8 @@ def _get_vtk_id_type():
     return np.int32
 
 
-class Cell(DataObject, _vtk.vtkGenericCell):
-    """Wrapping of vtkCell.
+class Cell(_BoundsSizeMixin, DataObject, _vtk.vtkGenericCell):
+    """Wrapping of :vtk:`vtkCell`.
 
     This class provides the capability to access a given cell topology and can
     be useful when walking through a cell's individual faces or investigating
@@ -46,8 +52,8 @@ class Cell(DataObject, _vtk.vtkGenericCell):
 
     Parameters
     ----------
-    vtk_cell : vtk.vtkCell, optional
-        The vtk object to wrap as Cell, that must be of ``vtk.vtkCell`` type.
+    vtk_cell : :vtk:`vtkCell`, optional
+        The vtk object to wrap as Cell, that must be of :vtk:`vtkCell` type.
 
     cell_type : int, optional
         VTK cell type. Determined from ``vtk_cell`` if not input.
@@ -77,11 +83,11 @@ class Cell(DataObject, _vtk.vtkGenericCell):
       Type:       <CellType.TRIANGLE: 5>
       Linear:     True
       Dimension:  2
-      N Points:	  3
+      N Points:   3
       N Faces:    0
       N Edges:    3
       X Bounds:   -5.406e-02, -5.551e-17
-      Y Bounds:	  0.000e+00, 1.124e-02
+      Y Bounds:   0.000e+00, 1.124e-02
       Z Bounds:   -5.000e-01, -4.971e-01
 
     Get the 0-th cell from a :class:`pyvista.UnstructuredGrid`.
@@ -103,12 +109,19 @@ class Cell(DataObject, _vtk.vtkGenericCell):
 
     """
 
-    def __init__(self, vtk_cell=None, cell_type=None, deep=False):
+    @_deprecate_positional_args(allowed=['vtk_cell', 'cell_type'])
+    def __init__(
+        self: Self,
+        vtk_cell: _vtk.vtkCell | None = None,
+        cell_type: CellType | None = None,
+        deep: bool = False,  # noqa: FBT001, FBT002
+    ) -> None:
         """Initialize the cell."""
         super().__init__()
         if vtk_cell is not None:
             if not isinstance(vtk_cell, _vtk.vtkCell):
-                raise TypeError(f'`vtk_cell` must be a vtkCell, not {type(vtk_cell)}')
+                msg = f'`vtk_cell` must be a vtkCell, not {type(vtk_cell)}'  # type: ignore[unreachable]
+                raise TypeError(msg)
             # cell type must be set first before deep or shallow copy
             if cell_type is None:
                 self.SetCellType(vtk_cell.GetCellType())
@@ -121,7 +134,7 @@ class Cell(DataObject, _vtk.vtkGenericCell):
                 self.ShallowCopy(vtk_cell)
 
     @property
-    def type(self) -> CellType:
+    def type(self: Self) -> CellType:
         """Get the cell type from the enum :class:`pyvista.CellType`.
 
         Returns
@@ -135,11 +148,12 @@ class Cell(DataObject, _vtk.vtkGenericCell):
         >>> mesh = pv.Sphere()
         >>> mesh.get_cell(0).type
         <CellType.TRIANGLE: 5>
+
         """
         return CellType(self.GetCellType())
 
     @property
-    def is_linear(self) -> bool:
+    def is_linear(self: Self) -> bool:
         """Return if the cell is linear.
 
         Returns
@@ -157,7 +171,7 @@ class Cell(DataObject, _vtk.vtkGenericCell):
         """
         return bool(self.IsLinear())
 
-    def plot(self, **kwargs):
+    def plot(self: Self, **kwargs) -> None:
         """Plot this cell.
 
         Parameters
@@ -176,7 +190,7 @@ class Cell(DataObject, _vtk.vtkGenericCell):
         """
         self.cast_to_unstructured_grid().plot(**kwargs)
 
-    def cast_to_polydata(self) -> pyvista.PolyData:
+    def cast_to_polydata(self: Self) -> pyvista.PolyData:
         """Cast this cell to PolyData.
 
         Can only be used for 0D, 1D, or 2D cells.
@@ -214,9 +228,10 @@ class Cell(DataObject, _vtk.vtkGenericCell):
             else:
                 return pyvista.PolyData(self.points.copy(), faces=cells)
         else:
-            raise ValueError(f"3D cells cannot be cast to PolyData: got cell type {self.type}")
+            msg = f'3D cells cannot be cast to PolyData: got cell type {self.type}'
+            raise ValueError(msg)
 
-    def cast_to_unstructured_grid(self) -> pyvista.UnstructuredGrid:
+    def cast_to_unstructured_grid(self: Self) -> UnstructuredGrid:
         """Cast this cell to an unstructured grid.
 
         Returns
@@ -256,7 +271,7 @@ class Cell(DataObject, _vtk.vtkGenericCell):
         )
 
     @property
-    def dimension(self) -> int:
+    def dimension(self: Self) -> int:
         """Return the cell dimension.
 
         This returns the dimensionality of the cell. For example, 1 for an edge,
@@ -273,11 +288,12 @@ class Cell(DataObject, _vtk.vtkGenericCell):
         >>> mesh = pv.Sphere()
         >>> mesh.get_cell(0).dimension
         2
+
         """
         return self.GetCellDimension()
 
     @property
-    def n_points(self) -> int:
+    def n_points(self: Self) -> int:
         """Get the number of points composing the cell.
 
         Returns
@@ -291,11 +307,12 @@ class Cell(DataObject, _vtk.vtkGenericCell):
         >>> mesh = pv.Sphere()
         >>> mesh.get_cell(0).n_points
         3
+
         """
         return self.GetNumberOfPoints()
 
     @property
-    def n_faces(self) -> int:
+    def n_faces(self: Self) -> int:
         """Get the number of faces composing the cell.
 
         Returns
@@ -309,11 +326,12 @@ class Cell(DataObject, _vtk.vtkGenericCell):
         >>> mesh = Tetrahedron()
         >>> mesh.get_cell(0).n_faces
         4
+
         """
         return self.GetNumberOfFaces()
 
     @property
-    def n_edges(self) -> int:
+    def n_edges(self: Self) -> int:
         """Get the number of edges composing the cell.
 
         Returns
@@ -327,11 +345,12 @@ class Cell(DataObject, _vtk.vtkGenericCell):
         >>> mesh = pv.Sphere()
         >>> mesh.get_cell(0).n_edges
         3
+
         """
         return self.GetNumberOfEdges()
 
     @property
-    def point_ids(self) -> list[int]:
+    def point_ids(self: Self) -> list[int]:
         """Get the point IDs composing the cell.
 
         Returns
@@ -345,12 +364,13 @@ class Cell(DataObject, _vtk.vtkGenericCell):
         >>> mesh = pv.Sphere()
         >>> mesh.get_cell(0).point_ids
         [2, 30, 0]
+
         """
         point_ids = self.GetPointIds()
         return [point_ids.GetId(i) for i in range(point_ids.GetNumberOfIds())]
 
     @property
-    def points(self) -> NumpyArray[float]:
+    def points(self: Self) -> NumpyArray[float]:
         """Get the point coordinates of the cell.
 
         Returns
@@ -366,10 +386,11 @@ class Cell(DataObject, _vtk.vtkGenericCell):
         array([[0.05405951, 0.        , 0.49706897],
                [0.05287818, 0.0112396 , 0.49706897],
                [0.        , 0.        , 0.5       ]])
+
         """
         return _vtk.vtk_to_numpy(self.GetPoints().GetData())
 
-    def get_edge(self, index: int) -> Cell:
+    def get_edge(self: Self, index: int) -> Cell:
         """Get the i-th edge composing the cell.
 
         Parameters
@@ -396,14 +417,15 @@ class Cell(DataObject, _vtk.vtkGenericCell):
 
         """
         if index + 1 > self.n_edges:
-            raise IndexError(f'Invalid index {index} for a cell with {self.n_edges} edges.')
+            msg = f'Invalid index {index} for a cell with {self.n_edges} edges.'
+            raise IndexError(msg)
 
         # must deep copy here as multiple sequental calls to GetEdge overwrite
         # the underlying pointer
-        return Cell(self.GetEdge(index), deep=True)
+        return Cell(self.GetEdge(index), deep=True)  # type: ignore[abstract]
 
     @property
-    def edges(self) -> list[Cell]:
+    def edges(self: Self) -> list[Cell]:
         """Return a list of edges composing the cell.
 
         Returns
@@ -424,7 +446,7 @@ class Cell(DataObject, _vtk.vtkGenericCell):
         return [self.get_edge(i) for i in range(self.n_edges)]
 
     @property
-    def faces(self) -> list[Cell]:
+    def faces(self: Self) -> list[Cell]:
         """Return a list of faces composing the cell.
 
         Returns
@@ -444,7 +466,7 @@ class Cell(DataObject, _vtk.vtkGenericCell):
         """
         return [self.get_face(i) for i in range(self.n_faces)]
 
-    def get_face(self, index: int) -> Cell:
+    def get_face(self: Self, index: int) -> Cell:
         """Get the i-th face composing the cell.
 
         Parameters
@@ -471,34 +493,40 @@ class Cell(DataObject, _vtk.vtkGenericCell):
         """
         # must deep copy here as sequental calls overwrite the underlying pointer
         if index + 1 > self.n_faces:
-            raise IndexError(f'Invalid index {index} for a cell with {self.n_faces} faces.')
+            msg = f'Invalid index {index} for a cell with {self.n_faces} faces.'
+            raise IndexError(msg)
 
         # must deep copy here as multiple sequental calls to GetFace overwrite
         # the underlying pointer
         cell = self.GetFace(index)
-        return Cell(cell, deep=True, cell_type=cell.GetCellType())
+        return Cell(cell, deep=True, cell_type=cast('CellType', cell.GetCellType()))  # type: ignore[abstract]
 
     @property
-    def bounds(self) -> tuple[float, float, float, float, float, float]:
-        """Get the cell bounds in ``[xmin, xmax, ymin, ymax, zmin, zmax]``.
+    def bounds(self: Self) -> BoundsTuple:
+        """Get the cell bounds in ``(x_min, x_max, y_min, y_max, z_min, z_max)``.
 
         Returns
         -------
-        tuple[float, float, float, float, float, float]
-            The cell bounds in ``[xmin, xmax, ymin, ymax, zmin, zmax]``.
+        BoundsTuple
+            The cell bounds in ``(x_min, x_max, y_min, y_max, z_min, z_max)``.
 
         Examples
         --------
         >>> import pyvista as pv
         >>> mesh = pv.Sphere()
         >>> mesh.get_cell(0).bounds
-        (0.0, 0.05405950918793678, 0.0, 0.011239604093134403, 0.49706897139549255, 0.5)
+        BoundsTuple(x_min = 0.0,
+                    x_max = 0.05405950918793678,
+                    y_min = 0.0,
+                    y_max = 0.011239604093134403,
+                    z_min = 0.49706897139549255,
+                    z_max = 0.5)
 
         """
-        return self.GetBounds()
+        return BoundsTuple(*self.GetBounds())
 
     @property
-    def center(self) -> tuple[float, float, float]:
+    def center(self: Self) -> tuple[float, float, float]:
         """Get the center of the cell.
 
         Uses parametric coordinate center to determine x-y-z center.
@@ -519,39 +547,40 @@ class Cell(DataObject, _vtk.vtkGenericCell):
         para_center = [0.0, 0.0, 0.0]
         sub_id = self.GetParametricCenter(para_center)
         # EvaluateLocation requires mutable sub_id
-        sub_id = _vtk.mutable(sub_id)
+        sub_id = _vtk.mutable(sub_id)  # type: ignore[assignment]
         # center and weights are returned from EvaluateLocation
         center = [0.0, 0.0, 0.0]
         weights = [0.0] * self.n_points
         self.EvaluateLocation(sub_id, para_center, center, weights)
-        return cast(Tuple[float, float, float], tuple(center))
+        return cast('tuple[float, float, float]', tuple(center))
 
-    def _get_attrs(self):
+    def _get_attrs(self: Self) -> list[tuple[str, Any, str]]:
         """Return the representation methods (internal helper)."""
         attrs = []
-        attrs.append(("Type", repr(self.type), "{}" * len(repr(self.type))))
-        attrs.append(("Linear", self.is_linear, "{}"))
-        attrs.append(("Dimension", self.dimension, "{}"))
-        attrs.append(("N Points", self.n_points, "{}"))
-        attrs.append(("N Faces", self.n_faces, "{}"))
-        attrs.append(("N Edges", self.n_edges, "{}"))
+        attrs.append(('Type', repr(self.type), '{}' * len(repr(self.type))))
+        attrs.append(('Linear', self.is_linear, '{}'))  # type: ignore[arg-type]
+        attrs.append(('Dimension', self.dimension, '{}'))  # type: ignore[arg-type]
+        attrs.append(('N Points', self.n_points, '{}'))  # type: ignore[arg-type]
+        attrs.append(('N Faces', self.n_faces, '{}'))  # type: ignore[arg-type]
+        attrs.append(('N Edges', self.n_edges, '{}'))  # type: ignore[arg-type]
         bds = self.bounds
-        fmt = f"{pyvista.FLOAT_FORMAT}, {pyvista.FLOAT_FORMAT}"
-        attrs.append(("X Bounds", (bds[0], bds[1]), fmt))
-        attrs.append(("Y Bounds", (bds[2], bds[3]), fmt))
-        attrs.append(("Z Bounds", (bds[4], bds[5]), fmt))
+        fmt = f'{pyvista.FLOAT_FORMAT}, {pyvista.FLOAT_FORMAT}'
+        attrs.append(('X Bounds', (bds[0], bds[1]), fmt))  # type: ignore[arg-type]
+        attrs.append(('Y Bounds', (bds[2], bds[3]), fmt))  # type: ignore[arg-type]
+        attrs.append(('Z Bounds', (bds[4], bds[5]), fmt))  # type: ignore[arg-type]
 
         return attrs
 
-    def __repr__(self) -> str:
+    def __repr__(self: Self) -> str:
         """Return the object representation."""
         return self.head(display=False, html=False)
 
-    def __str__(self) -> str:
+    def __str__(self: Self) -> str:
         """Return the object string representation."""
         return self.head(display=False, html=False)
 
-    def copy(self, deep=True) -> Cell:
+    @_deprecate_positional_args
+    def copy(self: Self, deep: bool = True) -> Self:  # noqa: FBT001, FBT002
         """Return a copy of the cell.
 
         Parameters
@@ -589,8 +618,13 @@ class Cell(DataObject, _vtk.vtkGenericCell):
         return type(self)(self, deep=deep)
 
 
-class CellArray(_vtk.vtkCellArray):
-    """PyVista wrapping of vtkCellArray.
+class CellArray(
+    _NoNewAttrMixin,
+    _vtk.DisableVtkSnakeCase,
+    _vtk.vtkPyVistaOverride,
+    _vtk.vtkCellArray,
+):
+    """PyVista wrapping of :vtk:`vtkCellArray`.
 
     Provides convenience functions to simplify creating a CellArray from
     a numpy array or list.
@@ -601,7 +635,7 @@ class CellArray(_vtk.vtkCellArray):
     Parameters
     ----------
     cells : np.ndarray or list, optional
-        Import an array of data with the legacy vtkCellArray layout, e.g.
+        Import an array of data with the legacy :vtk:`vtkCellArray` layout, e.g.
         ``{ n0, p0_0, p0_1, ..., p0_n, n1, p1_0, p1_1, ..., p1_n, ... }``
         Where n0 is the number of points in cell 0, and pX_Y is the Y'th
         point in cell X.
@@ -625,44 +659,47 @@ class CellArray(_vtk.vtkCellArray):
     >>> offsets = [0, 3, 6]
     >>> connectivity = [0, 1, 2, 3, 4, 5]
     >>> cellarr = CellArray.from_arrays(offsets, connectivity)
+
     """
 
+    @_deprecate_positional_args(allowed=['cells'])
     def __init__(
-        self,
+        self: Self,
         cells: CellsLike | None = None,
         n_cells: int | None = None,
-        deep: bool | None = None,
-    ):
-        """Initialize a vtkCellArray."""
+        deep: bool | None = None,  # noqa: FBT001
+    ) -> None:
+        """Initialize a :vtk:`vtkCellArray`."""
         super().__init__()
         self.__offsets: _vtk.vtkIdTypeArray | None = None
         self.__connectivity: _vtk.vtkIdTypeArray | None = None
         if cells is not None:
-            self.cells = cells  # type: ignore[assignment]
+            self.cells = cells
 
         # deprecated 0.44.0, convert to error in 0.47.0, remove 0.48.0
         for k, v in (('n_cells', n_cells), ('deep', deep)):
             if v is not None:
                 warnings.warn(
-                    f"`CellArray parameter `{k}` is deprecated and no longer used.",
+                    f'`CellArray parameter `{k}` is deprecated and no longer used.',
                     PyVistaDeprecationWarning,
                 )
 
     @property
-    def cells(self) -> NumpyArray[int]:
+    def cells(self: Self) -> NumpyArray[int]:
         """Return a numpy array of the cells.
 
         Returns
         -------
         np.ndarray
             A numpy array of the cells.
+
         """
         cells = _vtk.vtkIdTypeArray()
         self.ExportLegacyFormat(cells)
         return _vtk.vtk_to_numpy(cells)
 
     @cells.setter
-    def cells(self, cells: CellsLike):  # numpydoc ignore=GL08
+    def cells(self: Self, cells: CellsLike) -> None:
         cells = np.asarray(cells)
         vtk_idarr = numpy_to_idarr(cells, deep=False, return_ind=False)
         self.ImportLegacyFormat(vtk_idarr)
@@ -670,57 +707,60 @@ class CellArray(_vtk.vtkCellArray):
 
         # https://github.com/pyvista/pyvista/pull/5404
         if imported_size != cells.size:
-            raise CellSizeError(
-                message=(
-                    f"Cell array size is invalid. Size ({cells.size}) does not"
-                    f" match expected size ({imported_size}). This is likely"
-                    " due to invalid connectivity array."
-                ),
+            msg = (
+                f'Cell array size is invalid. Size ({cells.size}) does not'
+                f' match expected size ({imported_size}). This is likely'
+                ' due to invalid connectivity array.'
             )
+            raise CellSizeError(msg)
         self.__offsets = self.__connectivity = None
 
     @property
-    def n_cells(self) -> int:
+    def n_cells(self: Self) -> int:
         """Return the number of cells.
 
         Returns
         -------
         int
             The number of cells.
+
         """
         return self.GetNumberOfCells()
 
     @property
-    def connectivity_array(self) -> NumpyArray[int]:
+    def connectivity_array(self: Self) -> NumpyArray[int]:
         """Return the array with the point ids that define the cells' connectivity.
 
         Returns
         -------
         np.ndarray
             Array with the point ids that define the cells' connectivity.
+
         """
         return _get_connectivity_array(self)
 
     @property
-    def offset_array(self) -> NumpyArray[int]:
+    def offset_array(self: Self) -> NumpyArray[int]:
         """Return the array used to store cell offsets.
 
         Returns
         -------
         np.ndarray
             Array used to store cell offsets.
+
         """
         return _get_offset_array(self)
 
     def _set_data(
-        self,
+        self: Self,
         offsets: MatrixLike[int],
         connectivity: MatrixLike[int],
+        *,
         deep: bool = False,
     ) -> None:
         """Set the offsets and connectivity arrays."""
-        vtk_offsets = cast(_vtk.vtkIdTypeArray, numpy_to_idarr(offsets, deep=deep))
-        vtk_connectivity = cast(_vtk.vtkIdTypeArray, numpy_to_idarr(connectivity, deep=deep))
+        vtk_offsets = numpy_to_idarr(offsets, deep=deep)
+        vtk_connectivity = numpy_to_idarr(connectivity, deep=deep)
         self.SetData(vtk_offsets, vtk_connectivity)
 
         # Because vtkCellArray doesn't take ownership of the arrays, it's possible for them to get
@@ -729,19 +769,20 @@ class CellArray(_vtk.vtkCellArray):
         self.__connectivity = vtk_connectivity
 
     @staticmethod
+    @_deprecate_positional_args(allowed=['offsets', 'connectivity'])
     def from_arrays(
         offsets: MatrixLike[int],
         connectivity: MatrixLike[int],
-        deep: bool = False,
+        deep: bool = False,  # noqa: FBT001, FBT002
     ) -> CellArray:
         """Construct a CellArray from offsets and connectivity arrays.
 
         Parameters
         ----------
-        offsets : IntMatrix
+        offsets : MatrixLike[int]
             Offsets array of length `n_cells + 1`.
 
-        connectivity : IntMatrix
+        connectivity : MatrixLike[int]
             Connectivity array.
 
         deep : bool, default: False
@@ -758,8 +799,8 @@ class CellArray(_vtk.vtkCellArray):
         return cellarr
 
     @property
-    def regular_cells(self) -> NumpyArray[int]:
-        """Return an array of shape (n_cells, cell_size) of point indices when all faces have the same size.
+    def regular_cells(self: Self) -> NumpyArray[int]:
+        """Return a (n_cells, cell_size)-shaped array of point indices for equal-sized faces.
 
         Returns
         -------
@@ -771,17 +812,23 @@ class CellArray(_vtk.vtkCellArray):
         This property does not validate that the cells are all
         actually the same size. If they're not, this property may either
         raise a `ValueError` or silently return an incorrect array.
+
         """
         return _get_regular_cells(self)
 
     @classmethod
-    def from_regular_cells(cls, cells: MatrixLike[int], deep: bool = False) -> pyvista.CellArray:
+    @_deprecate_positional_args(allowed=['cells'])
+    def from_regular_cells(
+        cls: type[CellArray],
+        cells: MatrixLike[int],
+        deep: bool = False,  # noqa: FBT001, FBT002
+    ) -> pyvista.CellArray:
         """Construct a ``CellArray`` from a (n_cells, cell_size) array of cell indices.
 
         Parameters
         ----------
         cells : numpy.ndarray or list[list[int]]
-            Cell array of shape (n_cells, cell_size) where all cells have the same size `cell_size`.
+            Cell array of shape (n_cells, cell_size) where all cells have the same `cell_size`.
 
         deep : bool, default: False
             Whether to deep copy the cell array data into the vtk connectivity array.
@@ -790,6 +837,7 @@ class CellArray(_vtk.vtkCellArray):
         -------
         pyvista.CellArray
             Constructed ``CellArray``.
+
         """
         cells = np.asarray(cells, dtype=pyvista.ID_TYPE)
         n_cells, cell_size = cells.shape
@@ -799,23 +847,24 @@ class CellArray(_vtk.vtkCellArray):
         return cellarr
 
     @classmethod
-    def from_irregular_cells(cls, cells: Sequence[VectorLike[int]]) -> pyvista.CellArray:
+    def from_irregular_cells(cls: type[CellArray], cells: MatrixLike[int]) -> pyvista.CellArray:
         """Construct a ``CellArray`` from a (n_cells, cell_size) array of cell indices.
 
         Parameters
         ----------
         cells : numpy.ndarray or list[list[int]]
-            Cell array of shape (n_cells, cell_size) where all cells have the same size `cell_size`.
+            Cell array of shape (n_cells, cell_size) where all cells have the same `cell_size`.
 
         Returns
         -------
         pyvista.CellArray
             Constructed ``CellArray``.
+
         """
         offsets = np.cumsum([len(c) for c in cells])
         offsets = np.concatenate([[0], offsets], dtype=pyvista.ID_TYPE)
         connectivity = np.concatenate(cells, dtype=pyvista.ID_TYPE)
-        return cls.from_arrays(offsets, connectivity)
+        return cls.from_arrays(offsets, connectivity)  # type: ignore[arg-type]
 
 
 # The following methods would be much nicer bound to CellArray,
@@ -835,7 +884,7 @@ def _get_offset_array(cellarr: _vtk.vtkCellArray) -> NumpyArray[int]:
 
 
 def _get_regular_cells(cellarr: _vtk.vtkCellArray) -> NumpyArray[int]:
-    """Return an array of shape (n_cells, cell_size) of point indices when all faces have the same size."""
+    """Return a (n_cells, cell_size)-shaped array of point indices for equal-sized faces."""
     cells = _get_connectivity_array(cellarr)
     if len(cells) == 0:
         return cells
