@@ -4,29 +4,37 @@ from __future__ import annotations
 
 from collections.abc import Iterable
 from typing import TYPE_CHECKING
+from typing import cast
 
 import numpy as np
 
 from . import _vtk_core as _vtk
 from .utilities.arrays import FieldAssociation
 from .utilities.arrays import convert_array
+from .utilities.misc import _NoNewAttrMixin
+
+if TYPE_CHECKING:
+    from typing import Any
+
+    import numpy.typing as npt
+
+    from pyvista import DataSet
 
-if TYPE_CHECKING:  # pragma: no cover
     from ._typing_core import ArrayLike
     from ._typing_core import NumpyArray
 
 
-class pyvista_ndarray(np.ndarray):  # type: ignore[type-arg]  # numpydoc ignore=PR02
-    """A ndarray which references the owning dataset and the underlying vtkArray.
+class pyvista_ndarray(_NoNewAttrMixin, np.ndarray):  # numpydoc ignore=PR02  # noqa: N801
+    """A ndarray which references the owning dataset and the underlying vtk array.
 
     This array can be acted upon just like a :class:`numpy.ndarray`.
 
     Parameters
     ----------
-    array : Array or vtk.vtkAbstractArray
+    array : ArrayLike or :vtk:`vtkAbstractArray`
         Array like.
 
-    dataset : pyvista.DataSet
+    dataset : DataSet
         Input dataset.
 
     association : pyvista.core.utilities.arrays.FieldAssociation
@@ -50,12 +58,12 @@ class pyvista_ndarray(np.ndarray):  # type: ignore[type-arg]  # numpydoc ignore=
 
     """
 
-    def __new__(
-        cls,
+    def __new__(  # noqa: PYI034
+        cls: type[pyvista_ndarray],
         array: ArrayLike[float] | _vtk.vtkAbstractArray,
-        dataset=None,
-        association=FieldAssociation.NONE,
-    ):
+        dataset: DataSet | _vtk.vtkDataSet | _vtk.VTKObjectWrapper | None = None,
+        association: FieldAssociation = FieldAssociation.NONE,
+    ) -> pyvista_ndarray:
         """Allocate the array."""
         if isinstance(array, _vtk.vtkAbstractArray):
             obj = convert_array(array).view(cls)
@@ -63,20 +71,21 @@ class pyvista_ndarray(np.ndarray):  # type: ignore[type-arg]  # numpydoc ignore=
         elif isinstance(array, Iterable):
             obj = np.asarray(array).view(cls)
         else:
-            raise TypeError(
+            msg = (  # type: ignore[unreachable]
                 f'pyvista_ndarray got an invalid type {type(array)}. '
-                'Expected an Iterable or vtk.vtkAbstractArray',
+                'Expected an Iterable or vtk.vtkAbstractArray'
             )
+            raise TypeError(msg)
 
         obj.association = association
         obj.dataset = _vtk.vtkWeakReference()
         if isinstance(dataset, _vtk.VTKObjectWrapper):
             obj.dataset.Set(dataset.VTKObject)
         else:
-            obj.dataset.Set(dataset)
+            obj.dataset.Set(cast('_vtk.vtkDataSet', dataset))
         return obj
 
-    def __array_finalize__(self, obj):
+    def __array_finalize__(self: pyvista_ndarray, obj: npt.NDArray[Any] | None) -> None:
         """Finalize array (associate with parent metadata)."""
         # this is necessary to ensure that views/slices of pyvista_ndarray
         # objects stay associated with those of their parents.
@@ -85,7 +94,7 @@ class pyvista_ndarray(np.ndarray):  # type: ignore[type-arg]  # numpydoc ignore=
         # to hold this data. I don't know why this class doesn't use the same
         # convention, but here we just map those over to the appropriate
         # attributes of this class
-        _vtk.VTKArray.__array_finalize__(self, obj)
+        _vtk.VTKArray.__array_finalize__(self, obj)  # type: ignore[arg-type]
         if np.shares_memory(self, obj):
             self.dataset = getattr(obj, 'dataset', None)
             self.association = getattr(obj, 'association', FieldAssociation.NONE)
@@ -95,7 +104,7 @@ class pyvista_ndarray(np.ndarray):  # type: ignore[type-arg]  # numpydoc ignore=
             self.association = FieldAssociation.NONE
             self.VTKObject = None
 
-    def __setitem__(self, key: int | NumpyArray[int], value):
+    def __setitem__(self: pyvista_ndarray, key: int | NumpyArray[int], value: Any) -> None:  # type: ignore[override]
         """Implement [] set operator.
 
         When the array is changed it triggers "Modified()" which updates
@@ -111,7 +120,7 @@ class pyvista_ndarray(np.ndarray):  # type: ignore[type-arg]  # numpydoc ignore=
         if dataset is not None and dataset.Get():
             dataset.Get().Modified()
 
-    def __array_wrap__(self, out_arr, context=None, return_scalar=False):
+    def __array_wrap__(self: pyvista_ndarray, out_arr, context=None, return_scalar: bool = False):  # noqa: ANN001, ANN204, FBT001, FBT002
         """Return a numpy scalar if array is 0d.
 
         See https://github.com/numpy/numpy/issues/5819
@@ -123,4 +132,4 @@ class pyvista_ndarray(np.ndarray):  # type: ignore[type-arg]  # numpydoc ignore=
         # Match numpy's behavior and return a numpy dtype scalar
         return out_arr[()]
 
-    __getattr__ = _vtk.VTKArray.__getattr__
+    __getattr__ = _vtk.VTKObjectWrapperCheckSnakeCase.__getattr__
