@@ -3,19 +3,20 @@
 from __future__ import annotations
 
 from typing import TYPE_CHECKING
-from typing import ClassVar
 
+from pyvista._deprecate_positional_args import _deprecate_positional_args
 from pyvista.core import _vtk_core as _vtk
-from pyvista.core.utilities.misc import no_new_attr
+from pyvista.core.utilities.misc import _NoNewAttrMixin
 
 from .helpers import wrap
 
-if TYPE_CHECKING:  # pragma: no cover
-    from typing import Sequence
+if TYPE_CHECKING:
+    from collections.abc import Sequence
 
 
-@no_new_attr
-class ImageEllipsoidSource(_vtk.vtkImageEllipsoidSource):
+class ImageEllipsoidSource(
+    _NoNewAttrMixin, _vtk.DisableVtkSnakeCase, _vtk.vtkImageEllipsoidSource
+):
     """Create a binary image of an ellipsoid class.
 
     .. versionadded:: 0.44.0
@@ -41,7 +42,8 @@ class ImageEllipsoidSource(_vtk.vtkImageEllipsoidSource):
     ...     center=(10, 10, 0),
     ...     radius=(3, 4, 5),
     ... )
-    >>> source.output.plot(cpos="xy")
+    >>> source.output.plot(cpos='xy')
+
     """
 
     def __init__(self, whole_extent=None, center=None, radius=None) -> None:
@@ -61,6 +63,7 @@ class ImageEllipsoidSource(_vtk.vtkImageEllipsoidSource):
         -------
         sequence[int]
             The extent of the whole output image.
+
         """
         return self.GetWholeExtent()
 
@@ -72,17 +75,19 @@ class ImageEllipsoidSource(_vtk.vtkImageEllipsoidSource):
         ----------
         whole_extent : sequence[int]
             The extent of the whole output image.
+
         """
-        self.SetWholeExtent(whole_extent)
+        self.SetWholeExtent(whole_extent)  # type: ignore[call-overload]
 
     @property
-    def center(self) -> Sequence[float]:
+    def center(self) -> tuple[float, float, float]:
         """Get the center of the ellipsoid.
 
         Returns
         -------
-        sequence[float]
+        tuple[float, float, float]
             The center of the ellipsoid.
+
         """
         return self.GetCenter()
 
@@ -94,6 +99,7 @@ class ImageEllipsoidSource(_vtk.vtkImageEllipsoidSource):
         ----------
         center : sequence[float]
             The center of the ellipsoid.
+
         """
         self.SetCenter(center)
 
@@ -105,6 +111,7 @@ class ImageEllipsoidSource(_vtk.vtkImageEllipsoidSource):
         -------
         sequence[float]
             The radius of the ellipsoid.
+
         """
         return self.GetRadius()
 
@@ -116,6 +123,7 @@ class ImageEllipsoidSource(_vtk.vtkImageEllipsoidSource):
         ----------
         radius : sequence[float]
             The radius of the ellipsoid.
+
         """
         self.SetRadius(radius)
 
@@ -127,13 +135,15 @@ class ImageEllipsoidSource(_vtk.vtkImageEllipsoidSource):
         -------
         pyvista.ImageData
             The output image.
+
         """
         self.Update()
         return wrap(self.GetOutput())
 
 
-@no_new_attr
-class ImageMandelbrotSource(_vtk.vtkImageMandelbrotSource):
+class ImageMandelbrotSource(
+    _NoNewAttrMixin, _vtk.DisableVtkSnakeCase, _vtk.vtkImageMandelbrotSource
+):
     """Create an image of the Mandelbrot set.
 
     .. versionadded:: 0.44.0
@@ -155,7 +165,8 @@ class ImageMandelbrotSource(_vtk.vtkImageMandelbrotSource):
     ...     whole_extent=(0, 200, 0, 200, 0, 0),
     ...     maxiter=100,
     ... )
-    >>> source.output.plot(cpos="xy")
+    >>> source.output.plot(cpos='xy')
+
     """
 
     def __init__(self, whole_extent=None, maxiter=None) -> None:
@@ -173,6 +184,7 @@ class ImageMandelbrotSource(_vtk.vtkImageMandelbrotSource):
         -------
         sequence[int]
             The extent of the whole output image.
+
         """
         return self.GetWholeExtent()
 
@@ -184,8 +196,9 @@ class ImageMandelbrotSource(_vtk.vtkImageMandelbrotSource):
         ----------
         whole_extent : sequence[int]
             The extent of the whole output image.
+
         """
-        self.SetWholeExtent(whole_extent)
+        self.SetWholeExtent(whole_extent)  # type: ignore[call-overload]
 
     @property
     def maxiter(self) -> int:
@@ -195,6 +208,7 @@ class ImageMandelbrotSource(_vtk.vtkImageMandelbrotSource):
         -------
         int
             The maximum number of iterations.
+
         """
         return self.GetMaximumNumberOfIterations()
 
@@ -206,6 +220,7 @@ class ImageMandelbrotSource(_vtk.vtkImageMandelbrotSource):
         ----------
         maxiter : int
             The maximum number of iterations.
+
         """
         self.SetMaximumNumberOfIterations(maxiter)
 
@@ -217,13 +232,13 @@ class ImageMandelbrotSource(_vtk.vtkImageMandelbrotSource):
         -------
         pyvista.ImageData
             The output image.
+
         """
         self.Update()
         return wrap(self.GetOutput())
 
 
-@no_new_attr
-class ImageNoiseSource(_vtk.vtkImageNoiseSource):
+class ImageNoiseSource(_NoNewAttrMixin, _vtk.DisableVtkSnakeCase, _vtk.vtkImageNoiseSource):
     """Create an image filled with uniform noise.
 
     .. versionadded:: 0.44.0
@@ -253,12 +268,12 @@ class ImageNoiseSource(_vtk.vtkImageNoiseSource):
     ...     maximum=255,
     ...     seed=0,
     ... )
-    >>> source.output.plot(cpos="xy")
+    >>> source.output.plot(cpos='xy')
+
     """
 
-    _new_attr_exceptions: ClassVar[list[str]] = ['_whole_extent', 'whole_extent']
-
-    def __init__(
+    @_deprecate_positional_args
+    def __init__(  # noqa: PLR0917
         self,
         whole_extent=(0, 255, 0, 255, 0, 0),
         minimum=0.0,
@@ -283,6 +298,7 @@ class ImageNoiseSource(_vtk.vtkImageNoiseSource):
         -------
         sequence[int]
           The extent of the whole output image.
+
         """
         return self._whole_extent
 
@@ -294,6 +310,7 @@ class ImageNoiseSource(_vtk.vtkImageNoiseSource):
         ----------
         whole_extent : sequence[int]
           The extent of the whole output image.
+
         """
         self._whole_extent = whole_extent
         self.SetWholeExtent(whole_extent)
@@ -306,6 +323,7 @@ class ImageNoiseSource(_vtk.vtkImageNoiseSource):
         -------
         float
           The minimum value for the generated noise.
+
         """
         return self.GetMinimum()
 
@@ -317,6 +335,7 @@ class ImageNoiseSource(_vtk.vtkImageNoiseSource):
         ----------
         minimum : float
           The minimum value for the generated noise.
+
         """
         self.SetMinimum(minimum)
 
@@ -328,6 +347,7 @@ class ImageNoiseSource(_vtk.vtkImageNoiseSource):
         -------
         float
           The maximum value for the generated noise.
+
         """
         return self.GetMaximum()
 
@@ -339,6 +359,7 @@ class ImageNoiseSource(_vtk.vtkImageNoiseSource):
         ----------
         maximum : float
           The maximum value for the generated noise.
+
         """
         self.SetMaximum(maximum)
 
@@ -349,6 +370,7 @@ class ImageNoiseSource(_vtk.vtkImageNoiseSource):
         ----------
         value : int
           The seed value for the random number generator to use.
+
         """
         _vtk.vtkMath().RandomSeed(value)
 
@@ -360,13 +382,13 @@ class ImageNoiseSource(_vtk.vtkImageNoiseSource):
         -------
         pyvista.ImageData
           The output image.
+
         """
         self.Update()
         return wrap(self.GetOutput())
 
 
-@no_new_attr
-class ImageSinusoidSource(_vtk.vtkImageSinusoidSource):
+class ImageSinusoidSource(_NoNewAttrMixin, _vtk.DisableVtkSnakeCase, _vtk.vtkImageSinusoidSource):
     """Create an image of a sinusoid.
 
     .. versionadded:: 0.44.0
@@ -400,12 +422,12 @@ class ImageSinusoidSource(_vtk.vtkImageSinusoidSource):
     ...     amplitude=255,
     ...     direction=(1.0, 0.0, 0.0),
     ... )
-    >>> source.output.plot(cpos="xy")
+    >>> source.output.plot(cpos='xy')
+
     """
 
-    _new_attr_exceptions: ClassVar[list[str]] = ['_whole_extent', 'whole_extent']
-
-    def __init__(
+    @_deprecate_positional_args
+    def __init__(  # noqa: PLR0917
         self,
         whole_extent=None,
         direction=None,
@@ -433,6 +455,7 @@ class ImageSinusoidSource(_vtk.vtkImageSinusoidSource):
         -------
         sequence[int]
             The extent of the whole output image.
+
         """
         return self._whole_extent
 
@@ -444,6 +467,7 @@ class ImageSinusoidSource(_vtk.vtkImageSinusoidSource):
         ----------
         whole_extent : sequence[int]
             The extent of the whole output image.
+
         """
         self._whole_extent = whole_extent
         self.SetWholeExtent(
@@ -463,6 +487,7 @@ class ImageSinusoidSource(_vtk.vtkImageSinusoidSource):
         -------
         sequence[float]
             The direction of the sinusoid.
+
         """
         return self.GetDirection()
 
@@ -474,8 +499,9 @@ class ImageSinusoidSource(_vtk.vtkImageSinusoidSource):
         ----------
         direction : sequence[float]
             The direction of the sinusoid.
+
         """
-        self.SetDirection(direction)
+        self.SetDirection(direction)  # type: ignore[call-overload]
 
     @property
     def period(self) -> float:
@@ -485,6 +511,7 @@ class ImageSinusoidSource(_vtk.vtkImageSinusoidSource):
         -------
         float
             The period of the sinusoid in pixel.
+
         """
         return self.GetPeriod()
 
@@ -496,6 +523,7 @@ class ImageSinusoidSource(_vtk.vtkImageSinusoidSource):
         ----------
         period : float
             The period of the sinusoid in pixel.
+
         """
         self.SetPeriod(period)
 
@@ -507,8 +535,9 @@ class ImageSinusoidSource(_vtk.vtkImageSinusoidSource):
         -------
         sequence[float]
             The phase of the sinusoid in pixel.
+
         """
-        return self.GetPhase()
+        return self.GetPhase()  # type: ignore[return-value]
 
     @phase.setter
     def phase(self, phase: Sequence[float]) -> None:
@@ -518,8 +547,9 @@ class ImageSinusoidSource(_vtk.vtkImageSinusoidSource):
         ----------
         phase : sequence[float]
             The phase of the sinusoid in pixel.
+
         """
-        self.SetPhase(phase)
+        self.SetPhase(phase)  # type: ignore[arg-type]
 
     @property
     def amplitude(self) -> float:
@@ -529,6 +559,7 @@ class ImageSinusoidSource(_vtk.vtkImageSinusoidSource):
         -------
         float
             The magnitude of the sinusoid.
+
         """
         return self.GetAmplitude()
 
@@ -540,6 +571,7 @@ class ImageSinusoidSource(_vtk.vtkImageSinusoidSource):
         ----------
         amplitude : float
             The magnitude of the sinusoid.
+
         """
         self.SetAmplitude(amplitude)
 
@@ -551,13 +583,13 @@ class ImageSinusoidSource(_vtk.vtkImageSinusoidSource):
         -------
         pyvista.ImageData
             The output image.
+
         """
         self.Update()
         return wrap(self.GetOutput())
 
 
-@no_new_attr
-class ImageGaussianSource(_vtk.vtkImageGaussianSource):
+class ImageGaussianSource(_NoNewAttrMixin, _vtk.DisableVtkSnakeCase, _vtk.vtkImageGaussianSource):
     """Create a binary image with Gaussian pixel values.
 
     .. versionadded:: 0.44.0
@@ -587,12 +619,14 @@ class ImageGaussianSource(_vtk.vtkImageGaussianSource):
     ...     maximum=255,
     ...     std=100.0,
     ... )
-    >>> source.output.plot(cpos="xy")
+    >>> source.output.plot(cpos='xy')
+
     """
 
-    _new_attr_exceptions: ClassVar[list[str]] = ['_whole_extent', 'whole_extent']
-
-    def __init__(self, center=None, whole_extent=None, maximum=None, std=None) -> None:
+    @_deprecate_positional_args
+    def __init__(  # noqa: PLR0917
+        self, center=None, whole_extent=None, maximum=None, std=None
+    ) -> None:
         super().__init__()
         if center is not None:
             self.center = center
@@ -604,13 +638,14 @@ class ImageGaussianSource(_vtk.vtkImageGaussianSource):
             self.std = std
 
     @property
-    def center(self) -> Sequence[float]:
+    def center(self) -> tuple[float, float, float]:
         """Get the center of the gaussian.
 
         Returns
         -------
-        sequence[float]
+        tuple[float, float, float]
           The center of the gaussian.
+
         """
         return self.GetCenter()
 
@@ -622,6 +657,7 @@ class ImageGaussianSource(_vtk.vtkImageGaussianSource):
         ----------
         center : sequence[float]
           The center of the gaussian.
+
         """
         self.SetCenter(center)
 
@@ -633,6 +669,7 @@ class ImageGaussianSource(_vtk.vtkImageGaussianSource):
         -------
         sequence[int]
           The extent of the whole output image.
+
         """
         return self._whole_extent
 
@@ -644,6 +681,7 @@ class ImageGaussianSource(_vtk.vtkImageGaussianSource):
         ----------
         whole_extent : sequence[int]
           The extent of the whole output image.
+
         """
         self._whole_extent = whole_extent
         self.SetWholeExtent(
@@ -663,6 +701,7 @@ class ImageGaussianSource(_vtk.vtkImageGaussianSource):
         -------
         float
           The maximum value of the gaussian.
+
         """
         return self.GetMaximum()
 
@@ -674,6 +713,7 @@ class ImageGaussianSource(_vtk.vtkImageGaussianSource):
         ----------
         maximum : float
           The maximum value of the gaussian.
+
         """
         self.SetMaximum(maximum)
 
@@ -685,6 +725,7 @@ class ImageGaussianSource(_vtk.vtkImageGaussianSource):
         -------
         float
           The standard deviation of the gaussian.
+
         """
         return self.GetStandardDeviation()
 
@@ -696,6 +737,7 @@ class ImageGaussianSource(_vtk.vtkImageGaussianSource):
         ----------
         std : float
           The standard deviation of the gaussian.
+
         """
         self.SetStandardDeviation(std)
 
@@ -707,13 +749,13 @@ class ImageGaussianSource(_vtk.vtkImageGaussianSource):
         -------
         pyvista.ImageData
           The output image.
+
         """
         self.Update()
         return wrap(self.GetOutput())
 
 
-@no_new_attr
-class ImageGridSource(_vtk.vtkImageGridSource):
+class ImageGridSource(_NoNewAttrMixin, _vtk.DisableVtkSnakeCase, _vtk.vtkImageGridSource):
     """Create an image of a grid.
 
     .. versionadded:: 0.44.0
@@ -738,7 +780,8 @@ class ImageGridSource(_vtk.vtkImageGridSource):
     ...     extent=(0, 20, 0, 20, 0, 0),
     ...     spacing=(1, 1, 1),
     ... )
-    >>> source.output.plot(cpos="xy")
+    >>> source.output.plot(cpos='xy')
+
     """
 
     def __init__(self, origin=None, extent=None, spacing=None) -> None:
@@ -758,6 +801,7 @@ class ImageGridSource(_vtk.vtkImageGridSource):
         -------
         sequence[float]
             The origin of the grid.
+
         """
         return self.GetGridOrigin()
 
@@ -769,8 +813,9 @@ class ImageGridSource(_vtk.vtkImageGridSource):
         ----------
         origin : sequence[float]
             The origin of the grid.
+
         """
-        self.SetGridOrigin(origin)
+        self.SetGridOrigin(origin)  # type: ignore[arg-type]
 
     @property
     def extent(self) -> Sequence[int]:
@@ -780,6 +825,7 @@ class ImageGridSource(_vtk.vtkImageGridSource):
         -------
         sequence[int]
             The extent of the whole output image.
+
         """
         return self.GetDataExtent()
 
@@ -791,6 +837,7 @@ class ImageGridSource(_vtk.vtkImageGridSource):
         ----------
         extent : sequence[int]
             The extent of the whole output image.
+
         """
         self.SetDataExtent(extent)
 
@@ -802,6 +849,7 @@ class ImageGridSource(_vtk.vtkImageGridSource):
         -------
         sequence[float]
             The pixel spacing.
+
         """
         return self.GetDataSpacing()
 
@@ -813,6 +861,7 @@ class ImageGridSource(_vtk.vtkImageGridSource):
         ----------
         spacing : sequence[float]
             The pixel spacing.
+
         """
         self.SetDataSpacing(spacing)
 
@@ -824,6 +873,7 @@ class ImageGridSource(_vtk.vtkImageGridSource):
         -------
         pyvista.ImageData
             The output image.
+
         """
         self.Update()
         return wrap(self.GetOutput())
