@@ -2,6 +2,7 @@
 
 from __future__ import annotations
 
+import importlib.util
 import logging
 from pathlib import Path
 import re
@@ -12,7 +13,9 @@ import traceback
 from typing import NamedTuple
 
 import pyvista
+from pyvista._deprecate_positional_args import _deprecate_positional_args
 from pyvista.core import _vtk_core as _vtk
+from pyvista.core.utilities.misc import _NoNewAttrMixin
 
 
 def set_error_output_file(filename):
@@ -25,9 +28,9 @@ def set_error_output_file(filename):
 
     Returns
     -------
-    vtkFileOutputWindow
+    :vtk:`vtkFileOutputWindow`
         VTK file output window.
-    vtkOutputWindow
+    :vtk:`vtkOutputWindow`
         VTK output window.
 
     """
@@ -61,15 +64,16 @@ class VtkErrorCatcher:
     >>> import pyvista as pv
     >>> with pv.VtkErrorCatcher() as error_catcher:
     ...     sphere = pv.Sphere()
-    ...
+
     """
 
-    def __init__(self, raise_errors=False, send_to_logging=True):
+    @_deprecate_positional_args
+    def __init__(self, raise_errors: bool = False, send_to_logging: bool = True) -> None:  # noqa: FBT001, FBT002
         """Initialize context manager."""
         self.raise_errors = raise_errors
         self.send_to_logging = send_to_logging
 
-    def __enter__(self):
+    def __enter__(self) -> None:
         """Observe VTK string output window for errors."""
         error_output = _vtk.vtkStringOutputWindow()
         error_win = _vtk.vtkOutputWindow()
@@ -98,10 +102,16 @@ class VtkEvent(NamedTuple):
     alert: str
 
 
-class Observer:
+class Observer(_NoNewAttrMixin):
     """A standard class for observing VTK objects."""
 
-    def __init__(self, event_type='ErrorEvent', log=True, store_history=False):
+    @_deprecate_positional_args(allowed=['event_type'])
+    def __init__(
+        self,
+        event_type='ErrorEvent',
+        log: bool = True,  # noqa: FBT001, FBT002
+        store_history: bool = False,  # noqa: FBT001, FBT002
+    ) -> None:
         """Initialize observer."""
         self.__event_occurred = False
         self.__message = None
@@ -112,28 +122,28 @@ class Observer:
         self.__log = log
 
         self.store_history = store_history
-        self.event_history = []
+        self.event_history: list[VtkEvent] = []
 
     @staticmethod
-    def parse_message(message):
+    def parse_message(message):  # numpydoc ignore=RT01
         """Parse the given message."""
         # Message format
         regex = re.compile(r'([A-Z]+):\sIn\s(.+),\sline\s.+\n\w+\s\((.+)\):\s(.+)')
         try:
             kind, path, address, alert = regex.findall(message)[0]
-        except:
+        except Exception:  # noqa: BLE001
             return '', '', '', message
         else:
             return kind, path, address, alert
 
-    def log_message(self, kind, alert):
+    def log_message(self, kind, alert) -> None:
         """Parse different event types and passes them to logging."""
         if kind == 'ERROR':
-            logging.error(alert)
+            logging.error(alert)  # noqa: LOG015
         else:
-            logging.warning(alert)
+            logging.warning(alert)  # noqa: LOG015
 
-    def __call__(self, _obj, _event, message):
+    def __call__(self, _obj, _event, message) -> None:
         """Declare standard call function for the observer.
 
         On an event occurrence, this function executes.
@@ -148,7 +158,7 @@ class Observer:
                 self.event_history.append(VtkEvent(kind, path, address, alert))
             if self.__log:
                 self.log_message(kind, alert)
-        except Exception:  # pragma: no cover
+        except Exception:  # noqa: BLE001  # pragma: no cover
             try:
                 if len(message) > 120:
                     message = f'{message[:100]!r} ... ({len(message)} characters)'
@@ -159,10 +169,10 @@ class Observer:
                     file=sys.__stdout__,
                 )
                 traceback.print_tb(sys.last_traceback, file=sys.__stderr__)
-            except Exception:
+            except Exception:  # noqa: BLE001
                 pass
 
-    def has_event_occurred(self):
+    def has_event_occurred(self):  # numpydoc ignore=RT01
         """Ask self if an error has occurred since last queried.
 
         This resets the observer's status.
@@ -172,12 +182,14 @@ class Observer:
         self.__event_occurred = False
         return occ
 
-    def get_message(self, etc=False):
+    @_deprecate_positional_args
+    def get_message(self, etc: bool = False):  # noqa: FBT001, FBT002
         """Get the last set error message.
 
         Returns
         -------
-            str: the last set error message
+        str
+            The last set error message.
 
         """
         if etc:
@@ -187,14 +199,15 @@ class Observer:
     def observe(self, algorithm):
         """Make this an observer of an algorithm."""
         if self.__observing:
-            raise RuntimeError('This error observer is already observing an algorithm.')
+            msg = 'This error observer is already observing an algorithm.'
+            raise RuntimeError(msg)
         if hasattr(algorithm, 'GetExecutive') and algorithm.GetExecutive() is not None:
             algorithm.GetExecutive().AddObserver(self.event_type, self)
         algorithm.AddObserver(self.event_type, self)
         self.__observing = True
 
 
-def send_errors_to_logging():
+def send_errors_to_logging():  # numpydoc ignore=RT01
     """Send all VTK error/warning messages to Python's logging module."""
     error_output = _vtk.vtkStringOutputWindow()
     error_win = _vtk.vtkOutputWindow()
@@ -203,7 +216,7 @@ def send_errors_to_logging():
     return obs.observe(error_output)
 
 
-class ProgressMonitor:
+class ProgressMonitor(_NoNewAttrMixin):
     """A standard class for monitoring the progress of a VTK algorithm.
 
     This must be use in a ``with`` context and it will block keyboard
@@ -220,12 +233,11 @@ class ProgressMonitor:
 
     """
 
-    def __init__(self, algorithm, message=""):
+    def __init__(self, algorithm, message=''):
         """Initialize observer."""
-        try:
-            from tqdm import tqdm  # noqa: F401
-        except ImportError:
-            raise ImportError("Please install `tqdm` to monitor algorithms.")
+        if not importlib.util.find_spec('tqdm'):
+            msg = 'Please install `tqdm` to monitor algorithms.'
+            raise ImportError(msg)
         self.event_type = _vtk.vtkCommand.ProgressEvent
         self.progress = 0.0
         self._last_progress = self.progress
@@ -236,12 +248,12 @@ class ProgressMonitor:
         self._old_handler = None
         self._progress_bar = None
 
-    def handler(self, sig, frame):
+    def handler(self, sig, frame) -> None:
         """Pass signal to custom interrupt handler."""
-        self._interrupt_signal_received = (sig, frame)
-        logging.debug('SIGINT received. Delaying KeyboardInterrupt until VTK algorithm finishes.')
+        self._interrupt_signal_received = (sig, frame)  # type: ignore[assignment]
+        logging.debug('SIGINT received. Delaying KeyboardInterrupt until VTK algorithm finishes.')  # noqa: LOG015
 
-    def __call__(self, obj, *args):
+    def __call__(self, obj, *args) -> None:  # noqa: ARG002
         """Call progress update callback.
 
         On an event occurrence, this function executes.
@@ -251,12 +263,12 @@ class ProgressMonitor:
         else:
             progress = obj.GetProgress()
             step = progress - self._old_progress
-            self._progress_bar.update(step)
+            self._progress_bar.update(step)  # type: ignore[union-attr]
             self._old_progress = progress
 
     def __enter__(self):
         """Enter event for ``with`` context."""
-        from tqdm import tqdm
+        from tqdm import tqdm  # noqa: PLC0415
 
         # check if in main thread
         if threading.current_thread().__class__.__name__ == '_MainThread':
@@ -270,11 +282,11 @@ class ProgressMonitor:
         self.algorithm.AddObserver(self.event_type, self)
         return self._progress_bar
 
-    def __exit__(self, *args):
+    def __exit__(self, *args) -> None:
         """Exit event for ``with`` context."""
-        self._progress_bar.total = 1
-        self._progress_bar.refresh()
-        self._progress_bar.close()
+        self._progress_bar.total = 1  # type: ignore[union-attr]
+        self._progress_bar.refresh()  # type: ignore[union-attr]
+        self._progress_bar.close()  # type: ignore[union-attr]
         self.algorithm.RemoveObservers(self.event_type)
         if threading.current_thread().__class__.__name__ == '_MainThread':
             signal.signal(signal.SIGINT, self._old_handler)
