@@ -8,6 +8,7 @@ import numpy as np
 
 import pyvista
 from pyvista import examples
+from pyvista._deprecate_positional_args import _deprecate_positional_args
 
 from .logo import text_3d
 
@@ -81,7 +82,7 @@ def plot_glyphs(grid_sz=3, **kwargs):
 
     Returns
     -------
-    various
+    list | np.ndarray | ipywidgets.Widget
         See :func:`show <pyvista.Plotter.show>`.
 
     Examples
@@ -212,11 +213,12 @@ def orientation_plotter():
     pl.add_mesh(ocube['y_n'], color='green')
     pl.add_mesh(ocube['z_p'], color='red')
     pl.add_mesh(ocube['z_n'], color='red')
-    pl.show_axes()
+    pl.show_axes()  # type: ignore[call-arg]
     return pl
 
 
-def plot_wave(fps=30, frequency=1, wavetime=3, notebook=None):
+@_deprecate_positional_args
+def plot_wave(fps=30, frequency=1, wavetime=3, notebook=None):  # noqa: PLR0917
     """Plot a 3D moving wave in a render window.
 
     Parameters
@@ -263,11 +265,11 @@ def plot_wave(fps=30, frequency=1, wavetime=3, notebook=None):
     sgrid = pyvista.StructuredGrid(X, Y, Z)
 
     mesh = sgrid.extract_surface()
-    mesh["Height"] = Z.ravel()
+    mesh['Height'] = Z.ravel()
 
     # Start a plotter object and set the scalars to the Z height
     plotter = pyvista.Plotter(notebook=notebook)
-    plotter.add_mesh(mesh, scalars="Height", show_scalar_bar=False, smooth_shading=True)
+    plotter.add_mesh(mesh, scalars='Height', show_scalar_bar=False, smooth_shading=True)
     plotter.camera_position = cpos
     plotter.show(
         title='Wave Example',
@@ -286,7 +288,7 @@ def plot_wave(fps=30, frequency=1, wavetime=3, notebook=None):
         phase = telap * 2 * np.pi * frequency
         Z = np.sin(R + phase)
         mesh.points[:, -1] = Z.ravel()
-        mesh["Height"] = Z.ravel()
+        mesh['Height'] = Z.ravel()
 
         mesh.compute_normals(inplace=True)
 
@@ -314,7 +316,7 @@ def plot_ants_plane(notebook=None):
 
     This example plots the following:
 
-    .. code:: python
+    .. code-block:: python
 
        >>> import pyvista as pv
        >>> from pyvista import examples
@@ -337,8 +339,8 @@ def plot_ants_plane(notebook=None):
        Create plotting object.
 
        >>> plotter = pv.Plotter()
-       >>> _ = plotter.add_mesh(ant, 'r')
-       >>> _ = plotter.add_mesh(ant_copy, 'b')
+       >>> _ = plotter.add_mesh(ant, color='r')
+       >>> _ = plotter.add_mesh(ant_copy, color='b')
 
        Add airplane mesh and make the color equal to the Y position.
 
@@ -378,8 +380,8 @@ def plot_ants_plane(notebook=None):
 
     # Create plotting object
     plotter = pyvista.Plotter(notebook=notebook)
-    plotter.add_mesh(ant, 'r')
-    plotter.add_mesh(ant_copy, 'b')
+    plotter.add_mesh(ant, color='r')
+    plotter.add_mesh(ant_copy, color='b')
 
     # Add airplane mesh and make the color equal to the Y position
     plane_scalars = airplane.points[:, 1]
@@ -428,7 +430,7 @@ def plot_beam(notebook=None):
         scalars=d,
         scalar_bar_args={'title': 'Y Displacement'},
         rng=[-d.max(), d.max()],
-        cmap=cmap,
+        cmap=cmap,  # type: ignore[arg-type]
     )
     plotter.camera_position = cpos
     plotter.add_text('Static Beam Example')
@@ -470,12 +472,12 @@ def plot_datasets(dataset_type=None):
         'RectilinearGrid',
         'StructuredGrid',
     ]
-    if dataset_type is not None:
-        if dataset_type not in allowable_types:
-            raise ValueError(
-                f'Invalid dataset_type {dataset_type}.  Must be one '
-                f'of the following: {allowable_types}',
-            )
+    if dataset_type is not None and dataset_type not in allowable_types:
+        msg = (
+            f'Invalid dataset_type {dataset_type}.  '
+            f'Must be one of the following: {allowable_types}'
+        )
+        raise ValueError(msg)
 
     ###########################################################################
     # uniform grid
@@ -494,7 +496,7 @@ def plot_datasets(dataset_type=None):
     ang = np.linspace(0, np.pi / 2, 10)
     r = np.linspace(6, 10, 8)
     z = [0]
-    ang, r, z = np.meshgrid(ang, r, z)
+    ang, r, z = np.meshgrid(ang, r, z)  # type: ignore[assignment]
 
     x = r * np.sin(ang)
     y = r * np.cos(ang)
