@@ -28,10 +28,11 @@ downloading, reading, and processing files with a generic mapping:
 
 """
 
-# ruff: noqa: PTH102,PTH103,PTH107,PTH112,PTH113,PTH117,PTH118,PTH119,PTH122,PTH123,PTH202
+# mypy: disable-error-code="redundant-expr"
 from __future__ import annotations
 
 from abc import abstractmethod
+from collections.abc import Sequence
 import functools
 import os
 from pathlib import Path
@@ -39,9 +40,6 @@ from typing import TYPE_CHECKING
 from typing import Any
 from typing import Generic
 from typing import Protocol
-from typing import Sequence
-from typing import Tuple
-from typing import Type
 from typing import TypeVar
 from typing import Union
 from typing import cast
@@ -62,22 +60,22 @@ if TYPE_CHECKING:
 _FilePropStrType_co = TypeVar(
     '_FilePropStrType_co',
     str,
-    Tuple[str, ...],
+    tuple[str, ...],
     covariant=True,
 )
 _FilePropIntType_co = TypeVar(
     '_FilePropIntType_co',
     int,
-    Tuple[int, ...],
+    tuple[int, ...],
     covariant=True,
 )
 
 DatasetObject = Union[pv.DataSet, pv.Texture, NumpyArray[Any], pv.MultiBlock]
 DatasetType = Union[
-    Type[pv.DataSet],
-    Type[pv.Texture],
-    Type[NumpyArray[Any]],
-    Type[pv.MultiBlock],
+    type[pv.DataSet],
+    type[pv.Texture],
+    type[NumpyArray[Any]],
+    type[pv.MultiBlock],
 ]
 
 
@@ -142,7 +140,7 @@ class _SingleFilePropsProtocol(_BaseFilePropsProtocol[str, int]):
 
 
 class _MultiFilePropsProtocol(
-    _BaseFilePropsProtocol[Tuple[str, ...], Tuple[int, ...]],
+    _BaseFilePropsProtocol[tuple[str, ...], tuple[int, ...]],
 ):
     """Define file properties of multiple files."""
 
@@ -171,7 +169,7 @@ class _Downloadable(Protocol[_FilePropStrType_co]):
         name_iter = [name] if isinstance(name, str) else name
         url = self.base_url
         base_url_iter = [url] if isinstance(url, str) else url
-        url_raw = [os.path.join(base_url, name) for base_url, name in zip(base_url_iter, name_iter)]
+        url_raw = list(map(os.path.join, base_url_iter, name_iter))
         return url_raw[0] if isinstance(name, str) else tuple(url_raw)
 
     @property
@@ -242,7 +240,7 @@ class _DatasetLoader:
 
         def _flat(obj):
             if isinstance(obj, Sequence):
-                output_list = []
+                output_list = []  # type: ignore[var-annotated]
                 for item in obj:
                     (
                         output_list.extend(item)
@@ -277,17 +275,20 @@ class _DatasetLoader:
         cell_types: dict[pv.CellType, None] = {}
         for data in self.dataset_iterable:
             # Get the underlying dataset for the texture
-            if isinstance(data, pv.Texture):
-                data = cast(pv.ImageData, pv.wrap(data.GetInput()))
+            dataset = (
+                cast('pv.ImageData', pv.wrap(data.GetInput()))
+                if isinstance(data, pv.Texture)
+                else data
+            )
             try:
-                if isinstance(data, pv.ExplicitStructuredGrid):
+                if isinstance(dataset, pv.ExplicitStructuredGrid):
                     # extract_cells_by_type does not support this datatype
                     # so get cells manually
-                    cells = (c.type for c in data.cell)
+                    cells = (c.type for c in dataset.cell)
                     [cell_types.update({cell_type: None}) for cell_type in cells]
                 else:
                     for cell_type in pv.CellType:
-                        extracted = data.extract_cells_by_type(cell_type)  # type: ignore[union-attr]
+                        extracted = dataset.extract_cells_by_type(cell_type)  # type: ignore[union-attr]
                         if extracted.n_cells > 0:
                             cell_types[cell_type] = None
             except AttributeError:
@@ -299,7 +300,7 @@ class _SingleFile(_SingleFilePropsProtocol):
     """Wrap a single file."""
 
     def __init__(self, path):
-        from pyvista.examples.downloads import USER_DATA_PATH
+        from pyvista.examples.downloads import USER_DATA_PATH  # noqa: PLC0415
 
         self._path = (
             path if path is None or os.path.isabs(path) else os.path.join(USER_DATA_PATH, path)
@@ -389,20 +390,21 @@ class _SingleFileDatasetLoader(_SingleFile, _DatasetLoader):
         load_func = self._load_func
         try:
             # Read and load normally
-            return read_func(path) if load_func is None else load_func(read_func(path))
+            return read_func(path) if load_func is None else load_func(read_func(path))  # type: ignore[misc]
         except OSError:
             # Handle error generated by pv.read if reading a directory
             if read_func is pv.read and Path(path).is_dir():
                 # Re-define read function to read all files in a directory as a multiblock
-                read_func = lambda path: _load_as_multiblock(
+                read_func = lambda path: _load_as_multiblock(  # type: ignore[assignment]
                     [
                         _SingleFileDatasetLoader(str(Path(path, fname)))
-                        for fname in sorted(os.listdir(path))
+                        for fname in sorted(os.listdir(path))  # noqa: PTH208
                     ],
                 )
                 return read_func(path) if load_func is None else load_func(read_func(path))
             else:
-                raise RuntimeError(f'Error loading dataset from path:\n\t{self.path}')
+                msg = f'Error loading dataset from path:\n\t{self.path}'
+                raise RuntimeError(msg)
 
 
 class _DownloadableFile(_SingleFile, _Downloadable[str]):
@@ -422,23 +424,23 @@ class _DownloadableFile(_SingleFile, _Downloadable[str]):
     ):
         _SingleFile.__init__(self, path)
 
-        from pyvista.examples.downloads import SOURCE
-        from pyvista.examples.downloads import USER_DATA_PATH
-        from pyvista.examples.downloads import _download_archive_file_or_folder
-        from pyvista.examples.downloads import download_file
-        from pyvista.examples.downloads import file_from_files
-        from pyvista.examples.examples import dir_path
+        from pyvista.examples.downloads import SOURCE  # noqa: PLC0415
+        from pyvista.examples.downloads import USER_DATA_PATH  # noqa: PLC0415
+        from pyvista.examples.downloads import _download_archive_file_or_folder  # noqa: PLC0415
+        from pyvista.examples.downloads import download_file  # noqa: PLC0415
+        from pyvista.examples.downloads import file_from_files  # noqa: PLC0415
+        from pyvista.examples.examples import dir_path  # noqa: PLC0415
 
         if Path(path).is_absolute():
             # Absolute path must point to a built-in dataset
             assert Path(path).parent == Path(
                 dir_path,
-            ), "Absolute path must point to a built-in dataset."
-            self._base_url = "https://github.com/pyvista/pyvista/raw/main/pyvista/examples/"
+            ), 'Absolute path must point to a built-in dataset.'
+            self._base_url = 'https://github.com/pyvista/pyvista/raw/main/pyvista/examples/'
             self._source_name = Path(path).name
             # the dataset is already downloaded (it's built-in)
             # so make download() simply return the local filepath
-            self._download_func = lambda source: path
+            self._download_func = lambda _: path
         else:
             # Relative path, use vars from downloads.py
             self._base_url = SOURCE
@@ -495,7 +497,7 @@ class _SingleFileDownloadableDatasetLoader(_SingleFileDatasetLoader, _Downloadab
 
     """
 
-    def __init__(
+    def __init__(  # noqa: PLR0917
         self,
         path: str,
         read_func: Callable[[str], DatasetType] | None = None,
@@ -553,7 +555,7 @@ class _MultiFileDatasetLoader(_DatasetLoader, _MultiFilePropsProtocol):
     @property
     def _file_objects(self):
         if self._file_loaders_ is None and not isinstance(self._files_func, str):
-            self._file_loaders_ = self._files_func()
+            self._file_loaders_ = self._files_func()  # type: ignore[assignment]
         return self._file_loaders_
 
     @property
@@ -563,11 +565,7 @@ class _MultiFileDatasetLoader(_DatasetLoader, _MultiFilePropsProtocol):
     @property
     def path_loadable(self) -> tuple[str, ...]:
         return tuple(
-            [
-                file.path
-                for file in self._file_objects
-                if isinstance(file, _SingleFileDatasetLoader)
-            ],
+            file.path for file in self._file_objects if isinstance(file, _SingleFileDatasetLoader)
         )
 
     @property
@@ -578,11 +576,11 @@ class _MultiFileDatasetLoader(_DatasetLoader, _MultiFilePropsProtocol):
 
     @property
     def _filesize_format(self) -> tuple[str, ...]:
-        return tuple([_format_file_size(size) for size in self._filesize_bytes])
+        return tuple(_format_file_size(size) for size in self._filesize_bytes)
 
     @property
     def _total_size_bytes(self) -> int:
-        return sum([file._total_size_bytes for file in self._file_objects])
+        return sum(file._total_size_bytes for file in self._file_objects)
 
     @property
     def total_size(self) -> str:
@@ -607,7 +605,7 @@ class _MultiFileDatasetLoader(_DatasetLoader, _MultiFilePropsProtocol):
 
 class _MultiFileDownloadableDatasetLoader(
     _MultiFileDatasetLoader,
-    _Downloadable[Tuple[str, ...]],
+    _Downloadable[tuple[str, ...]],
 ):
     """Wrap multiple files for downloading and loading."""
 
@@ -645,6 +643,7 @@ def _flatten_nested_sequence(nested: Sequence[_ScalarType | Sequence[_ScalarType
 
 def _download_dataset(
     dataset_loader: _SingleFileDownloadableDatasetLoader | _MultiFileDownloadableDatasetLoader,
+    *,
     load: bool = True,
     metafiles: bool = False,
 ):
@@ -706,17 +705,21 @@ def _load_as_multiblock(
         )
         paths = [Path(path) for path in paths]
         names = [
-            path.name[: -len(get_ext(path.name))] if path.is_file() else path.name for path in paths
+            path.name[: -len(get_ext(path.name))] if path.is_file() else path.name
+            for path in paths
         ]
 
     for file, name in zip(files, names):
         if not isinstance(file, _DatasetLoader):
-            continue
+            continue  # type: ignore[unreachable]
         loaded = file.load()
         assert isinstance(
             loaded,
             (pv.MultiBlock, pv.DataSet),
-        ), f"Only MultiBlock or DataSet objects can be loaded as a MultiBlock. Got {type(loaded)}.'"
+        ), (
+            f'Only MultiBlock or DataSet objects can be loaded as a MultiBlock. '
+            f"Got {type(loaded)}.'"
+        )
         multi.append(loaded, name)
     return multi
 
@@ -764,9 +767,9 @@ def _format_file_size(size: int) -> str:
     size_flt = float(size)
     for unit in ('B', 'KB', 'MB'):
         if round(size_flt * 10) / 10 < 1000.0:
-            return f"{int(size_flt)} {unit}" if unit == 'B' else f"{size_flt:3.1f} {unit}"
+            return f'{int(size_flt)} {unit}' if unit == 'B' else f'{size_flt:3.1f} {unit}'
         size_flt /= 1000.0
-    return f"{size_flt:.1f} GB"
+    return f'{size_flt:.1f} GB'
 
 
 def _get_file_or_folder_ext(path: str):
@@ -780,7 +783,7 @@ def _get_file_or_folder_ext(path: str):
     return ext
 
 
-def _get_all_nested_filepaths(filepath, exclude_readme=True):
+def _get_all_nested_filepaths(filepath, *, exclude_readme=True):
     """Walk through directory and get all file paths.
 
     Optionally exclude any readme files (if any).
