@@ -2,11 +2,13 @@
 
 from __future__ import annotations
 
+from typing import TYPE_CHECKING
 import warnings
 
 import numpy as np
 
 import pyvista
+from pyvista._deprecate_positional_args import _deprecate_positional_args
 from pyvista.core.utilities.arrays import get_array
 from pyvista.core.utilities.misc import assert_empty_kwargs
 
@@ -14,8 +16,14 @@ from .colors import Color
 from .opts import InterpolationType
 from .tools import opacity_transfer_function
 
+if TYPE_CHECKING:
+    from pyvista.core._typing_core import NumpyArray
 
-def prepare_smooth_shading(mesh, scalars, texture, split_sharp_edges, feature_angle, preference):
+
+@_deprecate_positional_args
+def prepare_smooth_shading(  # noqa: PLR0917
+    mesh: pyvista.DataSet, scalars, texture, split_sharp_edges, feature_angle, preference
+) -> tuple[pyvista.PolyData, NumpyArray[float]]:
     """Prepare a dataset for smooth shading.
 
     VTK requires datasets with Phong shading to have active normals.
@@ -89,7 +97,7 @@ def prepare_smooth_shading(mesh, scalars, texture, split_sharp_edges, feature_an
         elif mesh.point_data.active_normals is None:
             mesh.compute_normals(cell_normals=False, inplace=True)
     except TypeError as e:
-        if "Normals cannot be computed" in repr(e):
+        if 'Normals cannot be computed' in repr(e):
             pass
         else:
             raise
@@ -98,10 +106,11 @@ def prepare_smooth_shading(mesh, scalars, texture, split_sharp_edges, feature_an
         ind = mesh[indices_array]
         scalars = np.asarray(scalars)[ind]
 
-    return mesh, scalars
+    return mesh, scalars  # type: ignore[return-value]
 
 
-def process_opacity(mesh, opacity, preference, n_colors, scalars, use_transparency):
+@_deprecate_positional_args
+def process_opacity(mesh, opacity, preference, n_colors, scalars, use_transparency):  # noqa: PLR0917
     """Process opacity.
 
     This function accepts an opacity string or array and always
@@ -150,18 +159,17 @@ def process_opacity(mesh, opacity, preference, n_colors, scalars, use_transparen
             # Get array from mesh
             opacity = get_array(mesh, opacity, preference=preference, err=True)
             if np.any(opacity > 1):
-                warnings.warn("Opacity scalars contain values over 1")
+                warnings.warn('Opacity scalars contain values over 1')
             if np.any(opacity < 0):
-                warnings.warn("Opacity scalars contain values less than 0")
+                warnings.warn('Opacity scalars contain values less than 0')
             custom_opac = True
         except KeyError:
             # Or get opacity transfer function (e.g. "linear")
             opacity = opacity_transfer_function(opacity, n_colors)
         else:
             if scalars.shape[0] != opacity.shape[0]:
-                raise ValueError(
-                    "Opacity array and scalars array must have the same number of elements.",
-                )
+                msg = 'Opacity array and scalars array must have the same number of elements.'
+                raise ValueError(msg)
     elif isinstance(opacity, (np.ndarray, list, tuple)):
         opacity = np.asanyarray(opacity)
         if opacity.shape[0] in [mesh.n_cells, mesh.n_points]:
@@ -180,6 +188,7 @@ def process_opacity(mesh, opacity, preference, n_colors, scalars, use_transparen
 
 
 def _common_arg_parser(
+    *,
     dataset,
     theme,
     n_colors,
@@ -195,7 +204,6 @@ def _common_arg_parser(
     name,
     nan_color,
     nan_opacity,
-    color,
     texture,
     rgb,
     style,
@@ -205,7 +213,7 @@ def _common_arg_parser(
     # supported aliases
     clim = kwargs.pop('rng', clim)
     cmap = kwargs.pop('colormap', cmap)
-    culling = kwargs.pop("backface_culling", culling)
+    culling = kwargs.pop('backface_culling', culling)
     rgb = kwargs.pop('rgba', rgb)
     vertex_color = kwargs.pop('vertex_color', theme.edge_color)
     vertex_style = kwargs.pop('vertex_style', 'points')
@@ -248,9 +256,6 @@ def _common_arg_parser(
 
     nan_color = Color(nan_color, opacity=nan_opacity, default_color=theme.nan_color)
 
-    if color is True:
-        color = theme.color
-
     if texture is False:
         texture = None
 
@@ -264,10 +269,9 @@ def _common_arg_parser(
     else:
         interpolation = theme.lighting_params.interpolation
 
-    if "scalar" in kwargs:
-        raise TypeError(
-            "`scalar` is an invalid keyword argument. Perhaps you mean `scalars` with an s?",
-        )
+    if 'scalar' in kwargs:
+        msg = '`scalar` is an invalid keyword argument. Perhaps you mean `scalars` with an s?'
+        raise TypeError(msg)
 
     assert_empty_kwargs(**kwargs)
     return (
@@ -282,7 +286,6 @@ def _common_arg_parser(
         culling,
         name,
         nan_color,
-        color,
         texture,
         rgb,
         interpolation,
