@@ -1,26 +1,26 @@
-"""Wrap vtkActor module."""
+"""Wrap :vtk:`vtkActor` module."""
 
 from __future__ import annotations
 
 from typing import TYPE_CHECKING
-from typing import ClassVar
 
 import numpy as np
 
 import pyvista
-from pyvista.core.utilities.misc import no_new_attr
+from pyvista._deprecate_positional_args import _deprecate_positional_args
 
 from . import _vtk
 from ._property import Property
 from .prop3d import Prop3D
 
-if TYPE_CHECKING:  # pragma: no cover
+if TYPE_CHECKING:
+    from typing_extensions import Self
+
     from .mapper import _BaseMapper
 
 
-@no_new_attr
 class Actor(Prop3D, _vtk.vtkActor):
-    """Wrap vtkActor.
+    """Wrap :vtk:`vtkActor`.
 
     This class represents the geometry & properties in a rendered
     scene. Normally, a :class:`pyvista.Actor` is constructed from
@@ -83,9 +83,7 @@ class Actor(Prop3D, _vtk.vtkActor):
 
     """
 
-    _new_attr_exceptions: ClassVar[list[str]] = ['_name']
-
-    def __init__(self, mapper=None, prop=None, name=None):
+    def __init__(self, mapper=None, prop=None, name=None) -> None:
         """Initialize actor."""
         super().__init__()
         if mapper is not None:
@@ -96,19 +94,6 @@ class Actor(Prop3D, _vtk.vtkActor):
             self.prop = prop
         self._name = name
 
-    @property
-    def name(self) -> str:  # numpydoc ignore=RT01
-        """Get or set the unique name identifier used by PyVista."""
-        if self._name is None:
-            self._name = f'{type(self).__name__}({self.memory_address})'
-        return self._name
-
-    @name.setter
-    def name(self, value: str):  # numpydoc ignore=GL08
-        if not value:
-            raise ValueError('Name must be truthy.')
-        self._name = value
-
     @property
     def mapper(self) -> _BaseMapper:  # numpydoc ignore=RT01
         """Return or set the mapper of the actor.
@@ -140,10 +125,10 @@ class Actor(Prop3D, _vtk.vtkActor):
           N Arrays:   1
 
         """
-        return self.GetMapper()
+        return self.GetMapper()  # type: ignore[return-value]
 
     @mapper.setter
-    def mapper(self, obj):  # numpydoc ignore=GL08
+    def mapper(self, obj) -> None:
         self.SetMapper(obj)
 
     @property
@@ -165,7 +150,7 @@ class Actor(Prop3D, _vtk.vtkActor):
         return self.GetProperty()
 
     @prop.setter
-    def prop(self, obj: Property):  # numpydoc ignore=GL08
+    def prop(self, obj: Property) -> None:
         self.SetProperty(obj)
 
     @property
@@ -200,13 +185,13 @@ class Actor(Prop3D, _vtk.vtkActor):
         return self.GetTexture()
 
     @texture.setter
-    def texture(self, obj):  # numpydoc ignore=GL08
+    def texture(self, obj) -> None:
         self.SetTexture(obj)
 
     @property
     def memory_address(self):  # numpydoc ignore=RT01
         """Return the memory address of this actor."""
-        return self.GetAddressAsString("")
+        return self.GetAddressAsString('')
 
     @property
     def pickable(self) -> bool:  # numpydoc ignore=RT01
@@ -228,33 +213,103 @@ class Actor(Prop3D, _vtk.vtkActor):
         return bool(self.GetPickable())
 
     @pickable.setter
-    def pickable(self, value):  # numpydoc ignore=GL08
+    def pickable(self, value) -> None:
         self.SetPickable(value)
 
     @property
     def visibility(self) -> bool:  # numpydoc ignore=RT01
         """Return or set actor visibility.
 
+        See Also
+        --------
+        use_bounds
+        pyvista.Plotter.compute_bounds
+
         Examples
         --------
         Create an actor using the :class:`pyvista.Plotter` and then change the
         visibility of the actor.
 
         >>> import pyvista as pv
+        >>> from pyvista import examples
+        >>> mesh = examples.load_airplane()
         >>> pl = pv.Plotter()
-        >>> actor = pl.add_mesh(pv.Sphere())
+        >>> actor = pl.add_mesh(mesh)
+        >>> pl.bounds
+        BoundsTuple(x_min =  139.06100463867188,
+                    x_max = 1654.9300537109375,
+                    y_min =   32.09429931640625,
+                    y_max = 1319.949951171875,
+                    z_min =  -17.741199493408203,
+                    z_max =  282.1300048828125)
+
         >>> actor.visibility = False
-        >>> actor.visibility
-        False
+        >>> pl.bounds
+        BoundsTuple(x_min = -1.0,
+                    x_max =  1.0,
+                    y_min = -1.0,
+                    y_max =  1.0,
+                    z_min = -1.0,
+                    z_max =  1.0)
 
         """
         return bool(self.GetVisibility())
 
     @visibility.setter
-    def visibility(self, value: bool):  # numpydoc ignore=GL08
+    def visibility(self, value: bool) -> None:
         self.SetVisibility(value)
 
-    def plot(self, **kwargs):
+    @property
+    def use_bounds(self) -> bool:  # numpydoc ignore=RT01
+        """Return or set the use of actor's bounds.
+
+        .. versionadded:: 0.45
+
+        See Also
+        --------
+        visibility
+        pyvista.Plotter.compute_bounds
+
+        Examples
+        --------
+        Create an actor using the :class:`pyvista.Plotter` and then change the
+        use of bounds for the actor.
+
+        >>> import pyvista as pv
+        >>> from pyvista import examples
+        >>> mesh = examples.load_airplane()
+        >>> pl = pv.Plotter()
+        >>> actor = pl.add_mesh(mesh)
+        >>> pl.bounds
+        BoundsTuple(x_min =  139.06100463867188,
+                    x_max = 1654.9300537109375,
+                    y_min =   32.09429931640625,
+                    y_max = 1319.949951171875,
+                    z_min =  -17.741199493408203,
+                    z_max =  282.1300048828125)
+
+        >>> actor.use_bounds = False
+        >>> pl.bounds
+        BoundsTuple(x_min = -1.0,
+                    x_max =  1.0,
+                    y_min = -1.0,
+                    y_max =  1.0,
+                    z_min = -1.0,
+                    z_max =  1.0)
+
+        Although the actor's bounds are no longer used, the actor remains visible.
+
+        >>> actor.visibility
+        True
+
+        """
+        return bool(self.GetUseBounds())
+
+    @use_bounds.setter
+    def use_bounds(self, value: bool) -> None:
+        self.SetUseBounds(value)
+
+    def plot(self, **kwargs) -> None:
         """Plot just the actor.
 
         This may be useful when interrogating or debugging individual actors.
@@ -282,7 +337,8 @@ class Actor(Prop3D, _vtk.vtkActor):
         pl.add_actor(self)
         pl.show(**kwargs)
 
-    def copy(self, deep=True) -> Actor:
+    @_deprecate_positional_args
+    def copy(self: Self, deep: bool = True) -> Self:  # noqa: FBT001, FBT002
         """Create a copy of this actor.
 
         Parameters
@@ -294,14 +350,14 @@ class Actor(Prop3D, _vtk.vtkActor):
 
         Returns
         -------
-        pyvista.Actor
+        Actor
             Deep or shallow copy of this actor.
 
         Examples
         --------
-        Create an actor of a cube by adding it to a :class:`pyvista.Plotter`
+        Create an actor of a cube by adding it to a :class:`~pyvista.Plotter`
         and then copy the actor, change the properties, and add it back to the
-        :class:`pyvista.Plotter`.
+        :class:`~pyvista.Plotter`.
 
         >>> import pyvista as pv
         >>> mesh = pv.Cube()
@@ -316,9 +372,10 @@ class Actor(Prop3D, _vtk.vtkActor):
         >>> pl.show()
 
         """
-        new_actor = Actor()
+        new_actor = type(self)()
         if deep:
-            new_actor.mapper = self.mapper.copy()
+            if self.mapper is not None:
+                new_actor.mapper = self.mapper.copy()
             new_actor.prop = self.prop.copy()
         else:
             new_actor.ShallowCopy(self)
@@ -326,10 +383,7 @@ class Actor(Prop3D, _vtk.vtkActor):
 
     def __repr__(self):
         """Representation of the actor."""
-        if self.user_matrix is None or np.array_equal(self.user_matrix, np.eye(4)):
-            mat_info = 'Identity'
-        else:
-            mat_info = 'Set'
+        mat_info = 'Identity' if np.array_equal(self.user_matrix, np.eye(4)) else 'Set'
         bnd = self.bounds
         attr = [
             f'{type(self).__name__} ({hex(id(self))})',
@@ -366,6 +420,10 @@ class Actor(Prop3D, _vtk.vtkActor):
         pyvista.Property
             The object describing backfaces.
 
+        See Also
+        --------
+        :ref:`backface_prop_example`
+
         Examples
         --------
         Clip a sphere by a plane and color the inside of the clipped sphere
@@ -390,8 +448,8 @@ class Actor(Prop3D, _vtk.vtkActor):
         """
         if self.GetBackfaceProperty() is None:
             self.SetBackfaceProperty(self.prop.copy())
-        return self.GetBackfaceProperty()
+        return self.GetBackfaceProperty()  # type: ignore[return-value]
 
     @backface_prop.setter
-    def backface_prop(self, value: pyvista.Property):  # numpydoc ignore=GL08
+    def backface_prop(self, value: pyvista.Property) -> None:
         self.SetBackfaceProperty(value)
