@@ -1,21 +1,23 @@
-"""Module containing pyvista implementation of vtkCamera."""
+"""Module containing pyvista implementation of :vtk:`vtkCamera`."""
 
 from __future__ import annotations
 
 from pathlib import Path
 from weakref import proxy
 import xml.dom.minidom as md
-from xml.etree import ElementTree
+from xml.etree import ElementTree as ET
 
 import numpy as np
 
 import pyvista
+from pyvista._deprecate_positional_args import _deprecate_positional_args
+from pyvista.core.utilities.misc import _NoNewAttrMixin
 
 from . import _vtk
 from .helpers import view_vectors
 
 
-class Camera(_vtk.vtkCamera):
+class Camera(_NoNewAttrMixin, _vtk.DisableVtkSnakeCase, _vtk.vtkCamera):
     """PyVista wrapper for the VTK Camera class.
 
     Parameters
@@ -45,21 +47,17 @@ class Camera(_vtk.vtkCamera):
         self._elevation = 0.0
         self._azimuth = 0.0
         self._is_set = False
+        self._focus = None  # Used by BackgroundRenderer
 
         if renderer:
             if not isinstance(renderer, pyvista.Renderer):
-                raise TypeError(
-                    'Camera only accepts a pyvista.Renderer or None as the ``renderer`` argument',
-                )
+                msg = 'Camera only accepts a pyvista.Renderer or None as the ``renderer`` argument'
+                raise TypeError(msg)
             self._renderer = proxy(renderer)
         else:
-            self._renderer = None
+            self._renderer = None  # type: ignore[assignment]
 
-    def __repr__(self):
-        """Print a repr specifying the id of the camera and its camera type."""
-        return f'<{self.__class__.__name__} at {hex(id(self))}>'
-
-    def __eq__(self, other):
+    def __eq__(self, other) -> bool:
         """Compare whether the relevant attributes of two cameras are equal."""
         # attributes which are native python types and thus implement __eq__
 
@@ -84,16 +82,31 @@ class Camera(_vtk.vtkCamera):
         if trans_count == 1:
             # either but not both are None
             return False
-        if trans_count == 2:
-            if not np.array_equal(this_trans, that_trans):
-                return False
+        return not (trans_count == 2 and not np.array_equal(this_trans, that_trans))
 
-        return True
+    __hash__ = None  # type: ignore[assignment]  # https://github.com/pyvista/pyvista/pull/7671
+
+    def __repr__(self):
+        """Print a repr specifying the id of the camera and its camera type."""
+        repr_str = f'{self.__class__.__name__} ({hex(id(self))})'
+        repr_str += f'\n  Position:            {self.position}'
+        repr_str += f'\n  Focal Point:         {self.focal_point}'
+        repr_str += f'\n  Parallel Projection: {self.parallel_projection}'
+        repr_str += f'\n  Distance:            {self.distance}'
+        repr_str += f'\n  Thickness:           {self.thickness}'
+        repr_str += f'\n  Parallel Scale:      {self.parallel_scale}'
+        repr_str += f'\n  Clipping Range:      {self.clipping_range}'
+        repr_str += f'\n  View Angle:          {self.view_angle}'
+        repr_str += f'\n  Roll:                {self.roll}'
+        return repr_str
+
+    def __str__(self):
+        """Return the object string representation."""
+        return self.__repr__()
 
     def __del__(self):
         """Delete the camera."""
         self.RemoveAllObservers()
-        self.parent = None
 
     @property
     def is_set(self) -> bool:  # numpydoc ignore=RT01
@@ -101,7 +114,7 @@ class Camera(_vtk.vtkCamera):
         return self._is_set
 
     @is_set.setter
-    def is_set(self, value: bool):  # numpydoc ignore=GL08
+    def is_set(self, value: bool):
         self._is_set = bool(value)
 
     @classmethod
@@ -125,43 +138,42 @@ class Camera(_vtk.vtkCamera):
         --------
         >>> import pyvista as pv
         >>> pl = pv.Plotter()
-        >>> pl.camera = pv.Camera.from_paraview_pvcc(
-        ...     "camera.pvcc"
-        ... )  # doctest:+SKIP
+        >>> pl.camera = pv.Camera.from_paraview_pvcc('camera.pvcc')  # doctest:+SKIP
         >>> pl.camera.position
         (1.0, 1.0, 1.0)
+
         """
         to_find = {
-            "CameraPosition": ("position", float),
-            "CameraFocalPoint": ("focal_point", float),
-            "CameraViewAngle": ("view_angle", float),
-            "CameraViewUp": ("up", float),
-            "CameraParallelProjection": ("parallel_projection", int),
-            "CameraParallelScale": ("parallel_scale", float),
+            'CameraPosition': ('position', float),
+            'CameraFocalPoint': ('focal_point', float),
+            'CameraViewAngle': ('view_angle', float),
+            'CameraViewUp': ('up', float),
+            'CameraParallelProjection': ('parallel_projection', int),
+            'CameraParallelScale': ('parallel_scale', float),
         }
         camera = cls()
 
-        tree = ElementTree.parse(filename)
+        tree = ET.parse(filename)
         root = tree.getroot()[0]
         for element in root:
             attrib = element.attrib
-            attrib_name = attrib["name"]
+            attrib_name = attrib['name']
 
             if attrib_name in to_find:
                 name, typ = to_find[attrib_name]
-                nelems = int(attrib["number_of_elements"])
+                nelems = int(attrib['number_of_elements'])
 
                 # Set the camera attributes
                 if nelems == 3:
-                    values = [typ(e.attrib["value"]) for e in element]
+                    values = [typ(e.attrib['value']) for e in element]
                     setattr(camera, name, values)
                 elif nelems == 1:
                     # Special case for bool since bool("0") returns True.
                     # So first convert to int from `to_find` and then apply bool
-                    if "name" in element[-1].attrib and element[-1].attrib["name"] == "bool":
-                        val = bool(typ(element[0].attrib["value"]))
+                    if 'name' in element[-1].attrib and element[-1].attrib['name'] == 'bool':
+                        val = bool(typ(element[0].attrib['value']))
                     else:
-                        val = typ(element[0].attrib["value"])
+                        val = typ(element[0].attrib['value'])
                     setattr(camera, name, val)
 
         camera.is_set = True
@@ -179,60 +191,61 @@ class Camera(_vtk.vtkCamera):
         --------
         >>> import pyvista as pv
         >>> pl = pv.Plotter()
-        >>> pl.camera.to_paraview_pvcc("camera.pvcc")  # doctest:+SKIP
-        """
-        root = ElementTree.Element("PVCameraConfiguration")
-        root.attrib["description"] = "ParaView camera configuration"
-        root.attrib["version"] = "1.0"
+        >>> pl.camera.to_paraview_pvcc('camera.pvcc')  # doctest:+SKIP
 
-        dico = dict(group="views", type="RenderView", id="0", servers="21")
-        proxy = ElementTree.SubElement(root, "Proxy", dico)
+        """
+        root = ET.Element('PVCameraConfiguration')
+        root.attrib['description'] = 'ParaView camera configuration'
+        root.attrib['version'] = '1.0'
+
+        dico = dict(group='views', type='RenderView', id='0', servers='21')
+        proxy = ET.SubElement(root, 'Proxy', dico)
 
         # Add tuples
         to_find = {
-            "CameraPosition": "position",
-            "CameraFocalPoint": "focal_point",
-            "CameraViewUp": "up",
+            'CameraPosition': 'position',
+            'CameraFocalPoint': 'focal_point',
+            'CameraViewUp': 'up',
         }
         for name, attr in to_find.items():
-            e = ElementTree.SubElement(
+            e = ET.SubElement(
                 proxy,
-                "Property",
-                dict(name=name, id=f"0.{name}", number_of_elements="3"),
+                'Property',
+                dict(name=name, id=f'0.{name}', number_of_elements='3'),
             )
 
             for i in range(3):
-                tmp = ElementTree.Element("Element")
-                tmp.attrib["index"] = str(i)
-                tmp.attrib["value"] = str(getattr(self, attr)[i])
+                tmp = ET.Element('Element')
+                tmp.attrib['index'] = str(i)
+                tmp.attrib['value'] = str(getattr(self, attr)[i])
                 e.append(tmp)
 
         # Add single values
         to_find = {
-            "CameraViewAngle": "view_angle",
-            "CameraParallelScale": "parallel_scale",
-            "CameraParallelProjection": "parallel_projection",
+            'CameraViewAngle': 'view_angle',
+            'CameraParallelScale': 'parallel_scale',
+            'CameraParallelProjection': 'parallel_projection',
         }
 
         for name, attr in to_find.items():
-            e = ElementTree.SubElement(
+            e = ET.SubElement(
                 proxy,
-                "Property",
-                dict(name=name, id=f"0.{name}", number_of_elements="1"),
+                'Property',
+                dict(name=name, id=f'0.{name}', number_of_elements='1'),
             )
-            tmp = ElementTree.Element("Element")
-            tmp.attrib["index"] = "0"
+            tmp = ET.Element('Element')
+            tmp.attrib['index'] = '0'
 
             val = getattr(self, attr)
             if not isinstance(val, bool):
-                tmp.attrib["value"] = str(val)
+                tmp.attrib['value'] = str(val)
                 e.append(tmp)
             else:
-                tmp.attrib["value"] = "1" if val else "0"
+                tmp.attrib['value'] = '1' if val else '0'
                 e.append(tmp)
-                e.append(ElementTree.Element("Domain", dict(name="bool", id=f"0.{name}.bool")))
+                e.append(ET.Element('Domain', dict(name='bool', id=f'0.{name}.bool')))
 
-        xmlstr = ElementTree.tostring(root).decode()
+        xmlstr = ET.tostring(root).decode()
         newxml = md.parseString(xmlstr)
         with Path(filename).open('w') as outfile:
             outfile.write(newxml.toprettyxml(indent='\t', newl='\n'))
@@ -255,11 +268,11 @@ class Camera(_vtk.vtkCamera):
         return self.GetPosition()
 
     @position.setter
-    def position(self, value):  # numpydoc ignore=GL08
+    def position(self, value):
         self.SetPosition(value)
         self._elevation = 0.0
         self._azimuth = 0.0
-        if self._renderer:
+        if self._renderer:  # type: ignore[truthy-bool]
             self.reset_clipping_range()
         self.is_set = True
 
@@ -277,9 +290,8 @@ class Camera(_vtk.vtkCamera):
 
         """
         if self._renderer is None:
-            raise AttributeError(
-                'Camera is must be associated with a renderer to reset its clipping range.',
-            )
+            msg = 'Camera is must be associated with a renderer to reset its clipping range.'  # type: ignore[unreachable]
+            raise AttributeError(msg)
         self._renderer.reset_camera_clipping_range()
 
     @property
@@ -295,11 +307,12 @@ class Camera(_vtk.vtkCamera):
         >>> pl.camera.focal_point = (2.0, 0.0, 0.0)
         >>> pl.camera.focal_point
         (2.0, 0.0, 0.0)
+
         """
         return self.GetFocalPoint()
 
     @focal_point.setter
-    def focal_point(self, point):  # numpydoc ignore=GL08
+    def focal_point(self, point):
         self.SetFocalPoint(point)
         self.is_set = True
 
@@ -338,7 +351,7 @@ class Camera(_vtk.vtkCamera):
         return matrix
 
     @model_transform_matrix.setter
-    def model_transform_matrix(self, matrix):  # numpydoc ignore=GL08
+    def model_transform_matrix(self, matrix):
         vtk_matrix = _vtk.vtkMatrix4x4()
         vtk_matrix.DeepCopy(matrix.ravel())
         self.SetModelTransformMatrix(vtk_matrix)
@@ -365,7 +378,7 @@ class Camera(_vtk.vtkCamera):
         return self.GetDistance()
 
     @distance.setter
-    def distance(self, distance):  # numpydoc ignore=GL08
+    def distance(self, distance):
         self.SetDistance(distance)
         self.is_set = True
 
@@ -387,7 +400,7 @@ class Camera(_vtk.vtkCamera):
         return self.GetThickness()
 
     @thickness.setter
-    def thickness(self, length):  # numpydoc ignore=GL08
+    def thickness(self, length):
         self.SetThickness(length)
 
     @property
@@ -408,7 +421,7 @@ class Camera(_vtk.vtkCamera):
         return self.GetParallelScale()
 
     @parallel_scale.setter
-    def parallel_scale(self, scale):  # numpydoc ignore=GL08
+    def parallel_scale(self, scale):
         self.SetParallelScale(scale)
 
     def zoom(self, value):
@@ -454,8 +467,9 @@ class Camera(_vtk.vtkCamera):
 
         """
         if isinstance(value, str):
-            if not value == 'tight':
-                raise ValueError('If a string, ``zoom`` can only be "tight"')
+            if value != 'tight':
+                msg = 'If a string, ``zoom`` can only be "tight"'
+                raise ValueError(msg)
             self.tight()
             return
 
@@ -480,7 +494,7 @@ class Camera(_vtk.vtkCamera):
         return self.GetViewUp()
 
     @up.setter
-    def up(self, vector):  # numpydoc ignore=GL08
+    def up(self, vector):
         self.SetViewUp(vector)
         self.is_set = True
 
@@ -515,6 +529,7 @@ class Camera(_vtk.vtkCamera):
         >>> pl = pv.demos.orientation_plotter()
         >>> pl.disable_parallel_projection()
         >>> pl.show()
+
         """
         self._parallel_projection = False
         self.SetParallelProjection(False)
@@ -531,11 +546,12 @@ class Camera(_vtk.vtkCamera):
         >>> pl.disable_parallel_projection()
         >>> pl.parallel_projection
         False
+
         """
         return self._parallel_projection
 
     @parallel_projection.setter
-    def parallel_projection(self, state):  # numpydoc ignore=GL08
+    def parallel_projection(self, state):
         if state:
             self.enable_parallel_projection()
         else:
@@ -562,9 +578,10 @@ class Camera(_vtk.vtkCamera):
         return self.GetClippingRange()
 
     @clipping_range.setter
-    def clipping_range(self, points):  # numpydoc ignore=GL08
+    def clipping_range(self, points):
         if points[0] > points[1]:
-            raise ValueError('Near point must be lower than the far point.')
+            msg = 'Near point must be lower than the far point.'
+            raise ValueError(msg)
         self.SetClippingRange(points[0], points[1])
 
     @property
@@ -585,7 +602,7 @@ class Camera(_vtk.vtkCamera):
         return self.GetViewAngle()
 
     @view_angle.setter
-    def view_angle(self, value):  # numpydoc ignore=GL08
+    def view_angle(self, value):
         self.SetViewAngle(value)
 
     @property
@@ -627,9 +644,9 @@ class Camera(_vtk.vtkCamera):
 
         """
         frustum_planes = [0] * 24
-        self.GetFrustumPlanes(aspect, frustum_planes)
+        self.GetFrustumPlanes(aspect, frustum_planes)  # type: ignore[arg-type]
         planes = _vtk.vtkPlanes()
-        planes.SetFrustumPlanes(frustum_planes)
+        planes.SetFrustumPlanes(frustum_planes)  # type: ignore[arg-type]
 
         frustum_source = _vtk.vtkFrustumSource()
         frustum_source.ShowLinesOff()
@@ -653,11 +670,12 @@ class Camera(_vtk.vtkCamera):
         >>> pl.camera.roll = 45.0
         >>> pl.camera.roll
         45.0
+
         """
         return self.GetRoll()
 
     @roll.setter
-    def roll(self, angle):  # numpydoc ignore=GL08
+    def roll(self, angle):
         self.SetRoll(angle)
         self.is_set = True
 
@@ -683,7 +701,7 @@ class Camera(_vtk.vtkCamera):
         return self._elevation
 
     @elevation.setter
-    def elevation(self, angle):  # numpydoc ignore=GL08
+    def elevation(self, angle):
         if self._elevation:
             self.Elevation(-self._elevation)
         self._elevation = angle
@@ -713,7 +731,7 @@ class Camera(_vtk.vtkCamera):
         return self._azimuth
 
     @azimuth.setter
-    def azimuth(self, angle):  # numpydoc ignore=GL08
+    def azimuth(self, angle):
         if self._azimuth:
             self.Azimuth(-self._azimuth)
         self._azimuth = angle
@@ -757,6 +775,7 @@ class Camera(_vtk.vtkCamera):
         ... )
         >>> copied_camera == camera
         False
+
         """
         immutable_attrs = [
             'position',
@@ -780,7 +799,14 @@ class Camera(_vtk.vtkCamera):
 
         return new_camera
 
-    def tight(self, padding=0.0, adjust_render_window=True, view='xy', negative=False):
+    @_deprecate_positional_args
+    def tight(  # noqa: PLR0917
+        self,
+        padding=0.0,
+        adjust_render_window: bool = True,  # noqa: FBT001, FBT002
+        view='xy',
+        negative: bool = False,  # noqa: FBT001, FBT002
+    ):
         """Adjust the camera position so that the actors fill the entire renderer.
 
         The camera view direction is reoriented to be normal to the ``view``
@@ -834,7 +860,7 @@ class Camera(_vtk.vtkCamera):
 
         """
         # Inspired by vedo resetCamera. Thanks @marcomusy.
-        x0, x1, y0, y1, z0, z1 = self._renderer.ComputeVisiblePropBounds()
+        x0, x1, y0, y1, z0, z1 = self._renderer.bounds
 
         self.enable_parallel_projection()
 
@@ -846,7 +872,7 @@ class Camera(_vtk.vtkCamera):
         objects_size = position1 - position0
         position = position0 + objects_size / 2
 
-        direction, viewup = view_vectors(view, negative)
+        direction, viewup = view_vectors(view, negative=negative)
         horizontal = np.cross(direction, viewup)
 
         vert_dist = abs(objects_size @ viewup)
