@@ -1,4 +1,4 @@
-"""Module containing pyvista implementation of vtk.vtkLight."""
+"""Module containing pyvista implementation of :vtk:`vtkLight`."""
 
 from __future__ import annotations
 
@@ -12,17 +12,23 @@ try:
     from vtkmodules.vtkRenderingCore import vtkLight
     from vtkmodules.vtkRenderingCore import vtkLightActor
 except ImportError:  # pragma: no cover
-    from vtk import vtkLight
-    from vtk import vtkLightActor
-    from vtk import vtkMatrix4x4
+    from vtk import vtkLight  # type: ignore[no-redef]
+    from vtk import vtkLightActor  # type: ignore[no-redef]
+    from vtk import vtkMatrix4x4  # type: ignore[no-redef]
 
 from typing import TYPE_CHECKING
 
+from pyvista._deprecate_positional_args import _deprecate_positional_args
+from pyvista.core import _validation
+from pyvista.core._vtk_core import DisableVtkSnakeCase
 from pyvista.core.utilities.arrays import vtkmatrix_from_array
+from pyvista.core.utilities.misc import _NoNewAttrMixin
 
 from .colors import Color
 
-if TYPE_CHECKING:  # pragma: no cover
+if TYPE_CHECKING:
+    from pyvista.core._typing_core import TransformLike
+
     from ._typing import ColorLike
 
 
@@ -38,7 +44,7 @@ class LightType(IntEnum):
         return self.name.replace('_', ' ').title()
 
 
-class Light(vtkLight):
+class Light(_NoNewAttrMixin, DisableVtkSnakeCase, vtkLight):
     """Light class.
 
     Parameters
@@ -140,7 +146,8 @@ class Light(vtkLight):
     CAMERA_LIGHT = LightType.CAMERA_LIGHT
     SCENE_LIGHT = LightType.SCENE_LIGHT
 
-    def __init__(
+    @_deprecate_positional_args
+    def __init__(  # noqa: PLR0917
         self,
         position=None,
         focal_point=None,
@@ -149,7 +156,7 @@ class Light(vtkLight):
         intensity=None,
         positional=None,
         cone_angle=None,
-        show_actor=False,
+        show_actor=False,  # noqa: FBT002
         exponent=None,
         shadow_attenuation=None,
         attenuation_values=None,
@@ -188,9 +195,8 @@ class Light(vtkLight):
                 )
                 raise ValueError(msg) from None
         elif not isinstance(light_type, int):
-            raise TypeError(
-                f'Parameter light_type must be int or str, not {type(light_type).__name__}.',
-            )
+            msg = f'Parameter light_type must be int or str, not {type(light_type).__name__}.'
+            raise TypeError(msg)
         # LightType is an int subclass
 
         self.light_type = light_type
@@ -218,11 +224,11 @@ class Light(vtkLight):
         self.actor.SetLight(self)
         self.actor.SetVisibility(show_actor)
 
-    def __repr__(self):
+    def __repr__(self) -> str:
         """Print a repr specifying the id of the light and its light type."""
         return f'<{self.__class__.__name__} ({self.light_type}) at {hex(id(self))}>'
 
-    def __eq__(self, other):
+    def __eq__(self, other) -> bool:
         """Compare whether the relevant attributes of two lights are equal."""
         # attributes which are native python types and thus implement __eq__
         native_attrs = [
@@ -258,6 +264,8 @@ class Light(vtkLight):
                         return False
         return True
 
+    __hash__ = None  # type: ignore[assignment]  # https://github.com/pyvista/pyvista/pull/7671
+
     def __del__(self):
         """Clean up when the light is being destroyed."""
         self.actor = None
@@ -287,7 +295,7 @@ class Light(vtkLight):
         return self.GetShadowAttenuation()
 
     @shadow_attenuation.setter
-    def shadow_attenuation(self, value):  # numpydoc ignore=GL08
+    def shadow_attenuation(self, value):
         self.SetShadowAttenuation(value)
 
     @property
@@ -316,7 +324,7 @@ class Light(vtkLight):
         return Color(self.GetAmbientColor())
 
     @ambient_color.setter
-    def ambient_color(self, color: ColorLike):  # numpydoc ignore=GL08
+    def ambient_color(self, color: ColorLike):
         self.SetAmbientColor(Color(color).float_rgb)
 
     @property
@@ -345,7 +353,7 @@ class Light(vtkLight):
         return Color(self.GetDiffuseColor())
 
     @diffuse_color.setter
-    def diffuse_color(self, color: ColorLike):  # numpydoc ignore=GL08
+    def diffuse_color(self, color: ColorLike):
         self.SetDiffuseColor(Color(color).float_rgb)
 
     @property
@@ -374,7 +382,7 @@ class Light(vtkLight):
         return Color(self.GetSpecularColor())
 
     @specular_color.setter
-    def specular_color(self, color: ColorLike):  # numpydoc ignore=GL08
+    def specular_color(self, color: ColorLike):
         self.SetSpecularColor(Color(color).float_rgb)
 
     @property
@@ -405,7 +413,7 @@ class Light(vtkLight):
         return self.GetPosition()
 
     @position.setter
-    def position(self, pos):  # numpydoc ignore=GL08
+    def position(self, pos):
         self.SetPosition(pos)
 
     @property
@@ -415,7 +423,7 @@ class Light(vtkLight):
         The world space position is the :py:attr:`position` property
         transformed by the light's transform matrix if it exists. The
         value of this read-only property corresponds to the
-        ``vtk.vtkLight.GetTransformedPosition()`` method.
+        :vtk:`vtkLight.GetTransformedPosition` method.
 
         Examples
         --------
@@ -459,7 +467,7 @@ class Light(vtkLight):
         return self.GetFocalPoint()
 
     @focal_point.setter
-    def focal_point(self, pos):  # numpydoc ignore=GL08
+    def focal_point(self, pos):
         self.SetFocalPoint(pos)
 
     @property
@@ -469,7 +477,7 @@ class Light(vtkLight):
         The world space focal point is the :py:attr:`focal_point`
         property transformed by the light's transform matrix if it
         exists. The value of this read-only property corresponds to
-        the ``vtk.vtkLight.GetTransformedFocalPoint()`` method.
+        the :vtk:`vtkLight.GetTransformedFocalPoint` method.
 
         Examples
         --------
@@ -505,31 +513,26 @@ class Light(vtkLight):
         >>> import pyvista as pv
         >>> plotter = pv.Plotter(lighting='none')
         >>> _ = plotter.add_mesh(pv.Cube(), color='cyan')
-        >>> light_bright = pv.Light(
-        ...     position=(3, 0, 0), light_type='scene light'
-        ... )
-        >>> light_dim = pv.Light(
-        ...     position=(0, 3, 0), light_type='scene light'
-        ... )
+        >>> light_bright = pv.Light(position=(3, 0, 0), light_type='scene light')
+        >>> light_dim = pv.Light(position=(0, 3, 0), light_type='scene light')
         >>> light_dim.intensity = 0.5
         >>> for light in light_bright, light_dim:
         ...     light.positional = True
         ...     plotter.add_light(light)
-        ...
         >>> plotter.show()
 
         """
         return self.GetIntensity()
 
     @intensity.setter
-    def intensity(self, intensity):  # numpydoc ignore=GL08
+    def intensity(self, intensity):
         self.SetIntensity(intensity)
 
     @property
     def on(self):  # numpydoc ignore=RT01
         """Return or set whether the light is on.
 
-        This corresponds to the Switch state of the ``vtk.vtkLight`` class.
+        This corresponds to the Switch state of the :vtk:`vtkLight` class.
 
         Examples
         --------
@@ -545,7 +548,7 @@ class Light(vtkLight):
         return bool(self.GetSwitch())
 
     @on.setter
-    def on(self, state):  # numpydoc ignore=GL08
+    def on(self, state):
         self.SetSwitch(state)
 
     @property
@@ -580,7 +583,7 @@ class Light(vtkLight):
         return bool(self.GetPositional())
 
     @positional.setter
-    def positional(self, state):  # numpydoc ignore=GL08
+    def positional(self, state):
         if not state:
             self.hide_actor()
         self.SetPositional(state)
@@ -598,16 +601,15 @@ class Light(vtkLight):
             return
 
         actor_state = self.cone_angle < 90 and self.positional
-        actor_name = self.actor.GetAddressAsString("")
+        actor_name = self.actor.GetAddressAsString('')
 
         # add or remove the actor from the renderer
         for renderer in self._renderers:
             if actor_state:
                 if actor_name not in renderer.actors:
                     renderer.add_actor(self.actor, render=False)
-            else:
-                if actor_name in renderer.actors:
-                    renderer.remove_actor(self.actor, render=False)
+            elif actor_name in renderer.actors:
+                renderer.remove_actor(self.actor, render=False)
 
     @property
     def exponent(self):  # numpydoc ignore=RT01
@@ -638,9 +640,7 @@ class Light(vtkLight):
         >>> import pyvista as pv
         >>> plotter = pv.Plotter(lighting='none')
         >>> for offset, exponent in zip([0, 1.5, 3], [1, 2, 5]):
-        ...     _ = plotter.add_mesh(
-        ...         pv.Plane((offset, 0, 0)), color='white'
-        ...     )
+        ...     _ = plotter.add_mesh(pv.Plane(center=(offset, 0, 0)), color='white')
         ...     light = pv.Light(
         ...         position=(offset, 0, 0.1),
         ...         focal_point=(offset, 0, 0),
@@ -649,7 +649,6 @@ class Light(vtkLight):
         ...     light.positional = True
         ...     light.cone_angle = 80
         ...     plotter.add_light(light)
-        ...
         >>> plotter.view_xy()
         >>> plotter.show()
 
@@ -657,7 +656,7 @@ class Light(vtkLight):
         return self.GetExponent()
 
     @exponent.setter
-    def exponent(self, exp):  # numpydoc ignore=GL08
+    def exponent(self, exp):
         self.SetExponent(exp)
 
     @property
@@ -677,6 +676,10 @@ class Light(vtkLight):
         If the light's cone angle is increased to 90 degrees or above,
         its actor (if previously shown) is automatically hidden.
 
+        See Also
+        --------
+        :ref:`beam_shape_example`
+
         Examples
         --------
         Plot three planes lit by three spotlights with varying cone
@@ -686,17 +689,12 @@ class Light(vtkLight):
         >>> import pyvista as pv
         >>> plotter = pv.Plotter(lighting='none')
         >>> for offset, angle in zip([0, 1.5, 3], [70, 30, 20]):
-        ...     _ = plotter.add_mesh(
-        ...         pv.Plane((offset, 0, 0)), color='white'
-        ...     )
-        ...     light = pv.Light(
-        ...         position=(offset, 0, 1), focal_point=(offset, 0, 0)
-        ...     )
+        ...     _ = plotter.add_mesh(pv.Plane(center=(offset, 0, 0)), color='white')
+        ...     light = pv.Light(position=(offset, 0, 1), focal_point=(offset, 0, 0))
         ...     light.exponent = 15
         ...     light.positional = True
         ...     light.cone_angle = angle
         ...     plotter.add_light(light)
-        ...
         >>> plotter.view_xy()
         >>> plotter.show()
 
@@ -704,7 +702,7 @@ class Light(vtkLight):
         return self.GetConeAngle()
 
     @cone_angle.setter
-    def cone_angle(self, angle):  # numpydoc ignore=GL08
+    def cone_angle(self, angle):
         if angle >= 90:
             self.hide_actor()
         self.SetConeAngle(angle)
@@ -724,6 +722,10 @@ class Light(vtkLight):
         distance. A larger attenuation constant corresponds to more
         rapid decay with distance.
 
+        See Also
+        --------
+        :ref:`attenuation_example`
+
         Examples
         --------
         Plot three cubes lit by two lights with different attenuation
@@ -738,7 +740,6 @@ class Light(vtkLight):
         ...     _ = plotter.add_mesh(
         ...         pv.Cube(center=(offset, offset, 0)), color='white'
         ...     )
-        ...
         >>> colors = ['b', 'g']
         >>> all_attenuations = [(0, 0.1, 0), (0, 0, 0.1)]
         >>> centers = [(0, 1, 0), (1, 0, 0)]
@@ -758,7 +759,7 @@ class Light(vtkLight):
         return self.GetAttenuationValues()
 
     @attenuation_values.setter
-    def attenuation_values(self, values):  # numpydoc ignore=GL08
+    def attenuation_values(self, values):
         self.SetAttenuationValues(values)
 
     @property
@@ -766,7 +767,7 @@ class Light(vtkLight):
         """Return (if any) or set the transformation matrix of the light.
 
         The transformation matrix is ``None`` by default, and it is
-        stored as a ``vtk.vtkMatrix4x4`` object when set. If set, the
+        stored as a :vtk:`vtkMatrix4x4` object when set. If set, the
         light's parameters (position and focal point) are transformed
         by the matrix before being rendered. See also the
         :py:attr:`world_position` and :py:attr:`world_focal_point`
@@ -805,17 +806,12 @@ class Light(vtkLight):
         return self.GetTransformMatrix()
 
     @transform_matrix.setter
-    def transform_matrix(self, matrix):  # numpydoc ignore=GL08
+    def transform_matrix(self, matrix: TransformLike):
         if matrix is None or isinstance(matrix, vtkMatrix4x4):
-            trans = matrix
+            self.SetTransformMatrix(matrix)
         else:
-            try:
-                trans = vtkmatrix_from_array(matrix)
-            except ValueError:
-                raise ValueError(
-                    'Transformation matrix must be a 4-by-4 matrix or array-like.',
-                ) from None
-        self.SetTransformMatrix(trans)
+            trans = _validation.validate_transform4x4(matrix)
+            self.SetTransformMatrix(vtkmatrix_from_array(trans))
 
     @property
     def light_type(self):  # numpydoc ignore=RT01
@@ -871,12 +867,11 @@ class Light(vtkLight):
         return LightType(self.GetLightType())
 
     @light_type.setter
-    def light_type(self, ltype):  # numpydoc ignore=GL08
+    def light_type(self, ltype):
         if not isinstance(ltype, int):
             # note that LightType is an int subclass
-            raise TypeError(
-                f'Light type must be an integer subclass instance, got {ltype} instead.',
-            )
+            msg = f'Light type must be an integer subclass instance, got {ltype} instead.'
+            raise TypeError(msg)
         self.SetLightType(ltype)
 
     @property
@@ -968,7 +963,7 @@ class Light(vtkLight):
         focal point is set to the origin. The position is defined in
         terms of an elevation and an azimuthal angle, both in degrees.
 
-        Note that the equivalent ``vtk.vtkLight.SetDirectionAngle()`` method
+        Note that the equivalent :vtk:`vtkLight.SetDirectionAngle` method
         uses a surprising coordinate system where the (x', y', z') axes of
         the method correspond to the (z, x, y) axes of the renderer.
         This method reimplements the functionality in a way that ``elev``
@@ -1003,7 +998,8 @@ class Light(vtkLight):
         phi = np.radians(azim)
         self.position = (np.sin(theta) * np.cos(phi), np.sin(theta) * np.sin(phi), np.cos(theta))
 
-    def copy(self, deep=True):
+    @_deprecate_positional_args
+    def copy(self, deep=True):  # noqa: FBT002
         """Return a shallow or a deep copy of the light.
 
         The only mutable attribute of :class:`pyvista.Light` is the
@@ -1070,7 +1066,7 @@ class Light(vtkLight):
             new_light.transform_matrix = self.transform_matrix
 
         # light actors are private, always copy, but copy visibility state as well
-        new_light.actor.SetVisibility(self.actor.GetVisibility())
+        new_light.actor.SetVisibility(self.actor.GetVisibility())  # type: ignore[union-attr]
 
         return new_light
 
@@ -1134,12 +1130,12 @@ class Light(vtkLight):
 
     @classmethod
     def from_vtk(cls, vtk_light):
-        """Create a light from a ``vtk.vtkLight``, resulting in a copy.
+        """Create a light from a :vtk:`vtkLight`, resulting in a copy.
 
         Parameters
         ----------
-        vtk_light : vtk.vtkLight
-            The ``vtk.vtkLight`` to be copied.
+        vtk_light : :vtk:`vtkLight`
+            The :vtk:`vtkLight` to be copied.
 
         Returns
         -------
@@ -1148,9 +1144,8 @@ class Light(vtkLight):
 
         """
         if not isinstance(vtk_light, vtkLight):
-            raise TypeError(
-                f'Expected vtk.vtkLight object, got {type(vtk_light).__name__} instead.',
-            )
+            msg = f'Expected vtk.vtkLight object, got {type(vtk_light).__name__} instead.'
+            raise TypeError(msg)
 
         light = cls()
         light.light_type = vtk_light.GetLightType()  # resets transformation matrix
@@ -1190,7 +1185,6 @@ class Light(vtkLight):
         >>> _ = plotter.add_mesh(pv.Cube(), color='white')
         >>> for light in plotter.renderer.lights:
         ...     light.intensity /= 5
-        ...
         >>> spotlight = pv.Light(position=(-1, 1, 1), color='cyan')
         >>> spotlight.positional = True
         >>> spotlight.cone_angle = 20
@@ -1203,7 +1197,7 @@ class Light(vtkLight):
         """
         if not self.positional or self.cone_angle >= 90:
             return
-        self.actor.VisibilityOn()
+        self.actor.VisibilityOn()  # type: ignore[union-attr]
 
     def hide_actor(self):
         """Hide the actor for a positional light that depicts the geometry of the beam.
@@ -1219,7 +1213,7 @@ class Light(vtkLight):
         """
         if not self.positional:
             return
-        self.actor.VisibilityOff()
+        self.actor.VisibilityOff()  # type: ignore[union-attr]
 
     @property
     def renderers(self):  # numpydoc ignore=RT01
@@ -1231,7 +1225,7 @@ class Light(vtkLight):
 
         Parameters
         ----------
-        renderer : vtk.vtkRenderer
+        renderer : :vtk:`vtkRenderer`
             Renderer.
 
         """
