@@ -2,25 +2,38 @@
 
 from __future__ import annotations
 
+from abc import ABC
+from abc import abstractmethod
+from functools import wraps
 from typing import TYPE_CHECKING
+from typing import Literal
 
 import numpy as np
 
+from pyvista._deprecate_positional_args import _deprecate_positional_args
 from pyvista.core import _validation
-from pyvista.core.utilities.arrays import _coerce_transformlike_arg
+from pyvista.core._typing_core import BoundsTuple
 from pyvista.core.utilities.arrays import array_from_vtkmatrix
 from pyvista.core.utilities.arrays import vtkmatrix_from_array
+from pyvista.core.utilities.misc import _BoundsSizeMixin
+from pyvista.core.utilities.misc import _NameMixin
+from pyvista.core.utilities.misc import _NoNewAttrMixin
+from pyvista.core.utilities.transform import Transform
 from pyvista.plotting import _vtk
 
-if TYPE_CHECKING:  # pragma: no cover
-    from pyvista.core._typing_core import BoundsLike
+if TYPE_CHECKING:
+    from typing_extensions import Self
+
     from pyvista.core._typing_core import NumpyArray
+    from pyvista.core._typing_core import RotationLike
     from pyvista.core._typing_core import TransformLike
     from pyvista.core._typing_core import VectorLike
 
 
-class Prop3D(_vtk.vtkProp3D):
-    """Prop3D wrapper for vtkProp3D.
+class Prop3D(
+    _NoNewAttrMixin, _NameMixin, _BoundsSizeMixin, _vtk.DisableVtkSnakeCase, _vtk.vtkProp3D
+):
+    """Prop3D wrapper for :vtk:`vtkProp3D`.
 
     Used to represent an entity in a rendering scene. It provides spatial
     properties and methods relating to an entity's position, orientation
@@ -38,7 +51,7 @@ class Prop3D(_vtk.vtkProp3D):
 
     """
 
-    def __init__(self):
+    def __init__(self) -> None:
         """Initialize Prop3D."""
         super().__init__()
 
@@ -62,8 +75,8 @@ class Prop3D(_vtk.vtkProp3D):
         return self.GetScale()
 
     @scale.setter
-    def scale(self, value: VectorLike[float]):  # numpydoc ignore=GL08
-        self.SetScale(value)
+    def scale(self, value: float | VectorLike[float]) -> None:
+        self.SetScale(value)  # type: ignore[arg-type]
 
     @property
     def position(self) -> tuple[float, float, float]:  # numpydoc ignore=RT01
@@ -87,10 +100,10 @@ class Prop3D(_vtk.vtkProp3D):
         return self.GetPosition()
 
     @position.setter
-    def position(self, value: VectorLike[float]):  # numpydoc ignore=GL08
-        self.SetPosition(value)
+    def position(self, value: VectorLike[float]) -> None:
+        self.SetPosition(value)  # type: ignore[call-overload]
 
-    def rotate_x(self, angle: float):
+    def rotate_x(self, angle: float) -> None:
         """Rotate the entity about the x-axis.
 
         Parameters
@@ -121,7 +134,7 @@ class Prop3D(_vtk.vtkProp3D):
         """
         self.RotateX(angle)
 
-    def rotate_y(self, angle: float):
+    def rotate_y(self, angle: float) -> None:
         """Rotate the entity about the y-axis.
 
         Parameters
@@ -152,7 +165,7 @@ class Prop3D(_vtk.vtkProp3D):
         """
         self.RotateY(angle)
 
-    def rotate_z(self, angle: float):
+    def rotate_z(self, angle: float) -> None:
         """Rotate the entity about the z-axis.
 
         Parameters
@@ -195,6 +208,11 @@ class Prop3D(_vtk.vtkProp3D):
 
         Rotations are applied about the specified :attr:`~origin`.
 
+        See Also
+        --------
+        rotation_from
+            Alternative method for setting the :attr:`orientation`.
+
         Examples
         --------
         Reorient just the actor and plot it. Note how the actor is rotated
@@ -254,8 +272,8 @@ class Prop3D(_vtk.vtkProp3D):
         return self.GetOrientation()
 
     @orientation.setter
-    def orientation(self, value: tuple[float, float, float]):  # numpydoc ignore=GL08
-        self.SetOrientation(value)
+    def orientation(self, value: VectorLike[float]) -> None:
+        self.SetOrientation(value)  # type: ignore[call-overload]
 
     @property
     def origin(self) -> tuple[float, float, float]:  # numpydoc ignore=RT01
@@ -269,14 +287,14 @@ class Prop3D(_vtk.vtkProp3D):
         return self.GetOrigin()
 
     @origin.setter
-    def origin(self, value: VectorLike[float]):  # numpydoc ignore=GL08
-        self.SetOrigin(value)
+    def origin(self, value: VectorLike[float]) -> None:
+        self.SetOrigin(value)  # type: ignore[arg-type]
 
     @property
-    def bounds(self) -> BoundsLike:  # numpydoc ignore=RT01
+    def bounds(self) -> BoundsTuple:  # numpydoc ignore=RT01
         """Return the bounds of the entity.
 
-        Bounds are ``(-X, +X, -Y, +Y, -Z, +Z)``
+        Bounds are ``(x_min, x_max, y_min, y_max, z_min, z_max)``
 
         Examples
         --------
@@ -285,10 +303,15 @@ class Prop3D(_vtk.vtkProp3D):
         >>> mesh = pv.Cube(x_length=0.1, y_length=0.2, z_length=0.3)
         >>> actor = pl.add_mesh(mesh)
         >>> actor.bounds
-        (-0.05, 0.05, -0.1, 0.1, -0.15, 0.15)
+        BoundsTuple(x_min = -0.05,
+                    x_max =  0.05,
+                    y_min = -0.1,
+                    y_max =  0.1,
+                    z_min = -0.15,
+                    z_max =  0.15)
 
         """
-        return self.GetBounds()
+        return BoundsTuple(*self.GetBounds())
 
     @property
     def center(self) -> tuple[float, float, float]:  # numpydoc ignore=RT01
@@ -301,6 +324,7 @@ class Prop3D(_vtk.vtkProp3D):
         >>> actor = pl.add_mesh(pv.Sphere(center=(0.5, 0.5, 1)))
         >>> actor.center  # doctest:+SKIP
         (0.5, 0.5, 1)
+
         """
         return self.GetCenter()
 
@@ -318,6 +342,11 @@ class Prop3D(_vtk.vtkProp3D):
         The user matrix is the last transformation applied to the actor before
         rendering.
 
+        See Also
+        --------
+        transform
+            Apply a transformation to the :attr:`user_matrix`.
+
         Returns
         -------
         np.ndarray
@@ -330,26 +359,23 @@ class Prop3D(_vtk.vtkProp3D):
         rotates the actor about the z-axis by approximately 45 degrees, and
         shrinks the actor by a factor of 0.5.
 
-        >>> import numpy as np
         >>> import pyvista as pv
         >>> mesh = pv.Cube()
         >>> pl = pv.Plotter()
-        >>> _ = pl.add_mesh(mesh, color="b")
+        >>> _ = pl.add_mesh(mesh, color='b')
         >>> actor = pl.add_mesh(
         ...     mesh,
-        ...     color="r",
-        ...     style="wireframe",
+        ...     color='r',
+        ...     style='wireframe',
         ...     line_width=5,
         ...     lighting=False,
         ... )
-        >>> arr = np.array(
-        ...     [
-        ...         [0.707, -0.707, 0, 0],
-        ...         [0.707, 0.707, 0, 0],
-        ...         [0, 0, 1, 1.500001],
-        ...         [0, 0, 0, 2],
-        ...     ]
-        ... )
+        >>> arr = [
+        ...     [0.707, -0.707, 0, 0],
+        ...     [0.707, 0.707, 0, 0],
+        ...     [0, 0, 1, 1.5],
+        ...     [0, 0, 0, 2],
+        ... ]
         >>> actor.user_matrix = arr
         >>> pl.show_axes()
         >>> pl.show()
@@ -360,10 +386,85 @@ class Prop3D(_vtk.vtkProp3D):
         return array_from_vtkmatrix(self.GetUserMatrix())
 
     @user_matrix.setter
-    def user_matrix(self, value: TransformLike):  # numpydoc ignore=GL08
-        array = np.eye(4) if value is None else _coerce_transformlike_arg(value)
+    def user_matrix(self, value: TransformLike) -> None:
+        array = np.eye(4) if value is None else _validation.validate_transform4x4(value)
         self.SetUserMatrix(vtkmatrix_from_array(array))
 
+    def transform(
+        self,
+        trans: TransformLike,
+        multiply_mode: Literal['pre', 'post'] = 'post',
+        *,
+        inplace: bool = False,
+    ):
+        """Apply a transformation to this object's :attr:`user_matrix`.
+
+        .. note::
+
+            This applies a transformation by modifying the :attr:`user_matrix`. This
+            differs from methods like :meth:`rotate_x`, :meth:`rotate_y`, :meth:`rotate_z`,
+            and :meth:`rotation_from` which apply a transformation indirectly by modifying
+            the :attr:`orientation`. See the :class:`Prop3D` class description for more
+            information about how this class is transformed.
+
+        .. versionadded:: 0.45
+
+        Parameters
+        ----------
+        trans : TransformLike
+            Transformation matrix as a 3x3 or 4x4 array, :vtk:`vtkMatrix3x3` or
+            :vtk:`vtkMatrix4x4`, :vtk:`vtkTransform`, or a SciPy ``Rotation`` instance.
+            If the input is 3x3, the array is padded using a 4x4 identity matrix.
+
+        multiply_mode : 'pre' | 'post', default: 'post'
+            Multiplication mode to use.
+
+            - ``'pre'``: pre-multiply ``trans`` with the :attr:`user_matrix`, i.e.
+              ``user_matrix @ trans``. The transformation is applied `before` the
+              current user-matrix.
+            - ``'post'``: post-multiply ``trans`` with the :attr:`user_matrix`, i.e.
+              ``trans @ user_matrix``. The transformation is applied `after` the
+              current user-matrix.
+
+        inplace : bool, default: False
+            When ``True``, modifies the prop inplace. Otherwise, a copy is returned.
+
+        Returns
+        -------
+        Prop3D
+            Transformed prop.
+
+        See Also
+        --------
+        pyvista.Transform
+            Describe linear transformations via a 4x4 matrix.
+        pyvista.DataObjectFilters.transform
+            Apply a transformation to a mesh.
+
+        """
+        # Validate input
+        _validation.check_contains(
+            ['pre', 'post'], must_contain=multiply_mode, name='multiply_mode'
+        )
+        matrix = _validation.validate_transform4x4(trans)
+
+        # Update user matrix
+        new_matrix = (
+            self.user_matrix @ matrix if multiply_mode == 'pre' else matrix @ self.user_matrix
+        )
+        output = self if inplace else self.copy()
+        output.user_matrix = new_matrix
+        return output
+
+    @abstractmethod
+    @_deprecate_positional_args
+    def copy(
+        self: Self,
+        deep: bool = True,  # noqa: FBT001, FBT002
+    ) -> Self:  # numpydoc ignore=RT01
+        """Return a copy of this prop."""
+        raise NotImplementedError  # pragma: no cover
+
     @property
     def length(self) -> float:  # numpydoc ignore=RT01
         """Return the length of the entity.
@@ -375,9 +476,44 @@ class Prop3D(_vtk.vtkProp3D):
         >>> actor = pl.add_mesh(pv.Sphere())
         >>> actor.length
         1.7272069317100354
+
         """
         return self.GetLength()
 
+    def rotation_from(self, rotation: RotationLike) -> None:
+        """Set the entity's orientation from a rotation.
+
+        Set the rotation of this entity from a 3x3 rotation matrix. This includes
+        NumPy arrays, a :vtk:`vtkMatrix3x3`, and SciPy ``Rotation`` objects.
+
+        This method may be used as an alternative for setting the :attr:`orientation`.
+
+        .. versionadded:: 0.45
+
+        Parameters
+        ----------
+        rotation : RotationLike
+            3x3 rotation matrix or a SciPy ``Rotation`` object.
+
+        Examples
+        --------
+        Create an actor and show its initial orientation.
+
+        >>> import pyvista as pv
+        >>> pl = pv.Plotter()
+        >>> actor = pl.add_mesh(pv.Sphere())
+        >>> actor.orientation
+        (0.0, -0.0, 0.0)
+
+        Set the orientation using a 3x3 matrix.
+
+        >>> actor.rotation_from([[0, 1, 0], [1, 0, 0], [0, 0, 1]])
+        >>> actor.orientation
+        (0.0, -180.0, -89.99999999999999)
+
+        """
+        self.orientation = _rotation_matrix_as_orientation(rotation)  # type: ignore[arg-type]
+
 
 def _rotation_matrix_as_orientation(
     array: NumpyArray[float] | _vtk.vtkMatrix3x3,
@@ -393,8 +529,8 @@ def _rotation_matrix_as_orientation(
 
     Parameters
     ----------
-    array : NumpyArray[float] | vtkMatrix3x3
-        3x3 rotation matrix as a NumPy array or a vtkMatrix.
+    array : NumpyArray[float] | :vtk:`vtkMatrix3x3`
+        3x3 rotation matrix as a NumPy array or a :vtk:`vtkMatrix3x3`.
 
     Returns
     -------
@@ -402,12 +538,7 @@ def _rotation_matrix_as_orientation(
         Tuple with x-y-z axis rotation angles in degrees.
 
     """
-    array_3x3 = _validation.validate_transform3x3(array)
-    array_4x4 = np.eye(4)
-    array_4x4[:3, :3] = array_3x3
-    transform = _vtk.vtkTransform()
-    transform.SetMatrix(array_4x4.ravel())
-    return transform.GetOrientation()
+    return Transform().rotate(array).GetOrientation()
 
 
 def _orientation_as_rotation_matrix(orientation: VectorLike[float]) -> NumpyArray[float]:
@@ -437,3 +568,121 @@ def _orientation_as_rotation_matrix(orientation: VectorLike[float]) -> NumpyArra
     matrix = _vtk.vtkMatrix4x4()
     prop.GetMatrix(matrix)
     return array_from_vtkmatrix(matrix)[:3, :3]
+
+
+class _Prop3DMixin(_BoundsSizeMixin, ABC):
+    """Add 3D transformations to props which do not inherit from :class:`pyvista.Prop3D`.
+
+    Derived classes need to implement the :meth:`_post_set_update` method to define
+    their behavior, e.g. manually apply a transformation.
+    """
+
+    def __init__(self) -> None:
+        from pyvista import Actor  # Avoid circular import  # noqa: PLC0415
+
+        self._prop3d = Actor()
+
+    @property
+    @wraps(Prop3D.scale.fget)  # type: ignore[attr-defined]
+    def scale(self) -> tuple[float, float, float]:  # numpydoc ignore=RT01
+        """Wrap :class:`pyvista.Prop3D.scale."""
+        return self._prop3d.scale
+
+    @scale.setter
+    @wraps(Prop3D.scale.fset)  # type: ignore[attr-defined]
+    def scale(self, scale: VectorLike[float]) -> None:
+        self._prop3d.scale = scale
+        self._post_set_update()
+
+    @property
+    @wraps(Prop3D.position.fget)  # type: ignore[attr-defined]
+    def position(self) -> tuple[float, float, float]:  # numpydoc ignore=RT01
+        """Wrap :class:`pyvista.Prop3D.position."""
+        return self._prop3d.position
+
+    @position.setter
+    @wraps(Prop3D.position.fset)  # type: ignore[attr-defined]
+    def position(self, position: VectorLike[float]) -> None:
+        self._prop3d.position = position
+        self._post_set_update()
+
+    @property
+    @wraps(Prop3D.orientation.fget)  # type: ignore[attr-defined]
+    def orientation(self) -> tuple[float, float, float]:  # numpydoc ignore=RT01
+        """Wrap :class:`pyvista.Prop3D.orientation."""
+        return self._prop3d.orientation
+
+    @orientation.setter
+    @wraps(Prop3D.orientation.fset)  # type: ignore[attr-defined]
+    def orientation(self, orientation: VectorLike[float]) -> None:
+        self._prop3d.orientation = orientation
+        self._post_set_update()
+
+    @property
+    @wraps(Prop3D.origin.fget)  # type: ignore[attr-defined]
+    def origin(self) -> tuple[float, float, float]:  # numpydoc ignore=RT01
+        """Wrap :class:`pyvista.Prop3D.origin."""
+        return self._prop3d.origin
+
+    @origin.setter
+    @wraps(Prop3D.origin.fset)  # type: ignore[attr-defined]
+    def origin(self, origin: VectorLike[float]) -> None:
+        self._prop3d.origin = origin
+        self._post_set_update()
+
+    @property
+    @wraps(Prop3D.user_matrix.fget)  # type: ignore[attr-defined]
+    def user_matrix(self) -> NumpyArray[float]:  # numpydoc ignore=RT01
+        """Wrap :class:`pyvista.Prop3D.user_matrix."""
+        return self._prop3d.user_matrix
+
+    @user_matrix.setter
+    @wraps(Prop3D.user_matrix.fset)  # type: ignore[attr-defined]
+    def user_matrix(self, matrix: TransformLike) -> None:
+        self._prop3d.user_matrix = matrix
+        self._post_set_update()
+
+    @property
+    def _transformation_matrix(self):
+        """Transformation matrix applied to the actor.
+
+        The transformation is computed from the attributes :attr:`position`
+        :attr:`origin`, :attr:`scale`, :attr:`orientation`, and :attr:`user_matrix`.
+
+        It is the actual transformation applied to the actor under-the-hood by vtk.
+        """
+        return array_from_vtkmatrix(self._prop3d.GetMatrix())
+
+    @abstractmethod
+    def _post_set_update(self):
+        """Update object after setting Prop3D attributes."""
+
+    @abstractmethod
+    def _get_bounds(self) -> BoundsTuple:
+        """Return the object's 3D bounds."""
+
+    @property
+    @wraps(Prop3D.bounds.fget)  # type: ignore[attr-defined]
+    def bounds(self) -> BoundsTuple:  # numpydoc ignore=RT01
+        """Wrap :class:`pyvista.Prop3D.bounds`."""
+        return BoundsTuple(*self._get_bounds())
+
+    @property
+    @wraps(Prop3D.center.fget)  # type: ignore[attr-defined]
+    def center(self) -> tuple[float, float, float]:  # numpydoc ignore=RT01
+        """Wrap :class:`pyvista.Prop3D.center."""
+        bnds = self.bounds
+        return (
+            (bnds.x_min + bnds.x_max) / 2,
+            (bnds.y_min + bnds.y_max) / 2,
+            (bnds.z_min + bnds.z_max) / 2,
+        )
+
+    @property
+    @wraps(Prop3D.length.fget)  # type: ignore[attr-defined]
+    def length(self) -> float:  # numpydoc ignore=RT01
+        """Wrap :class:`pyvista.Prop3D.length."""
+        bnds = self.bounds
+        return np.linalg.norm(
+            (bnds.x_max - bnds.x_min, bnds.y_max - bnds.y_min, bnds.z_max - bnds.z_min)
+        ).tolist()
