@@ -5,31 +5,40 @@ from __future__ import annotations
 import pathlib
 from pathlib import Path
 from typing import TYPE_CHECKING
+from typing import Literal
 
 import pyvista
+from pyvista._deprecate_positional_args import _deprecate_positional_args
 from pyvista.core import _validation
+from pyvista.core._typing_core import BoundsTuple
 from pyvista.core.utilities.misc import _check_range
-from pyvista.core.utilities.misc import no_new_attr
+from pyvista.core.utilities.misc import _NameMixin
+from pyvista.core.utilities.misc import _NoNewAttrMixin
 
 from . import _vtk
 from .colors import Color
+from .prop3d import _Prop3DMixin
 from .themes import Theme
 from .tools import FONTS
 
-if TYPE_CHECKING:  # pragma: no cover
-    from typing import ClassVar
-    from typing import Sequence
+if TYPE_CHECKING:
+    from collections.abc import Sequence
 
     from pyvista.core._typing_core import VectorLike
 
     from ._typing import ColorLike
 
+HorizontalOptions = Literal['left', 'center', 'right']
+VerticalOptions = Literal['bottom', 'center', 'top']
 
-@no_new_attr
-class CornerAnnotation(_vtk.vtkCornerAnnotation):
+
+class CornerAnnotation(
+    _NoNewAttrMixin, _vtk.DisableVtkSnakeCase, _NameMixin, _vtk.vtkCornerAnnotation
+):
     """Text annotation in four corners.
 
-    This is an annotation object that manages four text actors / mappers to provide annotation in the four corners of a viewport.
+    This is an annotation object that manages four text actors / mappers to provide
+    annotation in the four corners of a viewport.
 
     Parameters
     ----------
@@ -45,6 +54,11 @@ class CornerAnnotation(_vtk.vtkCornerAnnotation):
     linear_font_scale_factor : float, optional
         Linear font scale factor.
 
+    name : str, optional
+        The name of this actor used when tracking on a plotter.
+
+        .. versionadded:: 0.45
+
     Examples
     --------
     Create text annotation in four corners.
@@ -52,9 +66,13 @@ class CornerAnnotation(_vtk.vtkCornerAnnotation):
     >>> from pyvista import CornerAnnotation
     >>> text = CornerAnnotation(0, 'text')
     >>> prop = text.prop
+
     """
 
-    def __init__(self, position, text, prop=None, linear_font_scale_factor=None):
+    @_deprecate_positional_args(allowed=['position', 'text'])
+    def __init__(  # noqa: PLR0917
+        self, position, text, prop=None, linear_font_scale_factor=None, name=None
+    ):
         """Initialize a new text annotation descriptor."""
         super().__init__()
         self.set_text(position, text)
@@ -62,6 +80,7 @@ class CornerAnnotation(_vtk.vtkCornerAnnotation):
             self.prop = TextProperty()
         if linear_font_scale_factor is not None:
             self.linear_font_scale_factor = linear_font_scale_factor
+        self._name = name
 
     def get_text(self, position):
         """Get the text to be displayed for each corner.
@@ -75,6 +94,7 @@ class CornerAnnotation(_vtk.vtkCornerAnnotation):
         -------
         str
             Text to be displayed for each corner.
+
         """
         return self.GetText(position)
 
@@ -88,6 +108,7 @@ class CornerAnnotation(_vtk.vtkCornerAnnotation):
 
         text : str
             Text to be displayed for each corner.
+
         """
         corner_mappings = {
             'lower_left': self.LowerLeft,
@@ -123,11 +144,12 @@ class CornerAnnotation(_vtk.vtkCornerAnnotation):
         -------
         pyvista.TextProperty
             Property of this actor.
+
         """
         return self.GetTextProperty()
 
     @prop.setter
-    def prop(self, prop: TextProperty):  # numpydoc ignore=GL08
+    def prop(self, prop: TextProperty):
         self.SetTextProperty(prop)
 
     @property
@@ -138,16 +160,16 @@ class CornerAnnotation(_vtk.vtkCornerAnnotation):
         -------
         float
             Font scaling factors.
+
         """
         return self.GetLinearFontScaleFactor()
 
     @linear_font_scale_factor.setter
-    def linear_font_scale_factor(self, factor: float):  # numpydoc ignore=GL08
+    def linear_font_scale_factor(self, factor: float):
         self.SetLinearFontScaleFactor(factor)
 
 
-@no_new_attr
-class Text(_vtk.vtkTextActor):
+class Text(_NoNewAttrMixin, _vtk.DisableVtkSnakeCase, _NameMixin, _vtk.vtkTextActor):
     r"""Define text by default theme.
 
     Parameters
@@ -163,6 +185,11 @@ class Text(_vtk.vtkTextActor):
     prop : pyvista.TextProperty, optional
         The property of this actor.
 
+    name : str, optional
+        The name of this actor used when tracking on a plotter.
+
+        .. versionadded:: 0.45
+
     Examples
     --------
     Create a text with text's property.
@@ -170,9 +197,13 @@ class Text(_vtk.vtkTextActor):
     >>> from pyvista import Text
     >>> text = Text()
     >>> prop = text.prop
+
     """
 
-    def __init__(self, text=None, position=None, prop=None):
+    @_deprecate_positional_args(allowed=['text'])
+    def __init__(  # noqa: PLR0917
+        self, text=None, position=None, prop=None, name=None
+    ):
         """Initialize a new text descriptor."""
         super().__init__()
         if text is not None:
@@ -181,6 +212,7 @@ class Text(_vtk.vtkTextActor):
             self.position = position
         if prop is None:
             self.prop = TextProperty()
+        self._name = name
 
     @property
     def input(self):
@@ -192,11 +224,12 @@ class Text(_vtk.vtkTextActor):
             Text string to be displayed.
             "\n" is recognized as a carriage return/linefeed (line separator).
             The characters must be in the UTF-8 encoding.
+
         """
         return self.GetInput()
 
     @input.setter
-    def input(self, text: str):  # numpydoc ignore=GL08
+    def input(self, text: str):
         self.SetInput(text)
 
     @property
@@ -207,11 +240,12 @@ class Text(_vtk.vtkTextActor):
         -------
         pyvista.TextProperty
             Property of this actor.
+
         """
         return self.GetTextProperty()
 
     @prop.setter
-    def prop(self, prop: TextProperty):  # numpydoc ignore=GL08
+    def prop(self, prop: TextProperty):
         self.SetTextProperty(prop)
 
     @property
@@ -222,24 +256,41 @@ class Text(_vtk.vtkTextActor):
         -------
         Sequence[float]
             Position coordinate.
+
         """
         return self.GetPosition()
 
     @position.setter
-    def position(self, position: Sequence[float]):  # numpydoc ignore=GL08
+    def position(self, position: Sequence[float]):
         self.SetPosition(position[0], position[1])
 
 
-class Label(Text):
+class Label(_Prop3DMixin, Text):
     """2D label actor with a 3D position coordinate.
 
+    Unlike :class:`~pyvista.Text`, which uses 2D viewport coordinates to position text
+    in a plot, this class instead uses a 3D position coordinate. This class may be
+    positioned, oriented, and transformed in a manner similar to a 3D
+    :class:`~pyvista.Actor`.
+
+    In addition, this class supports an additional :attr:`relative_position` attribute.
+    In general, it is recommended to simply use :attr:`~pyvista.Prop3D.position` when positioning a
+    :class:`Label` by itself. However, if the position of the label depends on the
+    positioning of another actor, both :attr:`~pyvista.Prop3D.position` and
+    :attr:`relative_position` may be used together.
+    In these cases, the :attr:`~pyvista.Prop3D.position` of the label and actor
+    should be kept in-sync. See the examples below.
+
     Parameters
     ----------
     text : str, optional
         Text string to be displayed.
 
     position : VectorLike[float]
-        The position coordinate.
+        Position of the text in XYZ coordinates.
+
+    relative_position : VectorLike[float]
+        Position of the text in XYZ coordinates relative to its :attr:`~pyvista.Prop3D.position`.
 
     size : int
         Size of the text label.
@@ -247,50 +298,125 @@ class Label(Text):
     prop : pyvista.TextProperty, optional
         The property of this actor.
 
+    name : str, optional
+        The name of this actor used when tracking on a plotter.
+
+        .. versionadded:: 0.45
+
     See Also
     --------
     pyvista.Plotter.add_point_labels
 
     Examples
     --------
-    Create a label for a point of interest.
+    Create a label for a point of interest. Here we add a label to the tip of a cone.
 
     >>> import pyvista as pv
-    >>> mesh = pv.Cone()
-    >>> tip_point = mesh.points[0]
-    >>> label = pv.Label('tip', position=tip_point)
+    >>> cone_dataset = pv.Cone()
+    >>> tip = (0.5, 0, 0)
+    >>> label = pv.Label('tip', position=tip)
 
     Plot the mesh and label.
 
     >>> pl = pv.Plotter()
-    >>> _ = pl.add_mesh(mesh)
+    >>> cone_actor = pl.add_mesh(cone_dataset)
     >>> _ = pl.add_actor(label)
     >>> pl.show()
-    """
 
-    _new_attr_exceptions: ClassVar[tuple[str]] = ('size',)
+    The previous example set the label's position as the cone's tip explicitly.
+    However, this means that the two actors now have different positions.
+
+    >>> cone_actor.position
+    (0.0, 0.0, 0.0)
+    >>> label.position
+    (0.5, 0.0, 0.0)
+
+    And if we change the 3D orientation of the cone and label, the label is no longer
+    positioned at the tip.
+
+    >>> cone_actor.orientation = 0, 0, 90
+    >>> label.orientation = 0, 0, 90
+    >>>
+    >>> pl = pv.Plotter()
+    >>> _ = pl.add_actor(cone_actor)
+    >>> _ = pl.add_actor(label)
+    >>> pl.show()
+
+    This is because rotations by :class:`pyvista.Prop3D` are applied **before** the
+    actor is moved to its final position, and therefore the label's position is not
+    considered in the rotation. Hence, the final position of the label remains at
+    ``(0.5, 0.0, 0.0)`` as it did earlier, despite changing its orientation.
+
+    If we want the position of the label to have the same positioning *relative* to the
+    cone, we can instead set its :attr:`relative_position`.
+
+    First, reset the label's position to match the cone's position.
+
+    >>> label.position = cone_actor.position
+    >>> label.position
+    (0.0, 0.0, 0.0)
+
+    Now set its :attr:`relative_position` to the tip of the cone.
+
+    >>> label.relative_position = tip
+    >>> label.relative_position
+    (0.5, 0.0, 0.0)
+
+    Plot the results. The label is now correctly positioned at the tip of the cone.
+    This is because the :attr:`relative_position` is considered as part of the
+    rotation.
+
+    >>> pl = pv.Plotter()
+    >>> _ = pl.add_actor(cone_actor)
+    >>> _ = pl.add_actor(label)
+    >>> pl.show()
+
+    As long as the label and cone's :class:`pyvista.Prop3D` attributes are modified
+    together and synchronized, the label will remain at the tip of the cone.
+
+    Modify the position of the label and tip.
+
+    >>> cone_actor.position = (1.0, 2.0, 3.0)
+    >>> label.position = (1.0, 2.0, 3.0)
+    >>> pl = pv.Plotter()
+    >>> _ = pl.add_actor(cone_actor)
+    >>> _ = pl.add_actor(label)
+    >>> _ = pl.add_axes_at_origin()
+    >>> pl.show()
+
+    """
 
     def __init__(
         self,
         text: str | None = None,
         position: VectorLike[float] = (0.0, 0.0, 0.0),
+        relative_position: VectorLike[float] = (0.0, 0.0, 0.0),
         *,
         size: int = 50,
         prop: pyvista.Property | None = None,
+        name: str = 'Label',
     ):
-        super().__init__(text=text, prop=prop)
+        Text.__init__(self, text=text, prop=prop)
         self.GetPositionCoordinate().SetCoordinateSystemToWorld()
         self.SetTextScaleModeToNone()  # Use font size to control size of text
-        self.position = position  # type: ignore[assignment]
+        self._name = name
+
+        _Prop3DMixin.__init__(self)
+        self.relative_position = relative_position
+        self.position = position
         self.size = size
 
     @property
-    def position(self) -> tuple[float, float, float]:  # numpydoc ignore=RT01
-        """Text position coordinate in xyz space."""
+    def _label_position(self) -> tuple[float, float, float]:  # numpydoc ignore=RT01
+        """Position of the label in xyz space.
+
+        This is the "true" position of the label. Internally this is loosely
+        equal to :attr:`~pyvista.Prop3D.position` + :attr:`relative_position`.
+        """
         return self.GetPositionCoordinate().GetValue()
 
-    @position.setter
-    def position(self, position: VectorLike[float]):  # numpydoc ignore=GL08
+    @_label_position.setter
+    def _label_position(self, position: VectorLike[float]):
         valid_position = _validation.validate_array3(position)
         self.GetPositionCoordinate().SetValue(valid_position)
 
@@ -301,16 +427,38 @@ class Label(Text):
         Notes
         -----
         The text property's font size used to control the size of the label.
+
         """
         return self.prop.font_size
 
     @size.setter
-    def size(self, size: int):  # numpydoc ignore=GL08
+    def size(self, size: int):
         self.prop.font_size = size
 
+    @property
+    def relative_position(self) -> tuple[float, float, float]:  # numpydoc ignore=RT01
+        """Position of the label relative to its :attr:`~pyvista.Prop3D.position`."""
+        return tuple(self._relative_position.tolist())
 
-@no_new_attr
-class TextProperty(_vtk.vtkTextProperty):
+    @relative_position.setter
+    def relative_position(self, position: VectorLike[float]):
+        self._relative_position = _validation.validate_array3(position, dtype_out=float)
+        self._post_set_update()
+
+    def _post_set_update(self):
+        # Update the label's underlying text position
+        matrix4x4 = self._transformation_matrix
+        vector4 = (*self.relative_position, 1)
+        new_position = (matrix4x4 @ vector4)[:3]
+        self._label_position = new_position
+
+    def _get_bounds(self) -> BoundsTuple:
+        # Define its 3D position as its bounds
+        x, y, z = self._label_position
+        return BoundsTuple(x, x, y, y, z, z)
+
+
+class TextProperty(_NoNewAttrMixin, _vtk.DisableVtkSnakeCase, _vtk.vtkTextProperty):
     """Define text's property.
 
     Parameters
@@ -366,10 +514,10 @@ class TextProperty(_vtk.vtkTextProperty):
     >>> from pyvista import TextProperty
     >>> prop = TextProperty()
     >>> prop.opacity = 0.5
-    >>> prop.background_color = "b"
+    >>> prop.background_color = 'b'
     >>> prop.background_opacity = 0.5
     >>> prop.show_frame = True
-    >>> prop.frame_color = "b"
+    >>> prop.frame_color = 'b'
     >>> prop.frame_width = 10
     >>> prop.frame_color
     Color(name='blue', hex='#0000ffff', opacity=255)
@@ -381,7 +529,8 @@ class TextProperty(_vtk.vtkTextProperty):
     _background_color_set = None
     _font_family = None
 
-    def __init__(
+    @_deprecate_positional_args(allowed=['theme'])
+    def __init__(  # noqa: PLR0917
         self,
         theme=None,
         color=None,
@@ -389,11 +538,11 @@ class TextProperty(_vtk.vtkTextProperty):
         orientation=None,
         font_size=None,
         font_file=None,
-        shadow=False,
+        shadow: bool = False,  # noqa: FBT001, FBT002
         justification_horizontal=None,
         justification_vertical=None,
-        italic=False,
-        bold=False,
+        italic: bool = False,  # noqa: FBT001, FBT002
+        bold: bool = False,  # noqa: FBT001, FBT002
         background_color=None,
         background_opacity=None,
     ):
@@ -439,7 +588,7 @@ class TextProperty(_vtk.vtkTextProperty):
         return Color(self.GetColor())
 
     @color.setter
-    def color(self, color: ColorLike):  # numpydoc ignore=GL08
+    def color(self, color: ColorLike):
         self._color_set = color is not None
         rgb_color = Color(color, default_color=self._theme.font.color)
         self.SetColor(rgb_color.float_rgb)
@@ -458,7 +607,7 @@ class TextProperty(_vtk.vtkTextProperty):
         return self.GetOpacity()
 
     @opacity.setter
-    def opacity(self, opacity: float):  # numpydoc ignore=GL08
+    def opacity(self, opacity: float):
         _check_range(opacity, (0, 1), 'opacity')
         self.SetOpacity(opacity)
 
@@ -475,7 +624,7 @@ class TextProperty(_vtk.vtkTextProperty):
         return Color(self.GetBackgroundColor())
 
     @background_color.setter
-    def background_color(self, color: ColorLike):  # numpydoc ignore=GL08
+    def background_color(self, color: ColorLike):
         self._background_color_set = color is not None
         rgb_color = Color(color)
         self.SetBackgroundColor(rgb_color.float_rgb)
@@ -494,7 +643,7 @@ class TextProperty(_vtk.vtkTextProperty):
         return self.GetBackgroundOpacity()
 
     @background_opacity.setter
-    def background_opacity(self, opacity: float):  # numpydoc ignore=GL08
+    def background_opacity(self, opacity: float):
         _check_range(opacity, (0, 1), 'background_opacity')
         self.SetBackgroundOpacity(opacity)
 
@@ -511,7 +660,7 @@ class TextProperty(_vtk.vtkTextProperty):
         return bool(self.GetFrame())
 
     @show_frame.setter
-    def show_frame(self, frame: bool):  # numpydoc ignore=GL08
+    def show_frame(self, frame: bool):
         self.SetFrame(frame)
 
     @property
@@ -522,11 +671,12 @@ class TextProperty(_vtk.vtkTextProperty):
         -------
         pyvista.Color
             Frame color of text property.
+
         """
         return Color(self.GetFrameColor())
 
     @frame_color.setter
-    def frame_color(self, color):  # numpydoc ignore=GL08
+    def frame_color(self, color):
         self.SetFrameColor(Color(color).float_rgb)
 
     @property
@@ -538,11 +688,12 @@ class TextProperty(_vtk.vtkTextProperty):
         int
             Width of the frame. The width is expressed in pixels.
             The default is 1 pixel.
+
         """
         return self.GetFrameWidth()
 
     @frame_width.setter
-    def frame_width(self, width: int):  # numpydoc ignore=GL08
+    def frame_width(self, width: int):
         self.SetFrameWidth(width)
 
     @property
@@ -553,11 +704,12 @@ class TextProperty(_vtk.vtkTextProperty):
         -------
         str | None
             Font family or None.
+
         """
         return self._font_family
 
     @font_family.setter
-    def font_family(self, font_family: str | None):  # numpydoc ignore=GL08
+    def font_family(self, font_family: str | None):
         if font_family is None:
             font_family = self._theme.font.family
         self._font_family = font_family
@@ -571,11 +723,12 @@ class TextProperty(_vtk.vtkTextProperty):
         -------
         int
             Font size.
+
         """
         return self.GetFontSize()
 
     @font_size.setter
-    def font_size(self, font_size: int):  # numpydoc ignore=GL08
+    def font_size(self, font_size: int):
         self.SetFontSize(font_size)
 
     def enable_shadow(self) -> None:
@@ -590,11 +743,12 @@ class TextProperty(_vtk.vtkTextProperty):
         -------
         float
             Text's orientation (in degrees).
+
         """
         return self.GetOrientation()
 
     @orientation.setter
-    def orientation(self, orientation: float):  # numpydoc ignore=GL08
+    def orientation(self, orientation: float):
         self.SetOrientation(orientation)
 
     def set_font_file(self, font_file: str):
@@ -604,11 +758,13 @@ class TextProperty(_vtk.vtkTextProperty):
         ----------
         font_file : str
             Font file path.
+
         """
         path = pathlib.Path(font_file)
         path = path.resolve()
         if not Path(path).is_file():
-            raise FileNotFoundError(f'Unable to locate {path}')
+            msg = f'Unable to locate {path}'
+            raise FileNotFoundError(msg)
         self.SetFontFamily(_vtk.VTK_FONT_FILE)
         self.SetFontFile(str(path))
 
@@ -621,6 +777,7 @@ class TextProperty(_vtk.vtkTextProperty):
         str
             Text's horizontal justification.
             Should be either "left", "center" or "right".
+
         """
         justification = self.GetJustificationAsString().lower()
         if justification == 'centered':
@@ -628,7 +785,7 @@ class TextProperty(_vtk.vtkTextProperty):
         return justification
 
     @justification_horizontal.setter
-    def justification_horizontal(self, justification: str):  # numpydoc ignore=GL08
+    def justification_horizontal(self, justification: str):
         if justification.lower() == 'left':
             self.SetJustificationToLeft()
         elif justification.lower() == 'center':
@@ -636,10 +793,11 @@ class TextProperty(_vtk.vtkTextProperty):
         elif justification.lower() == 'right':
             self.SetJustificationToRight()
         else:
-            raise ValueError(
+            msg = (
                 f'Invalid {justification} for justification_horizontal. '
-                'Should be either "left", "center" or "right".',
+                'Should be either "left", "center" or "right".'
             )
+            raise ValueError(msg)
 
     @property
     def justification_vertical(self) -> str:
@@ -650,6 +808,7 @@ class TextProperty(_vtk.vtkTextProperty):
         str
             Text's vertical justification.
             Should be either "bottom", "center" or "top".
+
         """
         justification = self.GetVerticalJustificationAsString().lower()
         if justification == 'centered':
@@ -657,7 +816,7 @@ class TextProperty(_vtk.vtkTextProperty):
         return justification
 
     @justification_vertical.setter
-    def justification_vertical(self, justification: str):  # numpydoc ignore=GL08
+    def justification_vertical(self, justification: str):
         if justification.lower() == 'bottom':
             self.SetVerticalJustificationToBottom()
         elif justification.lower() == 'center':
@@ -665,10 +824,11 @@ class TextProperty(_vtk.vtkTextProperty):
         elif justification.lower() == 'top':
             self.SetVerticalJustificationToTop()
         else:
-            raise ValueError(
+            msg = (
                 f'Invalid {justification} for justification_vertical. '
-                'Should be either "bottom", "center" or "top".',
+                'Should be either "bottom", "center" or "top".'
             )
+            raise ValueError(msg)
 
     @property
     def italic(self) -> bool:
@@ -683,7 +843,7 @@ class TextProperty(_vtk.vtkTextProperty):
         return bool(self.GetItalic())
 
     @italic.setter
-    def italic(self, italic: bool):  # numpydoc ignore=GL08
+    def italic(self, italic: bool):
         self.SetItalic(italic)
 
     @property
@@ -699,5 +859,16 @@ class TextProperty(_vtk.vtkTextProperty):
         return bool(self.GetBold())
 
     @bold.setter
-    def bold(self, bold: bool):  # numpydoc ignore=GL08
+    def bold(self, bold: bool):
         self.SetBold(bold)
+
+    def shallow_copy(self, to_copy: TextProperty) -> None:
+        """Create a shallow copy of the text's property.
+
+        Parameters
+        ----------
+        to_copy : pyvista.TextProperty
+            Text's property to copy from.
+
+        """
+        self.ShallowCopy(to_copy)
