@@ -1,26 +1,26 @@
-"""This module provides a wrapper for vtk.vtkTexture."""
+"""Wrapper for :vtk:`vtkTexture`."""
 
 from __future__ import annotations
 
+from collections.abc import Sequence
 from typing import TYPE_CHECKING
-from typing import Sequence
 import warnings
 
 import numpy as np
 
 import pyvista
-from pyvista.core.dataset import DataObject
+from pyvista.core.dataobject import DataObject
 from pyvista.core.utilities.fileio import _try_imageio_imread
 from pyvista.core.utilities.misc import AnnotatedIntEnum
 
 from . import _vtk
 
-if TYPE_CHECKING:  # pragma: no cover
+if TYPE_CHECKING:
     from pyvista.core._typing_core import NumpyArray
 
 
 class Texture(DataObject, _vtk.vtkTexture):
-    """Wrap vtkTexture.
+    """Wrap :vtk:`vtkTexture`.
 
     Textures can be used to apply images to surfaces, as in the case of
     :ref:`texture_example`.
@@ -31,8 +31,8 @@ class Texture(DataObject, _vtk.vtkTexture):
 
     Parameters
     ----------
-    uinput : str, vtkImageData, vtkTexture, sequence[pyvista.ImageData], optional
-        Filename, ``vtkImageData``, ``vtkTexture``, :class:`numpy.ndarray` or a
+    uinput : str, :vtk:`vtkImageData`, :vtk:`vtkTexture`, sequence[ImageData], optional
+        Filename, :vtk:`vtkImageData`, :vtk:`vtkTexture`, :class:`numpy.ndarray` or a
         sequence of images to create a cubemap. If a sequence of images, must
         be of the same size and in the following order:
 
@@ -134,22 +134,25 @@ class Texture(DataObject, _vtk.vtkTexture):
             # add each image to the cubemap
             for i, image in enumerate(uinput):
                 if not isinstance(image, pyvista.ImageData):
-                    raise TypeError(
+                    msg = (
                         'If a sequence, the each item in the first argument must be a '
-                        'pyvista.ImageData',
+                        'pyvista.ImageData'
                     )
+                    raise TypeError(msg)
                 # must flip y for cubemap to display properly
                 self.SetInputDataObject(i, image._flip_uniform(1))
         elif uinput is None:
             pass
         else:
-            raise TypeError(f'Cannot create a pyvista.Texture from ({type(uinput)})')
+            msg = f'Cannot create a pyvista.Texture from ({type(uinput)})'
+            raise TypeError(msg)
 
     def _from_file(self, filename, **kwargs):
         try:
             image = pyvista.read(filename, **kwargs)
-            if image.n_points < 2:
-                raise RuntimeError("Problem reading the image with VTK.")  # pragma: no cover
+            if image.n_points < 2:  # pragma: no cover
+                msg = 'Problem reading the image with VTK.'
+                raise RuntimeError(msg)
             self._from_image_data(image)
         except (KeyError, ValueError, OSError):
             self._from_array(_try_imageio_imread(filename))  # pragma: no cover
@@ -169,19 +172,19 @@ class Texture(DataObject, _vtk.vtkTexture):
 
         >>> from pyvista import examples
         >>> texture = examples.download_masonry_texture()
-        >>> texture.interpolation = False
+        >>> texture.interpolate = False
         >>> texture.plot(cpos='xy', zoom=3)
 
         Plot the same texture with interpolation.
 
-        >>> texture.interpolation = True
+        >>> texture.interpolate = True
         >>> texture.plot(cpos='xy', zoom=3)
 
         """
         return bool(self.GetInterpolate())
 
     @interpolate.setter
-    def interpolate(self, value: bool):  # numpydoc ignore=GL08
+    def interpolate(self, value: bool):
         self.SetInterpolate(value)
 
     @property
@@ -190,7 +193,7 @@ class Texture(DataObject, _vtk.vtkTexture):
         return bool(self.GetMipmap())
 
     @mipmap.setter
-    def mipmap(self, value: bool):  # numpydoc ignore=GL08
+    def mipmap(self, value: bool):
         self.SetMipmap(value)
 
     def _from_image_data(self, image):
@@ -203,11 +206,13 @@ class Texture(DataObject, _vtk.vtkTexture):
         """Create a texture from a np.ndarray."""
         if image.ndim not in [2, 3]:
             # we support 2 [single component image] or 3 [e.g. rgb or rgba] dims
-            raise ValueError('Input image must be nn by nm by RGB[A]')
+            msg = 'Input image must be nn by nm by RGB[A]'
+            raise ValueError(msg)
 
         if image.ndim == 3:
             if image.shape[2] not in [1, 3, 4]:
-                raise ValueError('Third dimension of the array must be of size 3 (RGB) or 4 (RGBA)')
+                msg = 'Third dimension of the array must be of size 3 (RGB) or 4 (RGBA)'
+                raise ValueError(msg)
             n_components = image.shape[2]
         elif image.ndim == 2:
             n_components = 1
@@ -261,7 +266,7 @@ class Texture(DataObject, _vtk.vtkTexture):
         return bool(self.GetRepeat())
 
     @repeat.setter
-    def repeat(self, flag: bool):  # numpydoc ignore=GL08
+    def repeat(self, flag: bool):
         self.SetRepeat(flag)
 
     def flip_x(self) -> Texture:
@@ -280,7 +285,7 @@ class Texture(DataObject, _vtk.vtkTexture):
         >>> flipped.plot()
 
         """
-        return Texture(self.to_image()._flip_uniform(0))
+        return Texture(self.to_image()._flip_uniform(0))  # type: ignore[abstract]
 
     def flip_y(self) -> Texture:
         """Flip the texture in the y direction.
@@ -298,7 +303,7 @@ class Texture(DataObject, _vtk.vtkTexture):
         >>> flipped.plot()
 
         """
-        return Texture(self.to_image()._flip_uniform(1))
+        return Texture(self.to_image()._flip_uniform(1))  # type: ignore[abstract]
 
     def to_image(self):
         """Return the texture as an image.
@@ -340,7 +345,7 @@ class Texture(DataObject, _vtk.vtkTexture):
 
         """
         return self.to_image().active_scalars.reshape(
-            list(self.dimensions)[::-1] + [self.n_components],
+            [*list(self.dimensions)[::-1], self.n_components]
         )[::-1]
 
     def rotate_cw(self) -> Texture:
@@ -359,7 +364,7 @@ class Texture(DataObject, _vtk.vtkTexture):
         >>> rotated.plot()
 
         """
-        return Texture(np.rot90(self.to_array()))
+        return Texture(np.rot90(self.to_array()))  # type: ignore[abstract]
 
     def rotate_ccw(self) -> Texture:
         """Rotate this texture 90 degrees counter-clockwise.
@@ -377,7 +382,7 @@ class Texture(DataObject, _vtk.vtkTexture):
         >>> rotated.plot()
 
         """
-        return Texture(np.rot90(self.to_array(), k=3))
+        return Texture(np.rot90(self.to_array(), k=3))  # type: ignore[abstract]
 
     @property
     def cube_map(self) -> bool:  # numpydoc ignore=RT01
@@ -385,25 +390,26 @@ class Texture(DataObject, _vtk.vtkTexture):
         return self.GetCubeMap()
 
     @cube_map.setter
-    def cube_map(self, flag: bool):  # numpydoc ignore=GL08
+    def cube_map(self, flag: bool):
         self.SetCubeMap(flag)
 
-    def copy(self):
+    def copy(self):  # type: ignore[override]
         """Make a copy of this texture.
 
         Returns
         -------
         pyvista.Texture
             Copied texture.
+
         """
-        return Texture(self.to_image().copy())
+        return Texture(self.to_image().copy())  # type: ignore[abstract]
 
     def to_skybox(self):
-        """Return the texture as a ``vtkSkybox`` if cube mapping is enabled.
+        """Return the texture as a :vtk:`vtkSkybox` if cube mapping is enabled.
 
         Returns
         -------
-        vtk.vtkSkybox
+        :vtk:`vtkSkybox`
             Skybox if cube mapping is enabled.  Otherwise, ``None``.
 
         """
@@ -415,14 +421,14 @@ class Texture(DataObject, _vtk.vtkTexture):
 
     def __repr__(self):
         """Return the object representation."""
-        return pyvista.DataSet.__repr__(self)
+        return pyvista.DataSet.__repr__(self)  # type: ignore[type-var]
 
     def _get_attrs(self):
         """Return the representation methods (internal helper)."""
         attrs = []
-        attrs.append(("Components", self.n_components, "{:d}"))
-        attrs.append(("Cube Map", self.cube_map, "{:}"))
-        attrs.append(("Dimensions", self.dimensions, "{:d}, {:d}"))
+        attrs.append(('Components', self.n_components, '{:d}'))
+        attrs.append(('Cube Map', self.cube_map, '{:}'))
+        attrs.append(('Dimensions', self.dimensions, '{:d}, {:d}'))  # type: ignore[arg-type]
         return attrs
 
     @property
@@ -448,7 +454,7 @@ class Texture(DataObject, _vtk.vtkTexture):
         return input_data.GetPointData().GetScalars().GetNumberOfComponents()
 
     @property
-    def dimensions(self) -> tuple[float, float]:  # numpydoc ignore=RT01
+    def dimensions(self) -> tuple[int, int]:  # numpydoc ignore=RT01
         """Dimensions of the texture.
 
         Examples
@@ -477,7 +483,7 @@ class Texture(DataObject, _vtk.vtkTexture):
 
         Returns
         -------
-        various or None
+        pyvista.Actor | None
             See the returns section of :func:`pyvista.plot`.
 
         Examples
@@ -490,7 +496,7 @@ class Texture(DataObject, _vtk.vtkTexture):
 
         Plot a cubemap as a skybox.
 
-        >>> cube_map = examples.download_dikhololo_night()
+        >>> cube_map = examples.download_sky_box_cube_map()
         >>> cube_map.plot()
 
         """
@@ -511,7 +517,7 @@ class Texture(DataObject, _vtk.vtkTexture):
         lighting = kwargs.pop('lighting', None)
         pl = pyvista.Plotter(lighting=lighting)
         pl.add_actor(self.to_skybox())
-        pl.set_environment_texture(self, True)
+        pl.set_environment_texture(self, is_srgb=True)
         pl.add_mesh(pyvista.Sphere(), pbr=True, roughness=0.5, metallic=1.0)
         pl.camera_position = cpos
         pl.camera.zoom(zoom)
@@ -584,18 +590,20 @@ class Texture(DataObject, _vtk.vtkTexture):
 
         """
         if not hasattr(self, 'GetWrap'):  # pragma: no cover
-            from pyvista.core.errors import VTKVersionError
+            from pyvista.core.errors import VTKVersionError  # noqa: PLC0415
 
-            raise VTKVersionError('`wrap` requires VTK v9.1.0 or newer.')
+            msg = '`wrap` requires VTK v9.1.0 or newer.'
+            raise VTKVersionError(msg)
 
         return Texture.WrapType(self.GetWrap())  # type: ignore[call-arg]
 
     @wrap.setter
-    def wrap(self, value: Texture.WrapType | int):  # numpydoc ignore=GL08
+    def wrap(self, value: Texture.WrapType | int):
         if not hasattr(self, 'SetWrap'):  # pragma: no cover
-            from pyvista.core.errors import VTKVersionError
+            from pyvista.core.errors import VTKVersionError  # noqa: PLC0415
 
-            raise VTKVersionError('`wrap` requires VTK v9.1.0 or newer.')
+            msg = '`wrap` requires VTK v9.1.0 or newer.'
+            raise VTKVersionError(msg)
 
         self.SetWrap(value)
 
@@ -634,7 +642,7 @@ class Texture(DataObject, _vtk.vtkTexture):
         data = self.to_array()
         r, g, b = data[..., 0], data[..., 1], data[..., 2]
         data = (0.299 * r + 0.587 * g + 0.114 * b).round().astype(np.uint8)
-        return Texture(data)
+        return Texture(data)  # type: ignore[abstract]
 
 
 def image_to_texture(image):
@@ -642,7 +650,7 @@ def image_to_texture(image):
 
     Parameters
     ----------
-    image : pyvista.ImageData | vtkImageData
+    image : pyvista.ImageData | :vtk:`vtkImageData`
         Image to convert.
 
     Returns
@@ -651,7 +659,7 @@ def image_to_texture(image):
         The texture.
 
     """
-    return Texture(image)
+    return Texture(image)  # type: ignore[abstract]
 
 
 def numpy_to_texture(image):
@@ -685,4 +693,4 @@ def numpy_to_texture(image):
             UserWarning,
         )
 
-    return Texture(image)
+    return Texture(image)  # type: ignore[abstract]
