@@ -3,31 +3,32 @@
 from __future__ import annotations
 
 from typing import TYPE_CHECKING
-from typing import Optional
 from typing import cast
 
 import numpy as np
 
 import pyvista
+from pyvista._deprecate_positional_args import _deprecate_positional_args
 from pyvista.core.utilities.arrays import point_array
 from pyvista.core.utilities.helpers import wrap
 from pyvista.plotting import _vtk
 
-if TYPE_CHECKING:  # pragma: no cover
+if TYPE_CHECKING:
+    from pyvista import ImageData
     from pyvista.core._typing_core import NumpyArray
 
 
 def remove_alpha(img):
-    """Remove the alpha channel from a ``vtk.vtkImageData``.
+    """Remove the alpha channel from a :vtk:`vtkImageData`.
 
     Parameters
     ----------
-    img : vtk.vtkImageData
+    img : :vtk:`vtkImageData`
         The input image data with an alpha channel.
 
     Returns
     -------
-    pyvista.ImageData
+    ImageData
         The output image data with the alpha channel removed.
 
     """
@@ -61,11 +62,14 @@ def wrap_image_array(arr):
 
     """
     if arr.ndim != 3:
-        raise ValueError('Expecting a X by Y by (3 or 4) array')
+        msg = 'Expecting a X by Y by (3 or 4) array'
+        raise ValueError(msg)
     if arr.shape[2] not in [3, 4]:
-        raise ValueError('Expecting a X by Y by (3 or 4) array')
+        msg = 'Expecting a X by Y by (3 or 4) array'
+        raise ValueError(msg)
     if arr.dtype != np.uint8:
-        raise ValueError('Expecting a np.uint8 array')
+        msg = 'Expecting a np.uint8 array'
+        raise ValueError(msg)
 
     img = _vtk.vtkImageData()
     img.SetDimensions(arr.shape[1], arr.shape[0], 1)
@@ -75,12 +79,12 @@ def wrap_image_array(arr):
 
 
 def run_image_filter(imfilter: _vtk.vtkWindowToImageFilter) -> NumpyArray[float]:
-    """Run a ``vtkWindowToImageFilter`` and get output as array.
+    """Run a :vtk:`vtkWindowToImageFilter` and get output as array.
 
     Parameters
     ----------
-    imfilter : _vtk.vtkWindowToImageFilter
-        The ``vtkWindowToImageFilter`` instance to be processed.
+    imfilter : :vtk:`vtkWindowToImageFilter`
+        The :vtk:`vtkWindowToImageFilter` instance to be processed.
 
     Notes
     -----
@@ -97,22 +101,28 @@ def run_image_filter(imfilter: _vtk.vtkWindowToImageFilter) -> NumpyArray[float]
     # Update filter and grab pixels
     imfilter.Modified()
     imfilter.Update()
-    image = cast(Optional[pyvista.ImageData], wrap(imfilter.GetOutput()))
+    image = cast('ImageData | None', wrap(imfilter.GetOutput()))
     if image is None:
         return np.empty((0, 0, 0))
     img_size = image.dimensions
-    img_array = point_array(image, 'ImageScalars')
+    img_array = cast('NumpyArray[float]', point_array(image, 'ImageScalars'))
     # Reshape and write
     tgt_size = (img_size[1], img_size[0], -1)
     return img_array.reshape(tgt_size)[::-1]
 
 
-def image_from_window(render_window, as_vtk=False, ignore_alpha=False, scale=1):
+@_deprecate_positional_args(allowed=['render_window'])
+def image_from_window(  # noqa: PLR0917
+    render_window,
+    as_vtk: bool = False,  # noqa: FBT001, FBT002
+    ignore_alpha: bool = False,  # noqa: FBT001, FBT002
+    scale=1,
+):
     """Extract the image from the render window as an array.
 
     Parameters
     ----------
-    render_window : vtk.vtkRenderWindow
+    render_window : :vtk:`vtkRenderWindow`
         The render window to extract the image from.
 
     as_vtk : bool, default: False
@@ -128,7 +138,7 @@ def image_from_window(render_window, as_vtk=False, ignore_alpha=False, scale=1):
 
     Returns
     -------
-    ndarray | vtk.vtkImageData
+    ndarray | :vtk:`vtkImageData`
         The image as an array or as a VTK object depending on the ``as_vtk`` parameter.
 
     """
@@ -155,18 +165,24 @@ def image_from_window(render_window, as_vtk=False, ignore_alpha=False, scale=1):
     return data
 
 
-def compare_images(im1, im2, threshold=1, use_vtk=True):
+@_deprecate_positional_args(allowed=['im1', 'im2'])
+def compare_images(  # noqa: PLR0917
+    im1,
+    im2,
+    threshold=1,
+    use_vtk: bool = True,  # noqa: FBT001, FBT002
+):
     """Compare two different images of the same size.
 
     Parameters
     ----------
-    im1 : str | numpy.ndarray | vtkRenderWindow | vtkImageData
+    im1 : str | numpy.ndarray | :vtk:`vtkRenderWindow` | :vtk:`vtkImageData`
         Render window, numpy array representing the output of a render
-        window, or ``vtkImageData``.
+        window, or :vtk:`vtkImageData`.
 
-    im2 : str | numpy.ndarray | vtkRenderWindow | vtkImageData
+    im2 : str | numpy.ndarray | :vtk:`vtkRenderWindow` | :vtk:`vtkImageData`
         Render window, numpy array representing the output of a render
-        window, or ``vtkImageData``.
+        window, or :vtk:`vtkImageData`.
 
     threshold : int, default: 1
         Threshold tolerance for pixel differences.  This should be
@@ -178,7 +194,7 @@ def compare_images(im1, im2, threshold=1, use_vtk=True):
         image using numpy.  The difference between pixel is calculated
         for each RGB channel, summed, and then divided by the number
         of pixels.  This is faster than using
-        ``vtk.vtkImageDifference`` but potentially less accurate.
+        :vtk:`vtkImageDifference` but potentially less accurate.
 
     Returns
     -------
@@ -205,12 +221,12 @@ def compare_images(im1, im2, threshold=1, use_vtk=True):
     >>> pv.compare_images(img1, img2)  # doctest:+SKIP
 
     """
-    from pyvista import ImageData
-    from pyvista import Plotter
-    from pyvista import read
-    from pyvista import wrap
+    from pyvista import ImageData  # noqa: PLC0415
+    from pyvista import Plotter  # noqa: PLC0415
+    from pyvista import read  # noqa: PLC0415
+    from pyvista import wrap  # noqa: PLC0415
 
-    def to_img(img):  # numpydoc ignore=GL08
+    def to_img(img):
         if isinstance(img, ImageData):  # pragma: no cover
             return img
         elif isinstance(img, _vtk.vtkImageData):
@@ -224,21 +240,22 @@ def compare_images(im1, im2, threshold=1, use_vtk=True):
                 img._on_first_render_request()
                 img.render()
             if img.render_window is None:
-                raise RuntimeError(
-                    'Unable to extract image from Plotter as it has already been closed.',
-                )
-            return image_from_window(img.render_window, True, ignore_alpha=True)
+                msg = 'Unable to extract image from Plotter as it has already been closed.'
+                raise RuntimeError(msg)
+            return image_from_window(img.render_window, as_vtk=True, ignore_alpha=True)
         else:
-            raise TypeError(
+            msg = (
                 f'Unsupported data type {type(img)}.  Should be '
-                'Either a np.ndarray, vtkRenderWindow, or vtkImageData',
+                'Either a np.ndarray, vtkRenderWindow, or vtkImageData'
             )
+            raise TypeError(msg)
 
     im1 = remove_alpha(to_img(im1))
     im2 = remove_alpha(to_img(im2))
 
     if im1.GetDimensions() != im2.GetDimensions():
-        raise RuntimeError('Input images are not the same size.')
+        msg = 'Input images are not the same size.'
+        raise RuntimeError(msg)
 
     if use_vtk:
         img_diff = _vtk.vtkImageDifference()
