@@ -1,16 +1,18 @@
-"""This module contains the VolumeProperty class."""
+"""Wrapper for :vtk:`vtkVolumeProperty`."""
 
 from __future__ import annotations
 
+import weakref
+
 import pyvista
-from pyvista.core.utilities.misc import no_new_attr
+from pyvista._deprecate_positional_args import _deprecate_positional_args
+from pyvista.core.utilities.misc import _NoNewAttrMixin
 
 from . import _vtk
 
 
-@no_new_attr
-class VolumeProperty(_vtk.vtkVolumeProperty):
-    """Wrap the VTK class vtkVolumeProperty.
+class VolumeProperty(_NoNewAttrMixin, _vtk.DisableVtkSnakeCase, _vtk.vtkVolumeProperty):
+    """Wrap the VTK class :vtk:`vtkVolumeProperty`.
 
     This class is used to represent common properties associated with volume
     rendering. This includes properties for determining the type of
@@ -67,21 +69,19 @@ class VolumeProperty(_vtk.vtkVolumeProperty):
     >>> import pyvista as pv
     >>> noise = pv.perlin_noise(1, (1, 3, 5), (0, 0, 0))
     >>> grid = pv.sample_function(
-    ...     noise, [0, 3.0, -0, 1.0, 0, 1.0], dim=(40, 40, 40)
+    ...     noise, bounds=[0, 3.0, -0, 1.0, 0, 1.0], dim=(40, 40, 40)
     ... )
-    >>> grid['scalars'] -= grid['scalars'].min()
-    >>> grid['scalars'] *= 255 / grid['scalars'].max()
     >>> pl = pv.Plotter()
     >>> actor = pl.add_volume(grid, show_scalar_bar=False)
-    >>> lut = pv.LookupTable(cmap='bwr')
+    >>> lut = actor.mapper.lookup_table
+    >>> lut.cmap = 'bwr'
     >>> lut.apply_opacity([1.0, 0.0, 0.0, 0.3, 0.0, 0.0, 0.0, 0.3])
-    >>> actor.prop.apply_lookup_table(lut)
     >>> pl.show()
 
-
     """
 
-    def __init__(
+    @_deprecate_positional_args
+    def __init__(  # noqa: PLR0917
         self,
         lookup_table=None,
         interpolation_type=None,
@@ -92,8 +92,10 @@ class VolumeProperty(_vtk.vtkVolumeProperty):
         shade=None,
         opacity_unit_distance=None,
     ):
-        """Initialize the vtkVolumeProperty class."""
+        """Initialize the :vtk:`vtkVolumeProperty` class."""
         super().__init__()
+        self._lookup_table_ = None
+        self._lookup_table_observer_id = None
         if lookup_table is not None:
             self.apply_lookup_table(lookup_table)
         if interpolation_type is not None:
@@ -111,6 +113,42 @@ class VolumeProperty(_vtk.vtkVolumeProperty):
         if opacity_unit_distance is not None:
             self.opacity_unit_distance = opacity_unit_distance
 
+    @property
+    def _lookup_table(self) -> pyvista.LookupTable | None:
+        """Get the lookup table if applied via apply_lookup_table."""
+        if self._lookup_table_ is not None:
+            return self._lookup_table_()
+        return None
+
+    @_lookup_table.setter
+    def _lookup_table(self, lookup_table: pyvista.LookupTable):
+        """Set the lookup table if applied via apply_lookup_table."""
+        if self._lookup_table is not None and self._lookup_table_observer_id is not None:
+            # Clean up the old lookup table observer
+            self._lookup_table.RemoveObserver(self._lookup_table_observer_id)
+            self._lookup_table_observer_id = None
+        self._lookup_table_ = weakref.ref(lookup_table)
+        self._lookup_table_observer_id = lookup_table.AddObserver(
+            _vtk.vtkCommand.ModifiedEvent,
+            lambda *_: self.reapply_lookup_table(),
+        )
+
+    def reapply_lookup_table(self):
+        """Reapply the lookup table previously applied.
+
+        The VolumeProperty is unable to keep a dynamic link to the colors
+        and mapping laid out in the lookup table. This method allows you to
+        reapply the lookup table to the VolumeProperty. This is useful if
+        you modify the lookup table after it is applied to the
+        VolumeProperty.
+
+        We have our own modified event observer to reapply this automatically
+        when the lookup table is modified.
+
+        """
+        if self._lookup_table is not None:
+            self.apply_lookup_table(self._lookup_table)
+
     def apply_lookup_table(self, lookup_table: pyvista.LookupTable):
         """Apply a lookup table to the volume property.
 
@@ -129,24 +167,31 @@ class VolumeProperty(_vtk.vtkVolumeProperty):
         >>> import pyvista as pv
         >>> noise = pv.perlin_noise(1, (1, 3, 5), (0, 0, 0))
         >>> grid = pv.sample_function(
-        ...     noise, [0, 3.0, -0, 1.0, 0, 1.0], dim=(40, 40, 40)
+        ...     noise, bounds=[0, 3.0, -0, 1.0, 0, 1.0], dim=(40, 40, 40)
         ... )
-        >>> grid['scalars'] -= grid['scalars'].min()
-        >>> grid['scalars'] *= 255 / grid['scalars'].max()
         >>> pl = pv.Plotter()
         >>> actor = pl.add_volume(grid, show_scalar_bar=False)
-        >>> lut = pv.LookupTable(cmap='bwr')
+        >>> lut = actor.mapper.lookup_table
+        >>> lut.cmap = 'bwr'
         >>> lut.apply_opacity([1.0, 0.0, 0.0, 0.3, 0.0, 0.0, 0.0, 0.3])
-        >>> actor.prop.apply_lookup_table(lut)
         >>> pl.show()
 
         """
         if not isinstance(lookup_table, pyvista.LookupTable):
-            raise TypeError('`lookup_table` must be a `pyvista.LookupTable`')
-
+            msg = '`lookup_table` must be a `pyvista.LookupTable`'
+            raise TypeError(msg)
+        if self._lookup_table != lookup_table:
+            self._lookup_table = lookup_table
         self.SetColor(lookup_table.to_color_tf())
         self.SetScalarOpacity(lookup_table.to_opacity_tf())
 
+    def __del__(self):
+        """Clean up the lookup table observer when the object is deleted."""
+        if self._lookup_table_observer_id is not None and self._lookup_table is not None:
+            self._lookup_table.RemoveObserver(self._lookup_table_observer_id)
+            self._lookup_table_observer_id = None
+        self._lookup_table_ = None
+
     @property
     def interpolation_type(self) -> str:  # numpydoc ignore=RT01
         """Return or set the interpolation type.
@@ -194,13 +239,14 @@ class VolumeProperty(_vtk.vtkVolumeProperty):
         return self.GetInterpolationTypeAsString().split()[0].lower()
 
     @interpolation_type.setter
-    def interpolation_type(self, value: str):  # numpydoc ignore=GL08
+    def interpolation_type(self, value: str):
         if value == 'linear':
             self.SetInterpolationTypeToLinear()
         elif value == 'nearest':
             self.SetInterpolationTypeToNearest()
         else:
-            raise ValueError('`interpolation_type` must be either "linear" or "nearest"')
+            msg = '`interpolation_type` must be either "linear" or "nearest"'
+            raise ValueError(msg)
 
     @property
     def opacity_unit_distance(self) -> float:  # numpydoc ignore=RT01
@@ -216,7 +262,7 @@ class VolumeProperty(_vtk.vtkVolumeProperty):
         return self.GetScalarOpacityUnitDistance()
 
     @opacity_unit_distance.setter
-    def opacity_unit_distance(self, value: float):  # numpydoc ignore=GL08
+    def opacity_unit_distance(self, value: float):
         self.SetScalarOpacityUnitDistance(value)
 
     @property
@@ -236,7 +282,7 @@ class VolumeProperty(_vtk.vtkVolumeProperty):
         return bool(self.GetShade())
 
     @shade.setter
-    def shade(self, value: bool):  # numpydoc ignore=GL08
+    def shade(self, value: bool):
         self.SetShade(value)
 
     @property
@@ -262,7 +308,7 @@ class VolumeProperty(_vtk.vtkVolumeProperty):
         return bool(self.GetIndependentComponents())
 
     @independent_components.setter
-    def independent_components(self, value: bool):  # numpydoc ignore=GL08
+    def independent_components(self, value: bool):
         self.SetIndependentComponents(value)
 
     @property
@@ -280,7 +326,7 @@ class VolumeProperty(_vtk.vtkVolumeProperty):
         return self.GetAmbient()
 
     @ambient.setter
-    def ambient(self, value: float):  # numpydoc ignore=GL08
+    def ambient(self, value: float):
         self.SetAmbient(value)
 
     @property
@@ -298,7 +344,7 @@ class VolumeProperty(_vtk.vtkVolumeProperty):
         return self.GetDiffuse()
 
     @diffuse.setter
-    def diffuse(self, value: float):  # numpydoc ignore=GL08
+    def diffuse(self, value: float):
         self.SetDiffuse(value)
 
     @property
@@ -317,7 +363,7 @@ class VolumeProperty(_vtk.vtkVolumeProperty):
         return self.GetSpecular()
 
     @specular.setter
-    def specular(self, value: float):  # numpydoc ignore=GL08
+    def specular(self, value: float):
         self.SetSpecular(value)
 
     @property
@@ -330,7 +376,7 @@ class VolumeProperty(_vtk.vtkVolumeProperty):
         return self.GetSpecularPower()
 
     @specular_power.setter
-    def specular_power(self, value: float):  # numpydoc ignore=GL08
+    def specular_power(self, value: float):
         self.SetSpecularPower(value)
 
     def copy(self) -> VolumeProperty:
