@@ -5,12 +5,15 @@ from __future__ import annotations
 import asyncio
 import logging
 import os
+from typing import TYPE_CHECKING
+from typing import Literal
 import warnings
 
 from trame.widgets import html as html_widgets
 from trame.widgets import vtk as vtk_widgets
 from trame.widgets import vuetify as vuetify2_widgets
 from trame.widgets import vuetify3 as vuetify3_widgets
+from typing_extensions import Concatenate
 
 try:
     from ipywidgets.widgets import HTML
@@ -24,6 +27,15 @@ from pyvista.trame.ui import get_viewer
 from pyvista.trame.views import CLOSED_PLOTTER_ERROR
 from pyvista.trame.views import get_server
 
+if TYPE_CHECKING:
+    from collections.abc import Callable
+
+    from IPython.display import IFrame
+
+    from pyvista.jupyter import JupyterBackendOptions
+    from pyvista.plotting.plotter import Plotter
+    from pyvista.trame.ui.vuetify2 import Viewer
+
 SERVER_DOWN_MESSAGE = """Trame server has not launched.
 
 You must start the trame server before attempting to `show()`
@@ -37,7 +49,8 @@ You can use the following snippet to launch the server:
 """
 JUPYTER_SERVER_DOWN_MESSAGE = """Trame server has not launched.
 
-Prior to plotting, please make sure to run `set_jupyter_backend('trame')` when using the `'trame'`, `'server'`, or `'client'` Jupyter backends.
+Prior to plotting, please make sure to run `set_jupyter_backend('trame')` when using the
+`'trame'`, `'server'`, or `'client'` Jupyter backends.
 
     import pyvista as pv
     pyvista.set_jupyter_backend('trame')
@@ -69,29 +82,30 @@ class TrameJupyterServerDownError(RuntimeError):
         super().__init__(JUPYTER_SERVER_DOWN_MESSAGE)
 
 
-class Widget(HTML):  # numpydoc ignore=PR01
+class Widget(HTML):  # type: ignore[misc]  # numpydoc ignore=PR01
     """Custom HTML iframe widget for trame viewer."""
 
     def __init__(self, viewer, src, width=None, height=None, iframe_attrs=None, **kwargs):
         """Initialize."""
         if HTML is object:
-            raise ImportError('Please install `ipywidgets`.')
+            msg = 'Please install `ipywidgets`.'
+            raise ImportError(msg)
         # eventually we could maybe expose this, but for now make sure we're at least
         # consistent with matplotlib's color (light gray)
 
         if iframe_attrs is None:
             iframe_attrs = {}
 
-        border = "border: 1px solid rgb(221,221,221);"
+        border = 'border: 1px solid rgb(221,221,221);'
 
         iframe_attrs = {
             **iframe_attrs,
-            "src": src,
-            "class": "pyvista",
-            "style": f"width: {width}; height: {height}; {border}",
+            'src': src,
+            'class': 'pyvista',
+            'style': f'width: {width}; height: {height}; {border}',
         }
 
-        iframe_attrs_str = " ".join(f'{key}="{value!s}"' for key, value in iframe_attrs.items())
+        iframe_attrs_str = ' '.join(f'{key}="{value!s}"' for key, value in iframe_attrs.items())
 
         value = f'<iframe {iframe_attrs_str}></iframe>'
 
@@ -110,19 +124,23 @@ class Widget(HTML):  # numpydoc ignore=PR01
         return self._src
 
 
-class EmbeddableWidget(HTML):  # numpydoc ignore=PR01
+class EmbeddableWidget(HTML):  # type: ignore[misc]  # numpydoc ignore=PR01
     """Custom HTML iframe widget for embedding the trame viewer."""
 
     def __init__(self, plotter, width, height, **kwargs):
         """Initialize."""
         if HTML is object:
-            raise ImportError('Please install `ipywidgets`.')
+            msg = 'Please install `ipywidgets`.'
+            raise ImportError(msg)
         scene = plotter.export_html(filename=None)
         src = scene.getvalue().replace('"', '&quot;')
         # eventually we could maybe expose this, but for now make sure we're at least
         # consistent with matplotlib's color (light gray)
-        border = "border: 1px solid rgb(221,221,221);"
-        value = f'<iframe srcdoc="{src}" class="pyvista" style="width: {width}; height: {height}; {border}"></iframe>'
+        border = 'border: 1px solid rgb(221,221,221);'
+        value = (
+            f'<iframe srcdoc="{src}" class="pyvista" style="width: {width}; '
+            f'height: {height}; {border}"></iframe>'
+        )
         super().__init__(value, **kwargs)
         self._src = src
 
@@ -150,7 +168,9 @@ def launch_server(server=None, port=None, host=None, wslink_backend=None, **kwar
 
     wslink_backend : str, optional
         The wslink backend that the server should use
-        ``aiohttp`` by default, ``jupyter`` if the `trame_jupyter_extension <https://github.com/Kitware/trame-jupyter-extension>`_ is used.
+        ``aiohttp`` by default, ``jupyter`` if the
+        `trame_jupyter_extension <https://github.com/Kitware/trame-jupyter-extension>`_
+        is used.
 
     **kwargs : dict, optional
         Any additional keyword arguments to pass to ``pyvista.trame.views.get_server``.
@@ -174,7 +194,7 @@ def launch_server(server=None, port=None, host=None, wslink_backend=None, **kwar
     if (
         wslink_backend is None and pyvista.global_theme.trame.jupyter_extension_enabled
     ):  # pragma: no cover
-        wslink_backend = "jupyter"
+        wslink_backend = 'jupyter'
 
     # Must enable all used modules
     html_widgets.initialize(server)
@@ -185,7 +205,7 @@ def launch_server(server=None, port=None, host=None, wslink_backend=None, **kwar
     else:
         vuetify3_widgets.initialize(server)
 
-    def on_ready(**_):  # numpydoc ignore=GL08
+    def on_ready(**_):
         logger.debug(f'Server ready: {server}')
 
     if server._running_stage == 0:
@@ -220,9 +240,8 @@ def build_url(
         if server_proxy_prefix is None:
             server_proxy_prefix = pyvista.global_theme.trame.server_proxy_prefix
         # server_proxy_prefix assumes trailing slash
-        src = (
-            f"{server_proxy_prefix if server_proxy_prefix else ''}{_server.port}/index.html{params}"
-        )
+        prefix = server_proxy_prefix if server_proxy_prefix else ''
+        src = f'{prefix}{_server.port}/index.html{params}'
     else:
         src = f'{protocol}://{host}:{_server.port}/index.html{params}'
     logger.debug(src)
@@ -260,19 +279,20 @@ def initialize(
 
 
 def show_trame(
-    plotter,
-    mode=None,
-    name=None,
-    server_proxy_enabled=None,
-    server_proxy_prefix=None,
-    jupyter_extension_enabled=None,
-    collapse_menu=False,
-    add_menu=True,
-    add_menu_items=None,
-    default_server_rendering=True,
-    handler=None,
+    plotter: Plotter,
+    mode: JupyterBackendOptions | None = None,
+    name: str | None = None,
+    server_proxy_enabled: bool | None = None,
+    server_proxy_prefix: str | None = None,
+    jupyter_extension_enabled: bool | None = None,
+    collapse_menu: bool = False,
+    add_menu: bool = True,
+    add_menu_items: Callable[[Literal['trame', 'server', 'client'], bool, bool], None]
+    | None = None,
+    default_server_rendering: bool = True,
+    handler: Callable[Concatenate[Viewer, str, ...], IFrame] | None = None,
     **kwargs,
-):
+) -> EmbeddableWidget | IFrame | Widget:
     """Run and display the trame application in jupyter's event loop.
 
     Parameters
@@ -323,7 +343,7 @@ def show_trame(
         Pass a callable that accptes the viewer instance, the string URL,
         and ``**kwargs`` to create custom HTML representations of the output.
 
-        .. code:: python
+        .. code-block:: python
 
             import pyvista as pv
             from IPython.display import IFrame
@@ -362,9 +382,9 @@ def show_trame(
     if plotter._window_size_unset:
         dw, dh = '99%', '600px'
     else:
-        dw, dh = plotter.window_size
-        dw = f'{dw}px'
-        dh = f'{dh}px'
+        width, height = plotter.window_size
+        dw = f'{width}px'
+        dh = f'{height}px'
     kwargs.setdefault('width', dw)
     kwargs.setdefault('height', dh)
 
@@ -379,9 +399,9 @@ def show_trame(
     else:
         server = get_server(name=name)
     if name is None and not server.running:
-        wslink_backend = "aiohttp"
+        wslink_backend = 'aiohttp'
         if jupyter_extension_enabled:  # pragma: no cover
-            wslink_backend = "jupyter"
+            wslink_backend = 'jupyter'
 
         elegantly_launch(server, wslink_backend=wslink_backend)
         if not server.running:  # pragma: no cover
@@ -401,10 +421,10 @@ def show_trame(
     )
 
     if jupyter_extension_enabled:  # pragma: no cover
-        from trame_client.ui.core import iframe_url_builder_jupyter_extension
+        from trame_client.ui.core import iframe_url_builder_jupyter_extension  # noqa: PLC0415
 
         iframe_attrs = iframe_url_builder_jupyter_extension(viewer.layout)
-        src = iframe_attrs["src"]
+        src = iframe_attrs['src']
     else:
         # TODO: The build_url function could possibly be replaced by
         # trame's upstream url builders in trame_client.ui.core
@@ -446,17 +466,17 @@ def elegantly_launch(*args, **kwargs):  # numpydoc ignore=PR01
 
     """
     try:
-        import nest_asyncio
+        import nest_asyncio  # noqa: PLC0415
     except ImportError:
-        raise ImportError(
-            """Please install `nest_asyncio` to automagically launch the trame server without await. Or, to avoid `nest_asynctio` run:
-
-    from pyvista.trame.jupyter import launch_server
-    await launch_server().ready
-""",
+        msg = (
+            'Please install `nest_asyncio` to automagically launch the trame server '
+            'without await. Or, to avoid `nest_asynctio` run:\n\n'
+            'from pyvista.trame.jupyter import launch_server\n'
+            'await launch_server().ready'
         )
+        raise ImportError(msg)
 
-    async def launch_it():  # numpydoc ignore=GL08
+    async def launch_it():
         await launch_server(*args, **kwargs).ready
 
     # Basically monkey patches asyncio to support this
