@@ -1,7 +1,6 @@
 from __future__ import annotations
 
-import os
-import platform
+import re
 from string import ascii_letters
 from string import digits
 from string import whitespace
@@ -18,28 +17,21 @@ import numpy as np
 import pytest
 
 import pyvista as pv
-from pyvista.core.errors import PyVistaDeprecationWarning
 from pyvista.core.utilities.arrays import FieldAssociation
 from pyvista.core.utilities.arrays import convert_array
 
-skip_windows = pytest.mark.skipif(os.name == 'nt', reason='Test fails on Windows')
-skip_apple_silicon = pytest.mark.skipif(
-    platform.system() == 'Darwin' and platform.processor() == 'arm',
-    reason='Test fails on Apple Silicon',
-)
 
-
-@pytest.fixture()
+@pytest.fixture
 def hexbeam_point_attributes(hexbeam):
     return hexbeam.point_data
 
 
-@pytest.fixture()
+@pytest.fixture
 def hexbeam_field_attributes(hexbeam):
     return hexbeam.field_data
 
 
-@pytest.fixture()
+@pytest.fixture
 def insert_arange_narray(hexbeam_point_attributes):
     n_points = hexbeam_point_attributes.dataset.GetNumberOfPoints()
     sample_array = np.arange(n_points)
@@ -47,7 +39,7 @@ def insert_arange_narray(hexbeam_point_attributes):
     return hexbeam_point_attributes, sample_array
 
 
-@pytest.fixture()
+@pytest.fixture
 def insert_bool_array(hexbeam_point_attributes):
     n_points = hexbeam_point_attributes.dataset.GetNumberOfPoints()
     sample_array = np.ones(n_points, np.bool_)
@@ -55,14 +47,20 @@ def insert_bool_array(hexbeam_point_attributes):
     return hexbeam_point_attributes, sample_array
 
 
-@pytest.fixture()
+@pytest.fixture
 def insert_string_array(hexbeam_point_attributes):
     n_points = hexbeam_point_attributes.dataset.GetNumberOfPoints()
-    sample_array = np.repeat("A", n_points)
+    sample_array = np.repeat('A', n_points)
     hexbeam_point_attributes.set_array(sample_array, 'sample_array')
     return hexbeam_point_attributes, sample_array
 
 
+@pytest.mark.parametrize('i', [1, None, object(), True])
+def test_setitem_raises(i):
+    with pytest.raises(TypeError, match='Only strings are valid keys for DataSetAttributes.'):
+        pv.Sphere().point_data[i] = 1
+
+
 def test_init(hexbeam):
     attributes = pv.DataSetAttributes(
         hexbeam.GetPointData(),
@@ -171,6 +169,29 @@ def test_active_scalars_name(sphere):
     assert sphere.point_data.active_scalars_name is None
 
 
+def test_active_normals_name():
+    # Load dataset known to have active normals by default
+    sphere = pv.Sphere()
+    assert sphere.point_data._active_normals_name == 'Normals'
+    sphere.clear_data()
+    assert sphere.point_data._active_normals_name is None
+
+    # Set name of custom normals
+    key = 'data0'
+    normals = np.array([[0, 1, 0]] * sphere.n_points)
+    sphere.point_data[key] = normals
+    assert sphere.point_data._active_normals_name is None
+    sphere.point_data._active_normals_name = key
+    assert sphere.point_data._active_normals_name == 'data0'
+
+    # Test raises
+    sphere.point_data[key] = range(sphere.n_points)
+    with pytest.raises(ValueError, match=re.escape('data0 needs 3 components, has (1)')):
+        sphere.point_data._active_normals_name = key
+    with pytest.raises(KeyError, match='DataSetAttribute does not contain "foobar"'):
+        sphere.point_data._active_normals_name = 'foobar'
+
+
 def test_set_scalars(sphere):
     scalars = np.array(sphere.n_points)
     key = 'scalars'
@@ -502,7 +523,8 @@ def test_value_should_exist(insert_arange_narray):
     for arr in dsa.values():
         if np.array_equal(sample_array, arr):
             return
-    raise AssertionError('Array not in values.')
+    msg = 'Array not in values.'
+    raise AssertionError(msg)
 
 
 def test_active_scalars_setter(hexbeam_point_attributes):
@@ -526,18 +548,18 @@ def test_active_scalars_setter_no_override(hexbeam):
 def test_preserve_field_data_after_extract_cells(hexbeam, arr):
     if not ''.join(arr).isascii():
         with pytest.raises(ValueError, match='non-ASCII'):
-            hexbeam.field_data["foo"] = arr
+            hexbeam.field_data['foo'] = arr
         return
 
     # https://github.com/pyvista/pyvista/pull/934
-    hexbeam.field_data["foo"] = arr
+    hexbeam.field_data['foo'] = arr
     extracted = hexbeam.extract_cells([0, 1, 2, 3])
-    assert "foo" in extracted.field_data
+    assert 'foo' in extracted.field_data
 
 
 def test_assign_labels_to_points(hexbeam):
     hexbeam.point_data.clear()
-    labels = [f"Label {i}" for i in range(hexbeam.n_points)]
+    labels = [f'Label {i}' for i in range(hexbeam.n_points)]
     hexbeam['labels'] = labels
     assert (hexbeam['labels'] == labels).all()
 
@@ -555,8 +577,11 @@ def test_normals_get(plane):
 
 def test_normals_set():
     plane = pv.Plane(i_resolution=1, j_resolution=1)
-    plane.point_data.normals = plane.point_normals
-    assert np.array_equal(plane.point_data.active_normals, plane.point_normals)
+    plane.clear_data()
+    assert plane.active_normals is None
+    new_normals = np.zeros((plane.n_points, 3))
+    plane.point_data.active_normals = new_normals
+    assert np.array_equal(plane.point_data.active_normals, new_normals)
 
     with pytest.raises(ValueError, match='must be a 2-dim'):
         plane.point_data.active_normals = [1]
@@ -636,8 +661,8 @@ def test_active_texture_coordinates_name(plane):
         plane.field_data.active_texture_coordinates_name = 'arr'
 
 
-@skip_windows  # windows doesn't support np.complex256
-@skip_apple_silicon  # same with Apple silicon (M1/M2)
+@pytest.mark.skip_windows("windows doesn't support np.complex256")
+@pytest.mark.skip_mac('Test fails on Apple silicon (M1/M2)', processor='arm')
 def test_complex_raises(plane):
     with pytest.raises(ValueError, match='Only numpy.complex64'):
         plane.point_data['data'] = np.empty(plane.n_points, dtype=np.complex256)
@@ -653,7 +678,9 @@ def test_complex(plane, dtype_str):
         plane.point_data[name] = np.empty((plane.n_points, 2), dtype=dtype)
 
     real_type = np.float32 if dtype == np.complex64 else np.float64
-    data = np.random.default_rng().random((plane.n_points, 2)).astype(real_type).view(dtype).ravel()
+    data = (
+        np.random.default_rng().random((plane.n_points, 2)).astype(real_type).view(dtype).ravel()
+    )
     plane.point_data[name] = data
     assert np.array_equal(plane.point_data[name], data)
 
@@ -668,25 +695,28 @@ def test_complex(plane, dtype_str):
     assert np.issubdtype(plane.point_data[name].dtype, real_type)
 
 
-def test_active_t_coords_deprecated():
-    mesh = pv.Cube()
-    with pytest.warns(PyVistaDeprecationWarning, match='texture_coordinates'):
-        t_coords = mesh.point_data.active_t_coords
-        if pv._version.version_info >= (0, 46):
-            raise RuntimeError('Remove this deprecated property')
-    with pytest.warns(PyVistaDeprecationWarning, match='texture_coordinates'):
-        mesh.point_data.active_t_coords = t_coords
-        if pv._version.version_info >= (0, 46):
-            raise RuntimeError('Remove this deprecated property')
+@pytest.mark.parametrize('copy', [True, False])
+def test_update(uniform, copy):
+    new_mesh = pv.ImageData(dimensions=uniform.dimensions)
 
+    # Test point data
+    new_mesh.point_data.update(uniform.point_data, copy=copy)
+    for array_name in uniform.point_data.keys():
+        shares_memory = np.shares_memory(
+            new_mesh.point_data[array_name], uniform.point_data[array_name]
+        )
+        if copy:
+            assert not shares_memory
+        else:
+            assert shares_memory
 
-def test_active_t_coords_name_deprecated():
-    mesh = pv.Cube()
-    with pytest.warns(PyVistaDeprecationWarning, match='texture_coordinates'):
-        name = mesh.point_data.active_t_coords_name
-        if pv._version.version_info >= (0, 46):
-            raise RuntimeError('Remove this deprecated property')
-    with pytest.warns(PyVistaDeprecationWarning, match='texture_coordinates'):
-        mesh.point_data.active_t_coords_name = name
-        if pv._version.version_info >= (0, 46):
-            raise RuntimeError('Remove this deprecated property')
+    # Test cell data
+    new_mesh.cell_data.update(uniform.cell_data, copy=copy)
+    for array_name in uniform.cell_data.keys():
+        shares_memory = np.shares_memory(
+            new_mesh.cell_data[array_name], uniform.cell_data[array_name]
+        )
+        if copy:
+            assert not shares_memory
+        else:
+            assert shares_memory
