@@ -1,5 +1,8 @@
 from __future__ import annotations
 
+import re
+from typing import TYPE_CHECKING
+
 import numpy as np
 import pytest
 import trimesh
@@ -13,6 +16,9 @@ from pyvista.core.errors import MissingDataError
 from pyvista.core.utilities.arrays import set_default_active_scalars
 from pyvista.core.utilities.points import make_tri_mesh
 
+if TYPE_CHECKING:
+    from pytest_mock import MockerFixture
+
 
 def test_wrap_none():
     # check against the "None" edge case
@@ -24,6 +30,34 @@ def test_wrap_pyvista_ndarray(sphere):
     assert isinstance(pd, pv.PolyData)
 
 
+def test_wrap_raises():
+    with pytest.raises(
+        NotImplementedError,
+        match='NumPy array could not be wrapped pyvista.',
+    ):
+        pv.wrap(np.zeros((42, 42, 42, 42)))
+
+
+def test_wrap_vtk_not_supported_raises(mocker: MockerFixture):
+    m = mocker.patch.object(pv, '_wrappers')
+    m.__getitem__.side_effect = KeyError
+    m2 = mocker.MagicMock()
+    m2.GetClassName.return_value = (f := 'foo')
+
+    with pytest.raises(
+        TypeError,
+        match=re.escape(f'VTK data type ({f}) is not currently supported by pyvista.'),
+    ):
+        pv.wrap(m2)
+
+
+def test_wrap_raises_unable():
+    with pytest.raises(
+        NotImplementedError, match=re.escape("Unable to wrap (<class 'int'>) into a pyvista type.")
+    ):
+        pv.wrap(1)
+
+
 # NOTE: It's not necessary to test all data types here, several of the
 # most used ones.  We're just checking that we can wrap VTK data types.
 @pytest.mark.parametrize(
@@ -205,15 +239,15 @@ def test_set_default_active_vectors():
     assert mesh.active_vectors_name is None
 
     # Point data vectors
-    mesh["vec_point"] = np.ones((mesh.n_points, 3))
+    mesh['vec_point'] = np.ones((mesh.n_points, 3))
     pv.set_default_active_vectors(mesh)
-    assert mesh.active_vectors_name == "vec_point"
+    assert mesh.active_vectors_name == 'vec_point'
     mesh.clear_data()
 
     # Cell data vectors
-    mesh["vec_cell"] = np.ones((mesh.n_cells, 3))
+    mesh['vec_cell'] = np.ones((mesh.n_cells, 3))
     pv.set_default_active_vectors(mesh)
-    assert mesh.active_vectors_name == "vec_cell"
+    assert mesh.active_vectors_name == 'vec_cell'
     mesh.clear_data()
 
     # Raises if no data is present
@@ -222,30 +256,30 @@ def test_set_default_active_vectors():
     assert mesh.active_vectors_name is None
 
     # Raises if no vector-like data is present
-    mesh["scalar_data"] = np.ones((mesh.n_points, 1))
+    mesh['scalar_data'] = np.ones((mesh.n_points, 1))
     with pytest.raises(MissingDataError):
         pv.set_default_active_vectors(mesh)
     assert mesh.active_vectors_name is None
     mesh.clear_data()
 
     # Raises if multiple vector-like data is present
-    mesh["vec_data1"] = np.ones((mesh.n_points, 3))
-    mesh["vec_data2"] = np.ones((mesh.n_points, 3))
+    mesh['vec_data1'] = np.ones((mesh.n_points, 3))
+    mesh['vec_data2'] = np.ones((mesh.n_points, 3))
     with pytest.raises(AmbiguousDataError):
         pv.set_default_active_vectors(mesh)
     assert mesh.active_vectors_name is None
     mesh.clear_data()
 
     # Raises if multiple vector-like data in cell and point
-    mesh["vec_data1"] = np.ones((mesh.n_points, 3))
-    mesh["vec_data2"] = np.ones((mesh.n_cells, 3))
+    mesh['vec_data1'] = np.ones((mesh.n_points, 3))
+    mesh['vec_data2'] = np.ones((mesh.n_cells, 3))
     with pytest.raises(AmbiguousDataError):
         pv.set_default_active_vectors(mesh)
     assert mesh.active_vectors_name is None
 
     # Raises if multiple vector-like data with same name
-    mesh["vec_data"] = np.ones((mesh.n_points, 3))
-    mesh["vec_data"] = np.ones((mesh.n_cells, 3))
+    mesh['vec_data'] = np.ones((mesh.n_points, 3))
+    mesh['vec_data'] = np.ones((mesh.n_cells, 3))
     with pytest.raises(AmbiguousDataError):
         pv.set_default_active_vectors(mesh)
     assert mesh.active_vectors_name is None
@@ -258,31 +292,31 @@ def test_set_default_active_scalarrs():
     assert mesh.active_scalars_name is None
 
     # Point data scalars
-    mesh["scalar_point"] = np.ones(mesh.n_points)
+    mesh['scalar_point'] = np.ones(mesh.n_points)
     mesh.set_active_scalars(None)
     set_default_active_scalars(mesh)
-    assert mesh.active_scalars_name == "scalar_point"
+    assert mesh.active_scalars_name == 'scalar_point'
     mesh.clear_data()
 
     # Cell data scalars
-    mesh["scalar_cell"] = np.ones(mesh.n_cells)
+    mesh['scalar_cell'] = np.ones(mesh.n_cells)
     mesh.set_active_scalars(None)
     set_default_active_scalars(mesh)
-    assert mesh.active_scalars_name == "scalar_cell"
+    assert mesh.active_scalars_name == 'scalar_cell'
     mesh.clear_data()
 
     # Point data scalars multidimensional
-    mesh["scalar_point"] = np.ones((mesh.n_points, 3))
+    mesh['scalar_point'] = np.ones((mesh.n_points, 3))
     mesh.set_active_scalars(None)
     set_default_active_scalars(mesh)
-    assert mesh.active_scalars_name == "scalar_point"
+    assert mesh.active_scalars_name == 'scalar_point'
     mesh.clear_data()
 
     # Cell data scalars multidimensional
-    mesh["scalar_cell"] = np.ones((mesh.n_cells, 3))
+    mesh['scalar_cell'] = np.ones((mesh.n_cells, 3))
     mesh.set_active_scalars(None)
     set_default_active_scalars(mesh)
-    assert mesh.active_scalars_name == "scalar_cell"
+    assert mesh.active_scalars_name == 'scalar_cell'
     mesh.clear_data()
 
     # Raises if no data is present
@@ -291,8 +325,8 @@ def test_set_default_active_scalarrs():
     assert mesh.active_scalars_name is None
 
     # Raises if multiple scalar-like data is present
-    mesh["scalar_data1"] = np.ones(mesh.n_points)
-    mesh["scalar_data2"] = np.ones(mesh.n_points)
+    mesh['scalar_data1'] = np.ones(mesh.n_points)
+    mesh['scalar_data2'] = np.ones(mesh.n_points)
     mesh.set_active_scalars(None)
     with pytest.raises(AmbiguousDataError):
         set_default_active_scalars(mesh)
@@ -300,16 +334,16 @@ def test_set_default_active_scalarrs():
     mesh.clear_data()
 
     # Raises if multiple scalar-like data in cell and point
-    mesh["scalar_data1"] = np.ones(mesh.n_points)
-    mesh["scalar_data2"] = np.ones(mesh.n_cells)
+    mesh['scalar_data1'] = np.ones(mesh.n_points)
+    mesh['scalar_data2'] = np.ones(mesh.n_cells)
     mesh.set_active_scalars(None)
     with pytest.raises(AmbiguousDataError):
         set_default_active_scalars(mesh)
     assert mesh.active_scalars_name is None
 
     # Raises if multiple scalar-like data with same name
-    mesh["scalar_data"] = np.ones(mesh.n_points)
-    mesh["scalar_data"] = np.ones(mesh.n_cells)
+    mesh['scalar_data'] = np.ones(mesh.n_points)
+    mesh['scalar_data'] = np.ones(mesh.n_cells)
     mesh.set_active_scalars(None)
     with pytest.raises(AmbiguousDataError):
         set_default_active_scalars(mesh)
@@ -341,7 +375,7 @@ def test_vtk_points_deep_shallow():
 
 
 @pytest.mark.parametrize(
-    ("force_float", "expected_data_type"),
+    ('force_float', 'expected_data_type'),
     [(False, np.int64), (True, np.float32)],
 )
 def test_vtk_points_force_float(force_float, expected_data_type):
@@ -354,3 +388,10 @@ def test_vtk_points_force_float(force_float, expected_data_type):
     as_numpy = numpy_support.vtk_to_numpy(vtk_points.GetData())
 
     assert as_numpy.dtype == expected_data_type
+
+
+def test_vtk_points_allow_empty():
+    pv.vtk_points([], allow_empty=True)
+    match = 'points has shape (0,) which is not allowed. Shape must be one of [3, (-1, 3)].'
+    with pytest.raises(ValueError, match=re.escape(match)):
+        pv.vtk_points([], allow_empty=False)
