@@ -1,8 +1,8 @@
-# ruff: noqa: PTH102,PTH103,PTH107,PTH112,PTH113,PTH117,PTH118,PTH119,PTH122,PTH123,PTH202
 from __future__ import annotations
 
 from dataclasses import dataclass
 import inspect
+from itertools import starmap
 import os
 from pathlib import Path
 import shutil
@@ -27,8 +27,9 @@ from pyvista.examples._dataset_loader import _load_as_multiblock
 from pyvista.examples._dataset_loader import _MultiFileDownloadableDatasetLoader
 from pyvista.examples._dataset_loader import _SingleFileDatasetLoader
 from pyvista.examples._dataset_loader import _SingleFileDownloadableDatasetLoader
+from pyvista.examples.planets import _download_dataset_texture
 
-if TYPE_CHECKING:  # pragma: no cover
+if TYPE_CHECKING:
     from collections.abc import Callable
 
 
@@ -42,8 +43,7 @@ class DatasetLoaderTestCase:
 def _generate_dataset_loader_test_cases_from_module(
     module: ModuleType,
 ) -> list[DatasetLoaderTestCase]:
-    """Generate test cases by module with all dataset functions and their respective file loaders."""
-
+    # Generate test cases by module with all dataset functions and their respective file loaders.
     test_cases_dict: dict = {}
 
     def add_to_dict(func: str, dataset_function: Callable[[], Any]):
@@ -62,7 +62,8 @@ def _generate_dataset_loader_test_cases_from_module(
             dataset_name = func.split('load_')[1]
             key = 'dataset_function'
         else:
-            raise RuntimeError(f'Invalid case specified: {(func, dataset_function)}')
+            msg = f'Invalid case specified: {(func, dataset_function)}'
+            raise RuntimeError(msg)
         test_cases_dict.setdefault(dataset_name, {})
         test_cases_dict[dataset_name][key] = (func, dataset_function)
 
@@ -70,18 +71,14 @@ def _generate_dataset_loader_test_cases_from_module(
 
     # Collect all `download_<name> or `load_<name>` functions
     def _is_dataset_function(name, item):
-        return (
-            isinstance(item, FunctionType)
-            and name.startswith('download_')
-            or name.startswith('load_')
-        )
+        return isinstance(item, FunctionType) and name.startswith(('download_', 'load_'))
 
     dataset_functions = {
         name: item for name, item in module_members.items() if _is_dataset_function(name, item)
     }
     # Remove special case which is not a dataset function
     dataset_functions.pop('download_file', None)
-    [add_to_dict(name, func) for name, func in dataset_functions.items()]
+    list(starmap(add_to_dict, dataset_functions.items()))
 
     # Collect all `_dataset_<name>` file loaders
     dataset_file_loaders = {
@@ -89,7 +86,7 @@ def _generate_dataset_loader_test_cases_from_module(
         for name, item in module_members.items()
         if name.startswith('_dataset_') and isinstance(item, _DatasetLoader)
     }
-    [add_to_dict(name, func) for name, func in dataset_file_loaders.items()]
+    list(starmap(add_to_dict, dataset_file_loaders.items()))
 
     # Flatten dict
     test_cases_list: list[DatasetLoaderTestCase] = []
@@ -109,24 +106,27 @@ def _generate_dataset_loader_test_cases_from_module(
 def _get_mismatch_fail_msg(test_case: DatasetLoaderTestCase):
     if test_case.dataset_function is None:
         return (
-            f"A file loader:\n\t'{test_case.dataset_loader[0]}'\n\t{test_case.dataset_loader[1]}\n"
-            f"was found but is missing a corresponding download function.\n\n"
-            f"Expected to find a function named:\n\t'download_{test_case.dataset_name}'\nGot: {test_case.dataset_function}"
+            f"A file loader:\n\t'{test_case.dataset_loader[0]}'"
+            f'\n\t{test_case.dataset_loader[1]}\n'
+            f'was found but is missing a corresponding download function.\n\n'
+            f'Expected to find a function named:'
+            f"\n\t'download_{test_case.dataset_name}'\nGot: {test_case.dataset_function}"
         )
     elif test_case.dataset_loader is None:
         return (
-            f"A download function:\n\t'{test_case.dataset_function[0]}'\n\t{test_case.dataset_function[1]}\n"
-            f"was found but is missing a corresponding file loader.\n\n"
-            f"Expected to find a loader named:\n\t'_dataset_{test_case.dataset_name}'\nGot: {test_case.dataset_loader}"
+            f"A download function:\n\t'{test_case.dataset_function[0]}'"
+            f'\n\t{test_case.dataset_function[1]}\n'
+            f'was found but is missing a corresponding file loader.\n\n'
+            f'Expected to find a loader named:'
+            f"\n\t'_dataset_{test_case.dataset_name}'\nGot: {test_case.dataset_loader}"
         )
     else:
         return None
 
 
-@pytest.fixture()
+@pytest.fixture
 def examples_local_repository_tmp_dir(tmp_path):
     """Create a local repository with a bunch of datasets available for download."""
-
     # setup
     repository_path = os.path.join(tmp_path, 'repo')
     os.mkdir(repository_path)
@@ -152,7 +152,10 @@ def examples_local_repository_tmp_dir(tmp_path):
 
     # create a zipped copy of the datasets and include the zip with repository
     shutil.make_archive(os.path.join(tmp_path, 'archive'), 'zip', repository_path)
-    shutil.move(os.path.join(tmp_path, 'archive.zip'), os.path.join(repository_path, 'archive.zip'))
+    shutil.move(
+        os.path.join(tmp_path, 'archive.zip'),
+        os.path.join(repository_path, 'archive.zip'),
+    )
     downloadable_basenames.append('archive.zip')
 
     # initialize downloads fetcher
@@ -168,7 +171,7 @@ def examples_local_repository_tmp_dir(tmp_path):
     yield repository_path
 
     # teardown
-    downloads.FETCHER.base_url = "https://github.com/pyvista/vtk-data/raw/master/Data/"
+    downloads.FETCHER.base_url = 'https://github.com/pyvista/vtk-data/raw/master/Data/'
     downloads._FILE_CACHE = False
     [downloads.FETCHER.registry.pop(base, None) for base in downloadable_basenames]
 
@@ -176,18 +179,19 @@ def examples_local_repository_tmp_dir(tmp_path):
     [os.remove(file) for file in cached_paths if os.path.isfile(file)]
 
 
+@pytest.mark.usefixtures('examples_local_repository_tmp_dir')
 @pytest.mark.parametrize('use_archive', [True, False])
 @pytest.mark.parametrize(
-    'FileLoader',
+    'file_loader',
     [_SingleFileDatasetLoader, _DownloadableFile, _SingleFileDownloadableDatasetLoader],
 )
-def test_single_file_loader(FileLoader, use_archive, examples_local_repository_tmp_dir):
+def test_single_file_loader(file_loader, use_archive):
     basename = 'pyvista_logo.png'
-    if use_archive and isinstance(FileLoader, _Downloadable):
-        file_loader = FileLoader('archive.zip', target_file=basename)
+    if use_archive and isinstance(file_loader, _Downloadable):
+        file_loader = file_loader('archive.zip', target_file=basename)
         expected_path_is_absolute = False
     else:
-        file_loader = FileLoader(basename)
+        file_loader = file_loader(basename)
         expected_path_is_absolute = True
 
     # test initial path
@@ -237,7 +241,7 @@ def test_single_file_loader_from_directory(examples_local_repository_tmp_dir):
 
     # Test all datasets loaded as multiblock
     filenames = sorted(
-        [Path(fname).stem for fname in os.listdir(examples_local_repository_tmp_dir)],
+        [Path(fname).stem for fname in Path(examples_local_repository_tmp_dir).iterdir()],
     )
     loader = _SingleFileDatasetLoader(examples_local_repository_tmp_dir)
     dataset = loader.load()
@@ -247,7 +251,8 @@ def test_single_file_loader_from_directory(examples_local_repository_tmp_dir):
 
 
 @pytest.mark.parametrize('load_func', [_load_as_multiblock, _load_and_merge, None])
-def test_multi_file_loader(examples_local_repository_tmp_dir, load_func):
+@pytest.mark.usefixtures('examples_local_repository_tmp_dir')
+def test_multi_file_loader(load_func):
     basename_loaded1 = 'airplane.ply'
     basename_loaded2 = 'hexbeam.vtk'
     basename_not_loaded = 'pyvista_logo.png'
@@ -269,27 +274,27 @@ def test_multi_file_loader(examples_local_repository_tmp_dir, load_func):
     path = multi_file_loader.path
     assert multi_file_loader._file_loaders_ is not None
     assert isinstance(path, tuple)
-    assert [os.path.isabs(file) for file in path]
+    assert all(os.path.isabs(file) for file in path)
     assert len(path) == 3
 
     path_loadable = multi_file_loader.path_loadable
     assert isinstance(path_loadable, tuple)
-    assert [os.path.isabs(file) for file in path_loadable]
+    assert all(os.path.isabs(file) for file in path_loadable)
     assert len(path_loadable) == 2
     assert basename_not_loaded not in path_loadable
 
     # test download
     path_download = multi_file_loader.download()
     assert path_download == path
-    assert [os.path.isfile(file) for file in path_download]
-    assert [
+    assert all(os.path.isfile(file) for file in path_download)
+    assert all(
         'https://github.com/pyvista/vtk-data/raw/master/Data/' in url
         for url in multi_file_loader.source_url_raw
-    ]
-    assert [
+    )
+    assert all(
         'https://github.com/pyvista/vtk-data/blob/master/Data/' in url
         for url in multi_file_loader.source_url_blob
-    ]
+    )
 
     # test load
     # test calling load does not store the dataset internally
@@ -322,7 +327,7 @@ def test_multi_file_loader(examples_local_repository_tmp_dir, load_func):
         assert np.array_equal(dataset_loaded.points, expected.points)
 
 
-@pytest.fixture()
+@pytest.fixture
 def dataset_loader_one_file_local():
     # Test 'download' for a local built-in dataset
     loader = _SingleFileDownloadableDatasetLoader(examples.antfile)
@@ -355,7 +360,7 @@ def test_dataset_loader_one_file_local(dataset_loader_one_file_local):
     assert loader.unique_cell_types == (pv.CellType.TRIANGLE,)
 
 
-@pytest.fixture()
+@pytest.fixture
 def dataset_loader_one_file():
     loader = _SingleFileDownloadableDatasetLoader('cow.vtp')
     loader.download()
@@ -378,10 +383,14 @@ def test_dataset_loader_one_file(dataset_loader_one_file):
     assert loader.source_name == 'cow.vtp'
     assert loader.source_url_raw == 'https://github.com/pyvista/vtk-data/raw/master/Data/cow.vtp'
     assert loader.source_url_blob == 'https://github.com/pyvista/vtk-data/blob/master/Data/cow.vtp'
-    assert loader.unique_cell_types == (pv.CellType.TRIANGLE, pv.CellType.POLYGON, pv.CellType.QUAD)
+    assert loader.unique_cell_types == (
+        pv.CellType.TRIANGLE,
+        pv.CellType.POLYGON,
+        pv.CellType.QUAD,
+    )
 
 
-@pytest.fixture()
+@pytest.fixture
 def dataset_loader_two_files_one_loadable():
     def _files_func():
         loadable = _SingleFileDownloadableDatasetLoader('HeadMRVolume.mhd')
@@ -422,7 +431,7 @@ def test_dataset_loader_two_files_one_loadable(dataset_loader_two_files_one_load
     assert loader.unique_cell_types == (pv.CellType.VOXEL,)
 
 
-@pytest.fixture()
+@pytest.fixture
 def dataset_loader_two_files_both_loadable():
     def _files_func():
         loadable1 = _SingleFileDownloadableDatasetLoader('bolt.slc')
@@ -468,7 +477,7 @@ def test_dataset_loader_two_files_both_loadable(dataset_loader_two_files_both_lo
     assert loader.unique_cell_types == (pv.CellType.VOXEL,)
 
 
-@pytest.fixture()
+@pytest.fixture
 def dataset_loader_cubemap():
     loader = _SingleFileDownloadableDatasetLoader(
         'cubemap_park/cubemap_park.zip',
@@ -502,7 +511,7 @@ def test_dataset_loader_cubemap(dataset_loader_cubemap):
     assert loader.unique_cell_types == (pv.CellType.PIXEL,)
 
 
-@pytest.fixture()
+@pytest.fixture
 def dataset_loader_dicom():
     loader = _SingleFileDownloadableDatasetLoader('DICOM_Stack/data.zip', target_file='data')
     loader.download()
@@ -541,7 +550,11 @@ def test_dataset_loader_from_nested_files_and_directory(
     # test complex multiple file case with separate ext and reader, which are loaded as a tuple
     # piece together new dataset from existing ones
     def files_func():
-        return dataset_loader_one_file, dataset_loader_two_files_one_loadable, dataset_loader_dicom
+        return (
+            dataset_loader_one_file,
+            dataset_loader_two_files_one_loadable,
+            dataset_loader_dicom,
+        )
 
     loader = _MultiFileDownloadableDatasetLoader(files_func, load_func=_load_as_multiblock)
     loader.download()
@@ -602,7 +615,7 @@ def test_dataset_loader_from_nested_files_and_directory(
     )
 
 
-@pytest.fixture()
+@pytest.fixture
 def dataset_loader_nested_multiblock():
     loader = _SingleFileDownloadableDatasetLoader('mesh_fs8.exo')
     loader.download()
@@ -619,8 +632,8 @@ def test_dataset_loader_from_nested_multiblock(dataset_loader_nested_multiblock)
     assert loader._total_size_bytes == 69732
     assert loader.total_size == '69.7 KB'
     assert loader.unique_extension == '.exo'
-    assert loader._reader is None
-    assert loader.unique_reader_type is None
+    assert isinstance(loader._reader, pv.ExodusIIReader)
+    assert loader.unique_reader_type is pv.ExodusIIReader
     assert type(loader.dataset) is pv.MultiBlock
     assert isinstance(loader.dataset_iterable[0], pv.MultiBlock)
     assert len(loader.dataset_iterable) == 12
@@ -640,7 +653,7 @@ def test_dataset_loader_from_nested_multiblock(dataset_loader_nested_multiblock)
     )
 
 
-def test_load_dataset_no_reader(dataset_loader_one_file):
+def test_load_dataset_no_reader():
     # Test using dataset with .npy file
     dataset = downloads._dataset_cloud_dark_matter
 
@@ -680,3 +693,17 @@ def test_format_file_size():
     assert _format_file_size(999949000000) == '999.9 GB'
     assert _format_file_size(999950000000) == '1000.0 GB'
     assert _format_file_size(1000000000000) == '1000.0 GB'
+
+
+def test_download_dataset_texture():
+    loader = _SingleFileDownloadableDatasetLoader(
+        'beach.nrrd',
+    )
+    loaded = _download_dataset_texture(loader, texture=True, load=True)
+    assert isinstance(loaded, pv.Texture)
+
+    loaded = _download_dataset_texture(loader, texture=False, load=True)
+    assert isinstance(loaded, pv.ImageData)
+
+    loaded = _download_dataset_texture(loader, texture=False, load=False)
+    assert isinstance(loaded, str)
