@@ -6,6 +6,7 @@ from pathlib import PureWindowsPath
 
 import pytest
 import requests
+from retry_requests import retry
 
 import pyvista as pv
 from pyvista import examples
@@ -19,7 +20,15 @@ def pytest_generate_tests(metafunc):
     """Generate parametrized tests."""
     if 'test_case' in metafunc.fixturenames:
         # Generate a separate test case for each downloadable dataset
-        test_cases = _generate_dataset_loader_test_cases_from_module(pv.examples.downloads)
+        test_cases_downloads = _generate_dataset_loader_test_cases_from_module(
+            pv.examples.downloads
+        )
+        test_cases_planets = _generate_dataset_loader_test_cases_from_module(pv.examples.planets)
+        # Exclude `load` functions
+        test_cases_planets = [
+            case for case in test_cases_planets if case.dataset_function[0].startswith('download')
+        ]
+        test_cases = [*test_cases_downloads, *test_cases_planets]
         ids = [case.dataset_name for case in test_cases]
         metafunc.parametrize('test_case', test_cases, ids=ids)
 
@@ -30,8 +39,13 @@ def test_dataset_loader_name_matches_download_name(test_case: DatasetLoaderTestC
 
 
 def _is_valid_url(url):
+    session = retry(
+        status_to_retry=[500, 502, 504, 403, 429],  # default + GH rate limit (403, 429)
+        retries=5,
+        backoff_factor=2.0,
+    )
     try:
-        requests.get(url)
+        session.get(url)
     except requests.RequestException:
         return False
     else:
@@ -50,14 +64,14 @@ def test_dataset_loader_source_url_blob(test_case: DatasetLoaderTestCase):
     sources = [sources] if isinstance(sources, str) else sources  # Make iterable
     for url in sources:
         if not _is_valid_url(url):
-            pytest.fail(f"Invalid blob URL for {DatasetLoaderTestCase.dataset_name}:\n{url}")
+            pytest.fail(f'Invalid blob URL for {test_case.dataset_name}:\n{url}')
 
 
 def test_delete_downloads(tmpdir):
     # change the path so we don't delete the examples cache
     old_path = examples.downloads.USER_DATA_PATH
     try:
-        examples.downloads.USER_DATA_PATH = str(tmpdir.mkdir("tmpdir"))
+        examples.downloads.USER_DATA_PATH = str(tmpdir.mkdir('tmpdir'))
         assert Path(examples.downloads.USER_DATA_PATH).is_dir()
         tmp_file = str(Path(examples.downloads.USER_DATA_PATH) / 'tmp.txt')
         with Path(tmp_file).open('w') as fid:
@@ -120,7 +134,7 @@ def test_file_copier(tmpdir):
         examples.downloads._file_copier('not a file', output_file, None)
 
 
-def test_local_file_cache(tmpdir):
+def test_local_file_cache():
     """Ensure that pyvista.examples.downloads can work with a local cache."""
     basename = Path(examples.planefile).name
     dirname = str(Path(examples.planefile).parent)
@@ -138,6 +152,6 @@ def test_local_file_cache(tmpdir):
         Path(filename).unlink()
 
     finally:
-        downloads.FETCHER.base_url = "https://github.com/pyvista/vtk-data/raw/master/Data/"
+        downloads.FETCHER.base_url = 'https://github.com/pyvista/vtk-data/raw/master/Data/'
         downloads._FILE_CACHE = False
         downloads.FETCHER.registry.pop(basename, None)
