@@ -11,18 +11,16 @@ from pyvista.plotting import _vtk
 from pyvista.plotting.opts import InterpolationType
 from pyvista.plotting.opts import RepresentationType
 
-
-@pytest.fixture(autouse=True)
-def skip_check_gc(skip_check_gc):  # noqa: PT004
-    """All the tests here fail gc."""
+# A large number of tests here fail gc
+pytestmark = pytest.mark.skip_check_gc
 
 
-@pytest.fixture()
+@pytest.fixture
 def axes():
     return pv.Axes()
 
 
-@pytest.fixture()
+@pytest.fixture
 def axes_actor(axes):
     return axes.axes_actor
 
@@ -176,8 +174,8 @@ def test_axes_actor_labels_group(axes_actor):
     assert axes_actor.y_label == new_labels[1]
     assert axes_actor.z_label == new_labels[2]
 
-    match = 'Labels must be a list or tuple with three items. Got abc instead.'
-    with pytest.raises(ValueError, match=match):
+    match = 'Labels must be a list or tuple. Got abc instead.'
+    with pytest.raises(TypeError, match=match):
         axes_actor.labels = 'abc'
 
     match = "Labels must be a list or tuple with three items. Got ['1', '2'] instead."
