@@ -3,7 +3,6 @@
 from __future__ import annotations
 
 import itertools
-import platform
 import weakref
 
 import numpy as np
@@ -15,20 +14,10 @@ from pyvista import examples
 from pyvista.plotting import charts
 from pyvista.plotting.colors import COLOR_SCHEMES
 
-skip_mac = pytest.mark.skipif(
-    platform.system() == 'Darwin',
-    reason='MacOS CI fails when downloading examples',
-)
-
-
-@pytest.fixture(autouse=True)
-def skip_check_gc(skip_check_gc):  # noqa: PT004
-    """A large number of tests here fail gc."""
-
-
-# skip all tests if VTK<9.2.0
-if pv.vtk_version_info < (9, 2):
-    pytestmark = pytest.mark.skip
+pytestmark = [
+    pytest.mark.needs_vtk_version(9, 2),  # skip all tests if VTK<9.2.0
+    pytest.mark.skip_check_gc,  # A large number of tests here fail gc
+]
 
 
 def vtk_array_to_tuple(arr):
@@ -38,15 +27,16 @@ def vtk_array_to_tuple(arr):
 def to_vtk_scientific(val):
     parts = val.split('e')
     sign, exp = parts[1][0], parts[1][1:]
-    exp = exp.lstrip("0")  # Remove leading zeros of exponent
+    exp = exp.lstrip('0')  # Remove leading zeros of exponent
     return (
-        parts[0] + "e" + sign + exp if exp != "" else parts[0]
+        parts[0] + 'e' + sign + exp if exp != '' else parts[0]
     )  # Remove exponent altogether if it is 0
 
 
 class PlotterChanged:
     """Helper class to check whether the plotter's rendered content has changed
-    since the last call."""
+    since the last call.
+    """
 
     def __init__(self, plotter):
         self._plotter = plotter
@@ -63,29 +53,29 @@ class PlotterChanged:
         return changed
 
 
-@pytest.fixture()
+@pytest.fixture
 def pl():
     p = pv.Plotter(window_size=(600, 600))
     p.background_color = 'w'
     return p
 
 
-@pytest.fixture()
+@pytest.fixture
 def chart_2d():
     return pv.Chart2D()
 
 
-@pytest.fixture()
+@pytest.fixture
 def chart_box():
     return pv.ChartBox([[1, 2, 3]])
 
 
-@pytest.fixture()
+@pytest.fixture
 def chart_pie():
     return pv.ChartPie([1, 2, 3])
 
 
-@pytest.fixture()
+@pytest.fixture
 def chart_mpl():
     import matplotlib.pyplot as plt
 
@@ -94,42 +84,42 @@ def chart_mpl():
     return pv.ChartMPL(f)
 
 
-@pytest.fixture()
+@pytest.fixture
 def line_plot_2d(chart_2d):
     return chart_2d.line([0, 1, 2], [3, 1, 2])
 
 
-@pytest.fixture()
+@pytest.fixture
 def scatter_plot_2d(chart_2d):
     return chart_2d.scatter([0, 1, 2], [3, 1, 2])
 
 
-@pytest.fixture()
+@pytest.fixture
 def area_plot(chart_2d):
     return chart_2d.area([0, 1, 2], [2, 1, 3], [0, 2, 0])
 
 
-@pytest.fixture()
+@pytest.fixture
 def bar_plot(chart_2d):
     return chart_2d.bar([0, 1, 2], [[2, 1, 3], [1, 2, 0]])
 
 
-@pytest.fixture()
+@pytest.fixture
 def stack_plot(chart_2d):
     return chart_2d.stack([0, 1, 2], [[2, 1, 3], [1, 2, 0]])
 
 
-@pytest.fixture()
+@pytest.fixture
 def box_plot(chart_box):
     return chart_box.plot
 
 
-@pytest.fixture()
+@pytest.fixture
 def pie_plot(chart_pie):
     return chart_pie.plot
 
 
-@pytest.fixture()
+@pytest.fixture
 def axis(chart_2d):
     # Test properties, using the y axis of a 2D chart
     chart_2d.line([0, 1], [1, 10])
@@ -140,8 +130,8 @@ def axis(chart_2d):
 def test_pen():
     c_red, c_blue = (1.0, 0.0, 0.0, 1.0), (0.0, 0.0, 1.0, 1.0)
     w_thin, w_thick = 2, 10
-    s_dash, s_dot, s_inv = "--", ":", "|"
-    assert s_inv not in charts.Pen.LINE_STYLES, "New line styles added? Change this test."
+    s_dash, s_dot, s_inv = '--', ':', '|'
+    assert s_inv not in charts.Pen.LINE_STYLES, 'New line styles added? Change this test.'
 
     # Test constructor arguments
     pen = charts.Pen(color=c_red, width=w_thin, style=s_dash)
@@ -163,7 +153,7 @@ def test_pen():
 
     pen.style = s_dot
     assert pen.style == s_dot
-    assert pen.GetLineType() == charts.Pen.LINE_STYLES[s_dot]["id"]
+    assert pen.GetLineType() == charts.Pen.LINE_STYLES[s_dot]['id']
     with pytest.raises(ValueError):  # noqa: PT011
         pen.style = s_inv
 
@@ -180,7 +170,7 @@ def test_wrapping():
     assert pen.GetWidth() == width
 
 
-@skip_mac
+@pytest.mark.skip_mac('MacOS CI fails when downloading examples')
 def test_brush():
     c_red, c_blue = (1.0, 0.0, 0.0, 1.0), (0.0, 0.0, 1.0, 1.0)
     t_masonry = examples.download_masonry_texture()
@@ -216,19 +206,21 @@ def test_brush():
 
 
 def test_axis_init():
-    label = "Y axis"
+    label = 'Y axis'
     r_fix = [2, 5]
 
     # Test constructor arguments
     axis = charts.Axis(label=label, range=r_fix, grid=True)
     assert axis.label == label
     assert np.allclose(axis.range, r_fix)
-    assert axis.behavior == "fixed"
+    assert axis.behavior == 'fixed'
     assert axis.grid
+    assert isinstance(axis.pen, charts.Pen)
+    assert isinstance(axis.grid_pen, charts.Pen)
 
 
 def test_axis_label(axis):
-    label = "Y axis"
+    label = 'Y axis'
     axis.label = label
     assert axis.label == label
     assert axis.GetTitle() == label
@@ -241,20 +233,20 @@ def test_axis_label(axis):
 def test_axis_range(axis):
     r_fix, r_auto = [2, 5], None
     axis.range = r_auto
-    assert axis.behavior == "auto"
+    assert axis.behavior == 'auto'
     axis.range = r_fix
     r = [0.0, 0.0]
     axis.GetRange(r)
     assert np.allclose(axis.range, r_fix)
     assert np.allclose(r, r_fix)
-    assert axis.behavior == "fixed"
+    assert axis.behavior == 'fixed'
 
-    assert axis.GetBehavior() == charts.Axis.BEHAVIORS["fixed"]
-    axis.behavior = "auto"
-    assert axis.behavior == "auto"
-    assert axis.GetBehavior() == charts.Axis.BEHAVIORS["auto"]
+    assert axis.GetBehavior() == charts.Axis.BEHAVIORS['fixed']
+    axis.behavior = 'auto'
+    assert axis.behavior == 'auto'
+    assert axis.GetBehavior() == charts.Axis.BEHAVIORS['auto']
     with pytest.raises(ValueError):  # noqa: PT011
-        axis.behavior = "invalid"
+        axis.behavior = 'invalid'
 
 
 def test_axis_margin(axis):
@@ -264,10 +256,12 @@ def test_axis_margin(axis):
     assert axis.GetMargins()[0] == margin
 
 
-@pytest.mark.skip_plotting()
+@pytest.mark.skip_plotting
 def test_axis_scale(chart_2d, axis):
     axis.log_scale = True  # Log scale can be enabled for the currently drawn plot
-    chart_2d.show()  # We have to call show to update all chart properties (calls Update and Paint methods of chart/plot objects).
+    # We have to call show to update all chart properties
+    # (calls Update and Paint methods of chart/plot objects).
+    chart_2d.show()
     assert axis.log_scale
     assert axis.GetLogScaleActive()
 
@@ -275,8 +269,9 @@ def test_axis_scale(chart_2d, axis):
     chart_2d.show()
     assert not axis.log_scale
     assert not axis.GetLogScaleActive()
-    # Note: following lines cause "vtkMath::Jacobi: Error extracting eigenfunctions" warning to be printed.
-    # Should be fixed on VTK side, but tricky without breaking stuff (see !8828 for reference).
+    # Note: following lines cause "vtkMath::Jacobi: Error extracting eigenfunctions"
+    # warning to be printed. Should be fixed on VTK side, but tricky without breaking
+    # stuff (see !8828 for reference).
     chart_2d.line([0, 1], [-10, 10])  # Plot for which log scale cannot be enabled
     axis.log_scale = True
     chart_2d.show()
@@ -315,7 +310,7 @@ def test_axis_tick_count(axis):
 
 def test_axis_tick_locations(chart_2d, axis):
     tlocs, tlocs_large = [1, 5.5, 8], [5.2, 340, 9999.999]
-    tlabels = ["Foo", "Blub", "Spam"]
+    tlabels = ['Foo', 'Blub', 'Spam']
     tlocs0 = axis.tick_locations
     tlabels0 = axis.tick_labels
 
@@ -325,19 +320,19 @@ def test_axis_tick_locations(chart_2d, axis):
     assert np.allclose(axis.GetTickPositions(), tlocs)
     assert tuple(axis.tick_labels) == tuple(tlabels)
     assert vtk_array_to_tuple(axis.GetTickLabels()) == tuple(tlabels)
-    axis.tick_labels = "2f"
+    axis.tick_labels = '2f'
     chart_2d.show()
-    assert tuple(axis.tick_labels) == tuple(f"{loc:.2f}" for loc in tlocs)
-    assert vtk_array_to_tuple(axis.GetTickLabels()) == tuple(f"{loc:.2f}" for loc in tlocs)
+    assert tuple(axis.tick_labels) == tuple(f'{loc:.2f}' for loc in tlocs)
+    assert vtk_array_to_tuple(axis.GetTickLabels()) == tuple(f'{loc:.2f}' for loc in tlocs)
     assert axis.GetNotation() == charts.Axis.FIXED_NOTATION
     assert axis.GetPrecision() == 2
-    axis.tick_labels = "4e"
+    axis.tick_labels = '4e'
     axis.tick_locations = tlocs_large  # Add some more variety to labels
     chart_2d.show()
 
-    assert tuple(axis.tick_labels) == tuple(to_vtk_scientific(f"{loc:.4e}") for loc in tlocs_large)
+    assert tuple(axis.tick_labels) == tuple(to_vtk_scientific(f'{loc:.4e}') for loc in tlocs_large)
     assert vtk_array_to_tuple(axis.GetTickLabels()) == tuple(
-        to_vtk_scientific(f"{loc:.4e}") for loc in tlocs_large
+        to_vtk_scientific(f'{loc:.4e}') for loc in tlocs_large
     )
     assert axis.GetNotation() == charts.Axis.SCIENTIFIC_NOTATION
     assert axis.GetPrecision() == 4
@@ -391,15 +386,30 @@ def test_axis_label_font_size(chart_2d):
     assert axis.GetLabelProperties().GetFontSize() == font_size
 
 
-@pytest.mark.skip_plotting()
-@pytest.mark.parametrize("chart_f", [("chart_2d"), ("chart_box"), ("chart_pie"), ("chart_mpl")])
+@pytest.mark.skip_plotting
+@pytest.mark.parametrize(
+    'chart_f',
+    [
+        ('chart_2d'),
+        ('chart_box'),
+        ('chart_pie'),
+        pytest.param(
+            'chart_mpl',
+            marks=pytest.mark.filterwarnings(
+                r'ignore:No artists with labels found to put in legend\.  Note that artists '
+                r'whose label start with an underscore are ignored when legend\(\) is called '
+                r'with no argument\.:UserWarning'
+            ),
+        ),
+    ],
+)
 def test_chart_common(pl, chart_f, request):
     # Test the common chart functionalities
     chart = request.getfixturevalue(chart_f)
-    title = "Chart title"
+    title = 'Chart title'
     c_red, c_blue = (1.0, 0.0, 0.0, 1.0), (0.0, 0.0, 1.0, 1.0)
     bw = 10
-    bs = "--"
+    bs = '--'
 
     # Check scene and renderer properties
     assert chart._scene is None
@@ -438,7 +448,10 @@ def test_chart_common(pl, chart_f, request):
 
     # Check is_within
     assert chart._is_within(
-        ((chart.loc[0] + chart.size[0] / 2) * w, (chart.loc[1] + chart.size[1] / 2) * h),
+        (
+            (chart.loc[0] + chart.size[0] / 2) * w,
+            (chart.loc[1] + chart.size[1] / 2) * h,
+        ),
     )
     assert not chart._is_within(((chart.loc[0] + chart.size[0] / 2) * w, chart.loc[1] * h - 5))
     assert not chart._is_within((chart.loc[0] * w - 5, (chart.loc[1] + chart.size[1] / 2) * h))
@@ -471,15 +484,15 @@ def test_chart_common(pl, chart_f, request):
 
 
 @pytest.mark.parametrize(
-    "plot_f",
+    'plot_f',
     [
-        ("line_plot_2d"),
-        ("scatter_plot_2d"),
-        ("area_plot"),
-        ("bar_plot"),
-        ("stack_plot"),
-        ("box_plot"),
-        ("pie_plot"),
+        ('line_plot_2d'),
+        ('scatter_plot_2d'),
+        ('area_plot'),
+        ('bar_plot'),
+        ('stack_plot'),
+        ('box_plot'),
+        ('pie_plot'),
     ],
 )
 def test_plot_common(plot_f, request):
@@ -487,16 +500,16 @@ def test_plot_common(plot_f, request):
     plot = request.getfixturevalue(plot_f)
     c = (1.0, 0.0, 1.0, 1.0)
     w = 5
-    s = "-."
-    l = "Label"
+    s = '-.'
+    l = 'Label'
 
     plot.color = c
     assert plot.color == c
     assert plot.brush.color == c
 
-    if hasattr(plot, "GetPen"):
+    if hasattr(plot, 'GetPen'):
         assert plot.pen.__this__ == plot.GetPen().__this__
-    if hasattr(plot, "GetBrush"):
+    if hasattr(plot, 'GetBrush'):
         assert plot.brush.__this__ == plot.GetBrush().__this__
 
     plot.line_width = w
@@ -516,11 +529,11 @@ def test_plot_common(plot_f, request):
     assert plot.GetVisible()
 
 
-@pytest.mark.parametrize("plot_f", [("bar_plot"), ("stack_plot"), ("box_plot"), ("pie_plot")])
+@pytest.mark.parametrize('plot_f', [('bar_plot'), ('stack_plot'), ('box_plot'), ('pie_plot')])
 def test_multicomp_plot_common(plot_f, request):
     # Test the common multicomp plot functionalities
     plot = request.getfixturevalue(plot_f)
-    cs = "spectrum"
+    cs = 'spectrum'
     cs_colors = [
         (0.0, 0.0, 0.0, 1.0),
         (0.8941176470588236, 0.10196078431372549, 0.10980392156862745, 1.0),
@@ -531,11 +544,11 @@ def test_multicomp_plot_common(plot_f, request):
         (0.6509803921568628, 0.33725490196078434, 0.1568627450980392, 1.0),
     ]
     colors = [(1.0, 0.0, 1.0, 1.0), (0.0, 1.0, 1.0, 1.0), (1.0, 1.0, 0.0, 1.0)]
-    labels = ["Foo", "Spam", "Bla"]
+    labels = ['Foo', 'Spam', 'Bla']
 
     plot.color_scheme = cs
     assert plot.color_scheme == cs
-    assert plot._color_series.GetColorScheme() == COLOR_SCHEMES[cs]["id"]
+    assert plot._color_series.GetColorScheme() == COLOR_SCHEMES[cs]['id']
     assert all(pc == cs for pc, cs in zip(plot.colors, cs_colors))
     series_colors = [
         pv.Color(plot._color_series.GetColor(i)).float_rgba for i in range(len(cs_colors))
@@ -570,14 +583,14 @@ def test_multicomp_plot_common(plot_f, request):
     assert plot.label == labels[0]
     plot.labels = None
     assert plot.labels == []
-    assert plot.label == ""
+    assert plot.label == ''
 
     plot.label = labels[1]
     assert tuple(plot.labels) == (labels[1],)
     assert plot.label == labels[1]
     plot.label = None
     assert plot.labels == []
-    assert plot.label == ""
+    assert plot.label == ''
 
 
 def test_lineplot2d(chart_2d, line_plot_2d):
@@ -585,11 +598,11 @@ def test_lineplot2d(chart_2d, line_plot_2d):
     y = [4, 1, 0, -1, -4]
     c = (1.0, 0.0, 1.0, 1.0)
     w = 5
-    s = "-."
-    l = "Line"
+    s = '-.'
+    l = 'Line'
 
     # Test constructor
-    plot = charts.LinePlot2D(chart_2d, x, y, c, w, s, l)
+    plot = charts.LinePlot2D(chart_2d, x, y, color=c, width=w, style=s, label=l)
     assert plot._chart == weakref.proxy(chart_2d)
     assert np.allclose(plot.x, x)
     assert np.allclose(plot.y, y)
@@ -609,14 +622,14 @@ def test_scatterplot2d(chart_2d, scatter_plot_2d):
     y = [4, 1, 0, -1, -4]
     c = (1.0, 0.0, 1.0, 1.0)
     sz = 5
-    st, st_inv = "o", "^"
-    l = "Scatter"
-    assert (
-        st_inv not in charts.ScatterPlot2D.MARKER_STYLES
-    ), "New marker styles added? Change this test."
+    st, st_inv = 'o', '^'
+    l = 'Scatter'
+    assert st_inv not in charts.ScatterPlot2D.MARKER_STYLES, (
+        'New marker styles added? Change this test.'
+    )
 
     # Test constructor
-    plot = charts.ScatterPlot2D(chart_2d, x, y, c, sz, st, l)
+    plot = charts.ScatterPlot2D(chart_2d, x, y, color=c, size=sz, style=st, label=l)
     assert plot._chart == weakref.proxy(chart_2d)
     assert np.allclose(plot.x, x)
     assert np.allclose(plot.y, y)
@@ -635,10 +648,10 @@ def test_scatterplot2d(chart_2d, scatter_plot_2d):
     assert scatter_plot_2d.GetMarkerSize() == sz
 
     scatter_plot_2d.marker_style = None
-    assert scatter_plot_2d.marker_style == ""
+    assert scatter_plot_2d.marker_style == ''
     scatter_plot_2d.marker_style = st
     assert scatter_plot_2d.marker_style == st
-    assert scatter_plot_2d.GetMarkerStyle() == scatter_plot_2d.MARKER_STYLES[st]["id"]
+    assert scatter_plot_2d.GetMarkerStyle() == scatter_plot_2d.MARKER_STYLES[st]['id']
     with pytest.raises(ValueError):  # noqa: PT011
         scatter_plot_2d.marker_style = st_inv
 
@@ -648,10 +661,10 @@ def test_areaplot(chart_2d, area_plot):
     y1 = [4, 1, 0, -1, -4]
     y2 = [-4, -2, 0, 2, 4]
     c = (1.0, 0.0, 1.0, 1.0)
-    l = "Line"
+    l = 'Line'
 
     # Test constructor
-    plot = charts.AreaPlot(chart_2d, x, y1, y2, c, l)
+    plot = charts.AreaPlot(chart_2d, x, y1, y2, color=c, label=l)
     assert plot._chart == weakref.proxy(chart_2d)
     assert np.allclose(plot.x, x)
     assert np.allclose(plot.y1, y1)
@@ -670,12 +683,12 @@ def test_barplot(chart_2d, bar_plot):
     x = [0, 1, 2]
     y = [[1, 2, 3], [2, 1, 0], [1, 1, 1]]
     c = [(1.0, 0.0, 1.0, 1.0), (1.0, 1.0, 0.0, 1.0), (0.0, 1.0, 1.0, 1.0)]
-    ori, ori_inv = "H", "I"
-    l = ["Foo", "Spam", "Bla"]
-    assert ori_inv not in charts.BarPlot.ORIENTATIONS, "New orientations added? Change this test."
+    ori, ori_inv = 'H', 'I'
+    l = ['Foo', 'Spam', 'Bla']
+    assert ori_inv not in charts.BarPlot.ORIENTATIONS, 'New orientations added? Change this test.'
 
     # Test multi comp constructor
-    plot = charts.BarPlot(chart_2d, x, y, c, ori, l)
+    plot = charts.BarPlot(chart_2d, x, y, color=c, orientation=ori, label=l)
     assert plot._chart == weakref.proxy(chart_2d)
     assert np.allclose(plot.x, x)
     assert np.allclose(plot.y, y)
@@ -684,7 +697,7 @@ def test_barplot(chart_2d, bar_plot):
     assert plot.labels == l
 
     # Test single comp constructor
-    plot = charts.BarPlot(chart_2d, x, y[0], c[0], ori, l[0])
+    plot = charts.BarPlot(chart_2d, x, y[0], color=c[0], orientation=ori, label=l[0])
     assert plot._chart == weakref.proxy(chart_2d)
     assert np.allclose(plot.x, x)
     assert np.allclose(plot.y, y[0])
@@ -693,13 +706,13 @@ def test_barplot(chart_2d, bar_plot):
     assert plot.label == l[0]
 
     # Test multi and single comp constructors with inconsistent arguments
-    with pytest.raises(ValueError):  # noqa: PT011
-        charts.BarPlot(chart_2d, x, y, c[0], ori, l)
+    with pytest.raises(TypeError):
+        charts.BarPlot(chart_2d, x, y, color=c[0], orientation=ori, label=l)
     # charts.BarPlot(chart_2d, x, y, c, off, ori, l[0])  # This one is valid
     with pytest.raises(ValueError):  # noqa: PT011
-        charts.BarPlot(chart_2d, x, y[0], c, ori, l[0])
+        charts.BarPlot(chart_2d, x, y[0], color=c, orientation=ori, label=l[0])
     with pytest.raises(ValueError):  # noqa: PT011
-        charts.BarPlot(chart_2d, x, y[0], c[0], ori, l)
+        charts.BarPlot(chart_2d, x, y[0], color=c[0], orientation=ori, label=l)
 
     # Test remaining properties
     bar_plot.update(x, y)
@@ -717,10 +730,10 @@ def test_stackplot(chart_2d, stack_plot):
     x = [0, 1, 2]
     ys = [[1, 2, 3], [2, 1, 0], [1, 1, 1]]
     c = [(1.0, 0.0, 1.0, 1.0), (1.0, 1.0, 0.0, 1.0), (0.0, 1.0, 1.0, 1.0)]
-    l = ["Foo", "Spam", "Bla"]
+    l = ['Foo', 'Spam', 'Bla']
 
     # Test multi comp constructor
-    plot = charts.StackPlot(chart_2d, x, ys, c, l)
+    plot = charts.StackPlot(chart_2d, x, ys, colors=c, labels=l)
     assert plot._chart == weakref.proxy(chart_2d)
     assert np.allclose(plot.x, x)
     assert np.allclose(plot.ys, ys)
@@ -728,7 +741,7 @@ def test_stackplot(chart_2d, stack_plot):
     assert plot.labels == l
 
     # Test single comp constructor
-    plot = charts.StackPlot(chart_2d, x, ys[0], c[0], l[0])
+    plot = charts.StackPlot(chart_2d, x, ys[0], colors=c[0], labels=l[0])
     assert plot._chart == weakref.proxy(chart_2d)
     assert np.allclose(plot.x, x)
     assert np.allclose(plot.ys, ys[0])
@@ -736,13 +749,13 @@ def test_stackplot(chart_2d, stack_plot):
     assert plot.label == l[0]
 
     # Test multi and single comp constructors with inconsistent arguments
-    with pytest.raises(ValueError):  # noqa: PT011
-        charts.StackPlot(chart_2d, x, ys, c[0], l)
+    with pytest.raises(TypeError):
+        charts.StackPlot(chart_2d, x, ys, colors=c[0], labels=l)
     # charts.StackPlot(chart_2d, x, ys, c, l[0])  # This one is valid
     with pytest.raises(ValueError):  # noqa: PT011
-        charts.StackPlot(chart_2d, x, ys[0], c, l[0])
+        charts.StackPlot(chart_2d, x, ys[0], colors=c, labels=l[0])
     with pytest.raises(ValueError):  # noqa: PT011
-        charts.StackPlot(chart_2d, x, ys[0], c[0], l)
+        charts.StackPlot(chart_2d, x, ys[0], colors=c[0], labels=l)
 
     # Test remaining properties
     stack_plot.update(x, ys)
@@ -750,27 +763,27 @@ def test_stackplot(chart_2d, stack_plot):
     assert np.allclose(stack_plot.ys, ys)
 
 
-@pytest.mark.skip_plotting()
+@pytest.mark.skip_plotting
 def test_chart_2d(pl, chart_2d):
     size = (0.5, 0.5)
     loc = (0.25, 0.25)
-    lx = "X label"
-    ly = "Y label"
+    lx = 'X label'
+    ly = 'Y label'
     rx = [0, 5]
     ry = [0, 1]
     x = np.arange(11) - 5
     y = x**2
     ys = [np.sin(x), np.cos(x), np.tanh(x)]
     col = (1.0, 0.0, 1.0, 1.0)
-    cs = "citrus"
+    cs = 'citrus'
     sz = 5
-    ms = "d"
+    ms = 'd'
     w = 10
-    ls = "-."
-    ori = "V"
+    ls = '-.'
+    ori = 'V'
 
     # Test constructor
-    chart = pv.Chart2D(size, loc, lx, ly, False)
+    chart = pv.Chart2D(size=size, loc=loc, x_label=lx, y_label=ly, grid=False)
     assert chart.size == size
     assert chart.loc == loc
     assert chart.x_label == lx
@@ -790,12 +803,12 @@ def test_chart_2d(pl, chart_2d):
     )
 
     # Test parse_format
-    hex_colors = ["#fa09b6", "0xa53a8d", "#b02239f0", "0xcee6927f"]
-    colors = itertools.chain(pv.hexcolors, pv.plotting.colors.color_synonyms, [*hex_colors, ""])
+    hex_colors = ['#fa09b6', '0xa53a8d', '#b02239f0', '0xcee6927f']
+    colors = itertools.chain(pv.hexcolors, pv.plotting.colors.color_synonyms, [*hex_colors, ''])
     for m in charts.ScatterPlot2D.MARKER_STYLES:
         for l in charts.Pen.LINE_STYLES:
             for c in colors:
-                cp = "b" if c == "" else c
+                cp = 'b' if c == '' else c
                 assert (m, l, cp) == chart_2d._parse_format(m + l + c)
                 assert (m, l, cp) == chart_2d._parse_format(m + c + l)
                 assert (m, l, cp) == chart_2d._parse_format(l + m + c)
@@ -804,78 +817,78 @@ def test_chart_2d(pl, chart_2d):
                 assert (m, l, cp) == chart_2d._parse_format(c + l + m)
 
     # Test plotting methods
-    s, l = chart_2d.plot(x, y, "")
+    s, l = chart_2d.plot(x, y, '')
     assert s is None
     assert l is None
     assert len([*chart_2d.plots()]) == 0
-    s, l = chart_2d.plot(y, "-")
+    s, l = chart_2d.plot(y, '-')
     assert s is None
     assert l is not None
-    assert l in chart_2d.plots("line")
+    assert l in chart_2d.plots('line')
     chart_2d.remove_plot(l)
     assert len([*chart_2d.plots()]) == 0
-    s, l = chart_2d.plot(y, "x")
+    s, l = chart_2d.plot(y, 'x')
     assert s is not None
     assert l is None
-    assert s in chart_2d.plots("scatter")
-    chart_2d.clear("scatter")
+    assert s in chart_2d.plots('scatter')
+    chart_2d.clear('scatter')
     assert len([*chart_2d.plots()]) == 0
-    s, l = chart_2d.plot(x, y, "x-")
+    s, l = chart_2d.plot(x, y, 'x-')
     assert s is not None
     assert l is not None
-    assert s in chart_2d.plots("scatter")
-    assert l in chart_2d.plots("line")
-    chart_2d.plot(x, y, "x-")  # Check clearing of multiple plots (of the same type)
+    assert s in chart_2d.plots('scatter')
+    assert l in chart_2d.plots('line')
+    chart_2d.plot(x, y, 'x-')  # Check clearing of multiple plots (of the same type)
     chart_2d.clear()
     assert len([*chart_2d.plots()]) == 0
 
-    s = chart_2d.scatter(x, y, col, sz, ms, lx)
+    s = chart_2d.scatter(x, y, color=col, size=sz, style=ms, label=lx)
     assert np.allclose(s.x, x)
     assert np.allclose(s.y, y)
     assert s.color == col
     assert s.marker_size == sz
     assert s.marker_style == ms
     assert s.label == lx
-    assert s in chart_2d.plots("scatter")
+    assert s in chart_2d.plots('scatter')
     assert chart_2d.GetPlotIndex(s) >= 0
 
-    l = chart_2d.line(x, y, col, w, ls, lx)
+    l = chart_2d.line(x, y, color=col, width=w, style=ls, label=lx)
     assert np.allclose(l.x, x)
     assert np.allclose(l.y, y)
     assert l.color == col
     assert l.line_width == w
     assert l.line_style == ls
     assert l.label == lx
-    assert l in chart_2d.plots("line")
+    assert l in chart_2d.plots('line')
     assert chart_2d.GetPlotIndex(l) >= 0
 
-    a = chart_2d.area(x, -y, y, col, lx)
+    a = chart_2d.area(x, -y, y, color=col, label=lx)
     assert np.allclose(a.x, x)
     assert np.allclose(a.y1, -y)
     assert np.allclose(a.y2, y)
     assert a.color == col
     assert a.label == lx
-    assert a in chart_2d.plots("area")
+    assert a in chart_2d.plots('area')
     assert chart_2d.GetPlotIndex(a) >= 0
 
-    b = chart_2d.bar(x, -y, col, ori, lx)
+    b = chart_2d.bar(x, -y, color=col, orientation=ori, label=lx)
     assert np.allclose(b.x, x)
     assert np.allclose(b.y, -y)
     assert b.color == col
     assert b.orientation == ori
     assert b.label == lx
-    assert b in chart_2d.plots("bar")
+    assert b in chart_2d.plots('bar')
     assert chart_2d.GetPlotIndex(b) >= 0
 
-    s = chart_2d.stack(x, ys, cs, [lx, ly])
+    s = chart_2d.stack(x, ys, colors=cs, labels=[lx, ly])
     assert np.allclose(s.x, x)
     assert np.allclose(s.ys, ys)
     assert s.color_scheme == cs
     assert tuple(s.labels) == (lx, ly)
-    assert s in chart_2d.plots("stack")
+    assert s in chart_2d.plots('stack')
     assert chart_2d.GetPlotIndex(s) >= 0
 
-    inv_type = "blub"
+    inv_type = 'blub'
     with pytest.raises(KeyError):
         next(chart_2d.plots(inv_type))
     with pytest.raises(KeyError):
@@ -918,17 +931,17 @@ def test_chart_2d(pl, chart_2d):
         assert not axis.grid
 
 
-@pytest.mark.skip_plotting()
+@pytest.mark.skip_plotting
 def test_chart_box(pl, chart_box, box_plot):
     size = (0.5, 0.5)
     loc = (0.25, 0.25)
     data = [[0, 1, 1, 1, 2, 2, 3, 4, 4, 5, 5, 5, 6]]
     stats = [np.quantile(d, [0.0, 0.25, 0.5, 0.75, 1.0]) for d in data]
-    cs = "wild_flower"
-    ls = ["Datalabel"]
+    cs = 'wild_flower'
+    ls = ['Datalabel']
 
     # Test constructor
-    chart = pv.ChartBox(data, cs, ls, size, loc)
+    chart = pv.ChartBox(data, colors=cs, labels=ls, size=size, loc=loc)
     assert np.allclose(chart.plot.data, data)
     assert chart.plot.color_scheme == cs
     assert tuple(chart.plot.labels) == tuple(ls)
@@ -955,16 +968,16 @@ def test_chart_box(pl, chart_box, box_plot):
     assert np.allclose(box_plot.stats, stats)
 
 
-@pytest.mark.skip_plotting()
+@pytest.mark.skip_plotting
 def test_chart_pie(pl, chart_pie, pie_plot):
     size = (0.5, 0.5)
     loc = (0.25, 0.25)
     data = [3, 4, 5]
-    cs = "wild_flower"
-    ls = ["Tic", "Tac", "Toe"]
+    cs = 'wild_flower'
+    ls = ['Tic', 'Tac', 'Toe']
 
     # Test constructor
-    chart = pv.ChartPie(data, cs, ls, size, loc)
+    chart = pv.ChartPie(data, colors=cs, labels=ls, size=size, loc=loc)
     assert np.allclose(chart.plot.data, data)
     assert chart.plot.color_scheme == cs
     assert tuple(chart.plot.labels) == tuple(ls)
@@ -990,8 +1003,8 @@ def test_chart_pie(pl, chart_pie, pie_plot):
     assert np.allclose(pie_plot.data, data)
 
 
-@pytest.mark.skip_plotting()
-def test_chart_mpl(pl, chart_mpl):
+@pytest.mark.skip_plotting
+def test_chart_mpl(pl):
     import matplotlib.pyplot as plt
 
     size = (0.5, 0.5)
@@ -999,7 +1012,7 @@ def test_chart_mpl(pl, chart_mpl):
 
     # Test constructor
     f, ax = plt.subplots()
-    chart = pv.ChartMPL(f, size, loc)
+    chart = pv.ChartMPL(f, size=size, loc=loc)
     assert chart.size == size
     assert chart.loc == loc
 
@@ -1020,11 +1033,11 @@ def test_chart_mpl(pl, chart_mpl):
     assert np.allclose(chart._canvas.get_width_height(), (size[0] * r_w / 2, size[1] * r_h / 2))
 
     # test set position throw
-    with pytest.raises(ValueError, match="must be length 2"):
+    with pytest.raises(ValueError, match='must be length 2'):
         chart.position = (1, 2, 3)
 
 
-@pytest.mark.skip_plotting()
+@pytest.mark.skip_plotting
 def test_chart_mpl_update(pl):
     import matplotlib.pyplot as plt
 
@@ -1053,7 +1066,7 @@ def test_chart_mpl_update(pl):
     assert pl_changed()
 
 
-@pytest.mark.skip_plotting()
+@pytest.mark.skip_plotting
 def test_charts(pl):
     win_size = pl.window_size
     top_left = pv.Chart2D(size=(0.5, 0.5), loc=(0, 0.5))
@@ -1093,7 +1106,7 @@ def test_charts(pl):
     assert pl.renderer._charts._scene is None
 
 
-@pytest.mark.skip_plotting()
+@pytest.mark.skip_plotting
 def test_iren_context_style(pl):
     chart = pv.Chart2D(size=(0.5, 0.5), loc=(0.5, 0.5))
     win_size = pl.window_size
@@ -1105,7 +1118,7 @@ def test_iren_context_style(pl):
     # Simulate double left click on the chart:
     pl.iren._mouse_left_button_click(int(0.75 * win_size[0]), int(0.75 * win_size[1]), count=2)
     assert chart.GetInteractive()
-    assert pl.iren._style == "Context"
+    assert pl.iren._style == 'Context'
     assert pl.iren._style_class == pl.iren._context_style
     assert pl.iren._context_style.GetScene().__this__ == chart._scene.__this__
 
@@ -1117,12 +1130,12 @@ def test_iren_context_style(pl):
     assert pl.iren._context_style.GetScene() is None
 
 
-@pytest.mark.skip_plotting()
+@pytest.mark.skip_plotting
 @pytest.mark.needs_vtk_version(
     9,
     3,
     0,
-    reason="Chart interaction when using multiple renderers is bugged on older versions.",
+    reason='Chart interaction when using multiple renderers is bugged on older versions.',
 )
 def test_chart_interaction():
     # Setup multi renderer plotter with one chart in the top renderer and two charts
@@ -1213,7 +1226,7 @@ def test_chart_interaction():
     assert pl.iren._context_style.GetScene() is None
 
 
-@skip_mac
+@pytest.mark.skip_mac('MacOS CI fails when downloading examples')
 def test_get_background_texture(chart_2d):
     t_puppy = examples.download_puppy_texture()
     chart_2d.background_texture = t_puppy
