@@ -7,13 +7,11 @@ import pytest
 
 import pyvista as pv
 
-
-@pytest.fixture(autouse=True)
-def skip_check_gc(skip_check_gc):  # noqa: PT004
-    """A large number of tests here fail gc."""
+# A large number of tests here fail gc
+pytestmark = pytest.mark.skip_check_gc
 
 
-@pytest.fixture()
+@pytest.fixture
 def cube_axes_actor():
     pl = pv.Plotter()
     pl.add_mesh(pv.Sphere())
@@ -46,7 +44,7 @@ def test_labels(cube_axes_actor):
     cube_axes_actor.y_label_format = ''
     assert len(cube_axes_actor.y_labels) == 5
     values = np.array(cube_axes_actor.y_labels, float)
-    expected = np.linspace(cube_axes_actor.bounds[2], cube_axes_actor.bounds[3], 5)
+    expected = np.linspace(cube_axes_actor.bounds.y_min, cube_axes_actor.bounds.y_max, 5)
     assert np.allclose(values, expected)
 
     # standard format
@@ -111,11 +109,43 @@ def test_axis_minor_tick_visibility(cube_axes_actor):
     assert cube_axes_actor.z_axis_minor_tick_visibility is False
 
 
-def test_offset(cube_axes_actor):
+@pytest.mark.needs_vtk_version(
+    less_than=(9, 3, 0),
+    reason='title offset is a tuple of floats from vtk >= 9.3',
+)
+def test_title_offset(cube_axes_actor):
     assert isinstance(cube_axes_actor.title_offset, float)
     cube_axes_actor.title_offset = 0.01
     assert cube_axes_actor.title_offset == 0.01
 
+    with pytest.warns(
+        UserWarning,
+        match=r'Setting title_offset with a sequence is only supported from vtk >= 9\.3. '
+        rf'Considering only the second value \(ie\. y-offset\) of {(y := 0.02)}',
+    ):
+        cube_axes_actor.title_offset = [0.01, y]
+    assert cube_axes_actor.title_offset == y
+
+
+@pytest.mark.needs_vtk_version(9, 3)
+def test_title_offset_sequence(cube_axes_actor):
+    assert isinstance(cube_axes_actor.title_offset, tuple)
+    cube_axes_actor.title_offset = (t := (0.01, 0.02))
+    assert cube_axes_actor.title_offset == t
+
+
+@pytest.mark.needs_vtk_version(9, 3)
+def test_title_offset_float(cube_axes_actor):
+    with pytest.warns(
+        UserWarning,
+        match=r'Setting title_offset with a float is deprecated from vtk >= 9.3. Accepts now a '
+        r'sequence of \(x,y\) offsets. Setting the x offset to 0\.0',
+    ):
+        cube_axes_actor.title_offset = (t := 0.01)
+    assert cube_axes_actor.title_offset == (0.0, t)
+
+
+def test_label_offset(cube_axes_actor):
     assert isinstance(cube_axes_actor.label_offset, float)
     cube_axes_actor.label_offset = 0.01
     assert cube_axes_actor.label_offset == 0.01
