@@ -191,7 +191,9 @@ def test_transforms():
     light.transform_matrix = trans_matrix
     matrix = light.transform_matrix
     assert all(
-        matrix.GetElement(i, j) == trans_matrix.GetElement(i, j) for i in range(4) for j in range(4)
+        matrix.GetElement(i, j) == trans_matrix.GetElement(i, j)
+        for i in range(4)
+        for j in range(4)
     )
 
     linear_trans = trans_array[:-1, :-1]
@@ -201,7 +203,7 @@ def test_transforms():
     assert light.focal_point == focal_point
     assert np.allclose(light.world_focal_point, linear_trans @ focal_point + shift)
 
-    with pytest.raises(ValueError):  # noqa: PT011
+    with pytest.raises(TypeError, match='Input transform must be one of'):
         light.transform_matrix = 'invalid'
 
 
@@ -301,10 +303,9 @@ def test_from_vtk():
     # set the vtk light
     for _, value, vtkname in configuration:
         vtk_setter = getattr(vtk_light, vtkname)
-        if isinstance(value, np.ndarray):
-            # we can't pass the array to vtkLight directly
-            value = pv.vtkmatrix_from_array(value)
-        vtk_setter(value)
+        # we can't pass the array to vtkLight directly
+        input_value = pv.vtkmatrix_from_array(value) if isinstance(value, np.ndarray) else value
+        vtk_setter(input_value)
     light = pv.Light.from_vtk(vtk_light)
     for pvname, value, _ in configuration:
         if isinstance(value, np.ndarray):
@@ -317,7 +318,7 @@ def test_from_vtk():
     with pytest.raises(TypeError):
         pv.Light.from_vtk('invalid')
     with pytest.raises(TypeError):
-        pv.Light('invalid')
+        pv.Light(position='invalid')
 
 
 def test_add_vtk_light():
