@@ -2,19 +2,80 @@
 
 from __future__ import annotations
 
+import re
 import time
+from typing import TYPE_CHECKING
 
 import pytest
 
 import pyvista as pv
 from pyvista import _vtk
 from pyvista.core.errors import PyVistaDeprecationWarning
+from pyvista.plotting.render_window_interactor import InteractorStyleImage
+from pyvista.plotting.render_window_interactor import InteractorStyleJoystickActor
+from pyvista.plotting.render_window_interactor import InteractorStyleJoystickCamera
+from pyvista.plotting.render_window_interactor import InteractorStyleRubberBand2D
+from pyvista.plotting.render_window_interactor import InteractorStyleRubberBandPick
+from pyvista.plotting.render_window_interactor import InteractorStyleTerrain
+from pyvista.plotting.render_window_interactor import InteractorStyleTrackballActor
+from pyvista.plotting.render_window_interactor import InteractorStyleTrackballCamera
+from pyvista.plotting.render_window_interactor import InteractorStyleZoom
+from tests.plotting.test_plotting import skip_windows_mesa
+
+if TYPE_CHECKING:
+    from pytest_mock import MockerFixture
 
 
 def empty_callback():
     return
 
 
+@pytest.mark.parametrize('callback', ['foo', 1, object()])
+def test_track_click_position_raises(callback):
+    pl = pv.Plotter()
+    match = re.escape(
+        'Invalid callback provided, it should be either ``None`` or a callable.',
+    )
+    with pytest.raises(TypeError, match=match):
+        pl.track_click_position(callback=callback)
+
+
+def test_simulate_key_press_raises():
+    pl = pv.Plotter()
+    with pytest.raises(
+        ValueError,
+        match=re.escape('Only accepts a single key'),
+    ):
+        pl.iren._simulate_keypress(key=['f', 't'])
+
+
+def test_process_events_raises(mocker: MockerFixture):
+    pl = pv.Plotter()
+    m = mocker.patch.object(pl.iren, 'interactor')
+    m.GetInitialized.return_value = False
+
+    with pytest.raises(
+        RuntimeError,
+        match='Render window interactor must be initialized before processing events.',
+    ):
+        pl.iren.process_events()
+
+
+@pytest.mark.parametrize('picker', ['foo', 1000])
+def test_picker_raises(picker, mocker: MockerFixture):
+    pl = pv.Plotter()  # patching need to occur after init
+
+    from pyvista.plotting import render_window_interactor
+
+    m = mocker.patch.object(render_window_interactor.PickerType, 'from_any')
+    m.return_value = (v := len(list(render_window_interactor.PickerType)))
+
+    with pytest.raises(KeyError, match=re.escape(f'Picker class `{v}` is unknown.')):
+        pl.iren.picker = picker
+
+    m.assert_called_once_with(picker)
+
+
 @pytest.mark.needs_vtk_version(9, 1)
 def test_observers():
     pl = pv.Plotter()
@@ -42,21 +103,21 @@ def test_observers():
 
     # Custom events
     assert not pl.iren.interactor.HasObserver(
-        "PickEvent",
-    ), "Subsequent PickEvent HasObserver tests are wrong if this fails."
+        'PickEvent',
+    ), 'Subsequent PickEvent HasObserver tests are wrong if this fails.'
     # Add different observers
     obs_move = pl.iren.add_observer(_vtk.vtkCommand.MouseMoveEvent, empty_callback)
     obs_double1 = pl.iren.add_observer(_vtk.vtkCommand.LeftButtonDoubleClickEvent, empty_callback)
-    obs_double2 = pl.iren.add_observer("LeftButtonDoubleClickEvent", empty_callback)
-    obs_picks = tuple(pl.iren.add_observer("PickEvent", empty_callback) for _ in range(5))
-    pl.iren.add_observer("SelectionChangedEvent", empty_callback)
-    assert pl.iren._observers[obs_move] == "MouseMoveEvent"
-    assert pl.iren.interactor.HasObserver("MouseMoveEvent")
-    assert pl.iren._observers[obs_double1] == "LeftButtonDoubleClickEvent"
-    assert pl.iren._observers[obs_double2] == "LeftButtonDoubleClickEvent"
-    assert pl.iren.interactor.HasObserver("LeftButtonDoubleClickEvent")
-    assert all(pl.iren._observers[obs_pick] == "PickEvent" for obs_pick in obs_picks)
-    assert pl.iren.interactor.HasObserver("SelectionChangedEvent")
+    obs_double2 = pl.iren.add_observer('LeftButtonDoubleClickEvent', empty_callback)
+    obs_picks = tuple(pl.iren.add_observer('PickEvent', empty_callback) for _ in range(5))
+    pl.iren.add_observer('SelectionChangedEvent', empty_callback)
+    assert pl.iren._observers[obs_move] == 'MouseMoveEvent'
+    assert pl.iren.interactor.HasObserver('MouseMoveEvent')
+    assert pl.iren._observers[obs_double1] == 'LeftButtonDoubleClickEvent'
+    assert pl.iren._observers[obs_double2] == 'LeftButtonDoubleClickEvent'
+    assert pl.iren.interactor.HasObserver('LeftButtonDoubleClickEvent')
+    assert all(pl.iren._observers[obs_pick] == 'PickEvent' for obs_pick in obs_picks)
+    assert pl.iren.interactor.HasObserver('SelectionChangedEvent')
     # Remove a specific observer
     pl.iren.remove_observer(obs_move)
     assert obs_move not in pl.iren._observers
@@ -67,7 +128,7 @@ def test_observers():
     # Remove all (remaining) observers
     pl.iren.remove_observers()
     assert len(pl.iren._observers) == 0
-    assert not pl.iren.interactor.HasObserver("PickEvent")
+    assert not pl.iren.interactor.HasObserver('PickEvent')
 
 
 def test_clear_key_event_callbacks():
@@ -75,7 +136,7 @@ def test_clear_key_event_callbacks():
     pl.reset_key_events()
 
 
-@pytest.mark.skip_plotting()
+@pytest.mark.skip_plotting
 def test_track_mouse_position():
     pl = pv.Plotter()
     pl.track_mouse_position()
@@ -86,10 +147,10 @@ def test_track_mouse_position():
     assert pl.mouse_position == (x, y)
 
     pl.iren.untrack_mouse_position()
-    assert "MouseMoveEvent" not in pl.iren._observers.values()
+    assert 'MouseMoveEvent' not in pl.iren._observers.values()
 
 
-@pytest.mark.skip_plotting()
+@pytest.mark.skip_plotting
 def test_track_click_position_multi_render():
     points = []
 
@@ -113,15 +174,15 @@ def test_track_click_position_multi_render():
     assert len(points) == 1
 
 
-@pytest.mark.skip_plotting()
+@pytest.mark.skip_plotting
 def test_track_click_position():
     events = []
 
-    def single_click_callback(mouse_position):
-        events.append("single")
+    def single_click_callback(mouse_position):  # noqa: ARG001
+        events.append('single')
 
-    def double_click_callback(mouse_position):
-        events.append("double")
+    def double_click_callback(mouse_position):  # noqa: ARG001
+        events.append('double')
 
     pl = pv.Plotter()
     pl.track_click_position(callback=single_click_callback, side='left', double=False)
@@ -131,28 +192,30 @@ def test_track_click_position():
     # Test single and double clicks:
     pl.iren._mouse_left_button_click(10, 10)
     assert len(events) == 1
-    assert events.pop(0) == "single"
+    assert events.pop(0) == 'single'
     pl.iren._mouse_left_button_click(50, 50, count=2)
     assert len(events) == 2
-    assert events.pop(1) == "double"
-    assert events.pop(0) == "single"
+    assert events.pop(1) == 'double'
+    assert events.pop(0) == 'single'
 
     # Test triple click behaviour:
     pl.iren._mouse_left_button_click(10, 10, count=3)
     assert len(events) == 3
-    assert events.pop(2) == "single"
-    assert events.pop(1) == "double"
-    assert events.pop(0) == "single"
+    assert events.pop(2) == 'single'
+    assert events.pop(1) == 'double'
+    assert events.pop(0) == 'single'
 
 
+@skip_windows_mesa
 @pytest.mark.skipif(
     type(_vtk.vtkRenderWindowInteractor()).__name__
-    not in ("vtkWin32RenderWindowInteractor", "vtkXRenderWindowInteractor"),
+    not in ('vtkWin32RenderWindowInteractor', 'vtkXRenderWindowInteractor'),
     reason='Other RenderWindowInteractors do not invoke TimerEvents during ProcessEvents.',
 )
 @pytest.mark.needs_vtk_version(
     (9, 2),
-    reason='vtkXRenderWindowInteractor (Linux) does not invoke TimerEvents during ProcessEvents until VTK9.2.',
+    reason='vtkXRenderWindowInteractor (Linux) does not invoke TimerEvents during ProcessEvents '
+    'until VTK9.2.',
 )
 def test_timer():
     # Create a normal interactor from the offscreen plotter (not generic,
@@ -165,7 +228,7 @@ def test_timer():
     delay = 5 * duration  # Extra time we wait for the timers to fire at least once
     events = []
 
-    def on_timer(obj, event):
+    def on_timer(obj, event):  # noqa: ARG001
         # TimerEvent callback
         events.append(event)
 
@@ -176,7 +239,7 @@ def test_timer():
             iren.process_events()
 
     # Setup interactor
-    iren.add_observer("TimerEvent", on_timer)
+    iren.add_observer('TimerEvent', on_timer)
     iren.initialize()
 
     # Test one-shot timer (only fired once for the extended duration)
@@ -211,7 +274,7 @@ def test_add_timer_event():
     pl.show(cpos=cpos)
 
 
-@pytest.mark.skip_plotting()
+@pytest.mark.skip_plotting
 def test_poked_subplot_loc():
     pl = pv.Plotter(shape=(2, 2), window_size=(800, 800))
 
@@ -230,8 +293,9 @@ def test_poked_subplot_loc():
     pl.close()
 
 
-@pytest.mark.skip_plotting()
-def test_poked_subplot_context(verify_image_cache):
+@pytest.mark.skip_plotting
+@pytest.mark.usefixtures('verify_image_cache')
+def test_poked_subplot_context():
     pl = pv.Plotter(shape=(2, 2), window_size=(800, 800))
 
     pl.iren._mouse_left_button_press(200, 600)
@@ -253,10 +317,10 @@ def test_poked_subplot_context(verify_image_cache):
     pl.show()
 
 
-@pytest.mark.skip_plotting()
+@pytest.mark.skip_plotting
 def test_add_pick_observer():
+    pl = pv.Plotter()
     with pytest.warns(PyVistaDeprecationWarning, match='`add_pick_obeserver` is deprecated'):
-        pl = pv.Plotter()
         pl.iren.add_pick_obeserver(empty_callback)
     pl = pv.Plotter()
     pl.iren.add_pick_observer(empty_callback)
@@ -290,9 +354,60 @@ def test_enable_custom_trackball_style():
 
     pl = pv.Plotter()
     with pytest.raises(ValueError, match="Action 'not an option' not in the allowed"):
-        pl.enable_custom_trackball_style(left="not an option")
+        pl.enable_custom_trackball_style(left='not an option')
 
 
 def test_enable_2d_style():
     pl = pv.Plotter()
     pl.enable_2d_style()
+
+
+def test_enable_interactors():
+    mapping = {
+        'enable_trackball_style': InteractorStyleTrackballCamera,
+        'enable_custom_trackball_style': InteractorStyleTrackballCamera,
+        'enable_2d_style': InteractorStyleTrackballCamera,
+        'enable_trackball_actor_style': InteractorStyleTrackballActor,
+        'enable_image_style': InteractorStyleImage,
+        'enable_joystick_style': InteractorStyleJoystickCamera,
+        'enable_joystick_actor_style': InteractorStyleJoystickActor,
+        'enable_zoom_style': InteractorStyleZoom,
+        'enable_terrain_style': InteractorStyleTerrain,
+        'enable_rubber_band_style': InteractorStyleRubberBandPick,
+        'enable_rubber_band_2d_style': InteractorStyleRubberBand2D,
+    }
+
+    pl = pv.Plotter()
+
+    # check that all "enable_*_style" methods on plotter are in the mapping and vice versa
+    attrs = dir(pl)
+    attrs_enable_style = {
+        attr for attr in attrs if attr.startswith('enable_') and attr.endswith('_style')
+    }
+
+    check_set = set(mapping.keys())
+    assert attrs_enable_style == check_set
+
+    # do the same for methods on the RenderWindowInteractor
+    attrs = dir(pl.iren)
+    attrs_enable_style = {
+        attr for attr in attrs if attr.startswith('enable_') and attr.endswith('_style')
+    }
+    check_set = set(mapping.keys())
+    assert attrs_enable_style == check_set
+
+    # check that the method gives the right class
+    for attr, class_ in mapping.items():
+        print(attr, class_)
+        getattr(pl, attr)()
+        assert isinstance(pl.iren.style, class_)
+
+    for attr, class_ in mapping.items():
+        getattr(pl.iren, attr)()
+        assert isinstance(pl.iren.style, class_)
+
+
+def test_setting_custom_style():
+    pl = pv.Plotter()
+    pl.iren.style = _vtk.vtkInteractorStyleJoystickActor()
+    assert isinstance(pl.iren.style, _vtk.vtkInteractorStyleJoystickActor)
