@@ -5,13 +5,15 @@ anything that's beyond testing actual library code.
 
 """
 
+from __future__ import annotations
+
 
 def test_mpl_backend():
     """Check if the backend is correctly set for testing."""
     # only fail if matplotlib is otherwise available
     try:
-        import matplotlib
+        import matplotlib as mpl
     except ImportError:
         return
 
-    assert matplotlib.get_backend() == 'agg'
+    assert mpl.get_backend() == 'agg'
